/************************************************************************
*
*                              ML6DEMO1.C
*
*           Shows the handling of a Multi-COM board from a PC
*           with Windows NT or 95
*
*					      version      : see history
*							creation 	 : 04.04.98
*							last change  : see history
*							author       : A. Horst
*
*         		(c) by SORCUS Computer GmbH Heidelberg 1998
*************************************************************************/

/************************************************************************
*
*	software requirements:
*       Windows NT:
*       To make an EXE-file you have to link NML6BIB.LIB (MSVC) or
*       NML6BIBB.LIB (BC) and ML6ERRE.C.
*		  To run the application the NML6BIB.DLL must be in the actual
*       directory or in the systems path
*       Windows 95:
*       To make an EXE-file you have to link FML6BIB.LIB (MSVC) or
*       FML6BIBB.LIB (BC) and ML6ERRE.C.
*		  To run the application the FML6BIB.DLL must be in the actual
*       directory or in the systems path
*
*  hints:
*		- this program is tested with Borland C 5.0 and MSVC V.4.1 but it
*       should run with other 32-bit compilers.
*
*     - to compile this example you have to build a 'console application'
*       because of the usage of 'printf'.
*
*************************************************************************/

/************************************************************************
*  history:
*   	1.A. 04.04.98 (AH):
*        - creation of the file
*************************************************************************/

#include <conio.h>
#include <stdio.h>
#include <stdlib.h>

#include "ml6bib.h"                    // include SORCUS library

#define BLINK_COUNT 20						// number of LED switchings
#define MS_WAITING  100					   // delay between switching


void errorhandler(void);
void waitmillisec(unsigned long msec);


void main(void)
{
	unsigned int	retval;
	unsigned int	w;
	char			   errorstr[80];
	unsigned char  errorclass, errorcode;


   printf("\n***********************************************************\n");
   printf("           ML6DEMO1: blinking LED ('Hello World!')\n");
   printf("***********************************************************\n");

   /* ml6_bib_startup: this procedure must be called before all other
      ml6_xxx procedures because of library initialisation.
      The used language is C
   */
   ml6_bib_startup(LANGUAGE_C);

	/* In Windows NT some Parameters of the board like I/O address and
	   interrupt channel are retained by the registry. Therefore some
		parameters of 'ml6_reset' are not used */
   retval = ml6_reset(
                  0, 				      // card number
                  0x380, 					// not used in Windows NT
                  0, 						// mode: no interrupts used
                  7, 						// not used in Windows NT
                  1, 						// not used in Windows NT
                  * errorhandler, 		// address of error handler called
													//	back by the library
                  "ROM", 					// operating system for the board
                  20);						// timeout


   if (retval > 0)                       // if an error occured
   {
	   printf("\nError in 'ml6_reset': \n");
		errorclass = (byte)(retval >> 8);
		errorcode  = (byte)(retval);
													// get the error message
      ml6_get_error_msg(errorstr, errorclass, errorcode);
      printf("%s\n",errorstr);
      printf("Fehlerklasse: %02Xh\n", errorclass);
      printf("Fehlercode  : %02Xh\n", errorcode);
	   ml6_exit();
  	   getch();
      return;
   }

	/*----------- internal LED blinking -------------*/
   printf("\nInternal LED:  ");
   for (w = 0; w < BLINK_COUNT; w++)
   {
	   ml6_local_led_on();
	   printf("*");

	   waitmillisec(MS_WAITING);
	   ml6_local_led_off();
	   waitmillisec(MS_WAITING);
   }
   printf("\n");


	/*----------- external LED blinking -------------*/
   printf("\nExternal LED (only if connected):  ");
   for (w = 0; w < BLINK_COUNT; w++)
   {
	   ml6_external_led_on();
	   printf("*");
	   waitmillisec(MS_WAITING);
	   ml6_external_led_off();
	   waitmillisec(MS_WAITING);
   }
   printf("\n");


   ml6_exit();		           /* use ml6_exit to close the library */
	printf("\n\n<press any key>\n");
	getch();
   return;
}


/**********************************************************************
*  waitmillisec:
*     delays execution for a time given in milliseconds
**********************************************************************/
void waitmillisec(unsigned long msec)
{
	unsigned long	start, current;

	start = GetTickCount();

	do
   {
	   current = GetTickCount();
	} while((current - start) < msec);
}

/********************************************************************
*  errorhandler:
*     This is a callback function. It is called if there's an error
*     during a library call.
*********************************************************************/
void errorhandler(void)
{
   char   errstr[80];
	struct ml6_error_info_type err;

	ml6_get_error_info(&err);

   printf("\n\n\n************************************************\n");
   printf("************** ERROR OCCURED!!! ****************\n");
   printf("************************************************\n\n");
	switch (err.errortype)
   {
      case ERROR_DLL:
	         ml6_get_error_msg(errstr, err.dll.errorclass, err.dll.errorcode);
	         printf("DLL-Error    : %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.dll.errorclass);
	         printf("errorcode    : %02Xh\n", err.dll.errorcode);
            break;
      case ERROR_COMMUNICATION:
	         ml6_get_error_msg(errstr, err.dll.errorclass, err.dll.errorcode);
	         printf("Communication Error: %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.com.errorclass);
	         printf("errorcode    : %02Xh\n", err.com.errorcode);
            break;
      case ERROR_SYSTEM:
	         printf("System Error: %d(d)\n", err.system.error);
            break;
      case ERROR_DRIVER:
	         printf("Driver Error: \n");
	         printf("expected data length: %d(d)\n", err.drv.dataoutsize);
	         printf("real data length: %d(d)\n", err.drv.retlength);
            break;
      default: printf("unknown error\n");
   }
	getch();
	exit(1);
}
