/************************************************************************
*
*                              ML6DEMO2.C
*
*           Shows the handling of a Multi-COM board from a PC
*           with Windows NT or 95: a realtime program is loaded
*
*					      version      : see history
*							creation 	 : 06.04.98
*							last change  : see history
*							author       : A. Horst
*
*         		(c) by SORCUS Computer GmbH Heidelberg 1998
*************************************************************************/

/************************************************************************
*
*	description:
*       The realtime program M6P0300.EXE is loaded to the Multi-COM
*       board. After starting the blink rate of the internal LED can
*       be modified
*
*	software requirements:
*       Windows NT:
*       To make an EXE-file you have to link NML6BIB.LIB and ML6ERRE.C.
*		  To run the application the NML6BIB.DLL must be in the actual
*       directory or in the systems path.
*       Windows 95:
*       To make an EXE-file you have to link FML6BIB.LIB and ML6ERRE.C.
*		  To run the application the FML6BIB.DLL must be in the actual
*       directory or in the systems path.
*
*       The realtime program M6P0300.EXE must be in the given directory.
*
*  hints:
*		- this program is tested with Borland C 5.0 and MSVC V.4.1 but it
*       should run with other 32-bit compilers.
*
*     - to compile this example you have to build a 'console application'
*       because of the usage of 'printf'.
*
*************************************************************************/

/************************************************************************
*  history:
*   	1.A. 06.04.98 (AH):
*        - creation of the file
*************************************************************************/

#include <conio.h>
#include <stdio.h>
#include <stdlib.h>

#include "ml6bib.h"

#define BLINK_MAX   30000					// maximal blink rate
#define BLINK_MIN   2000 					// minimal blink rate
#define BLINK_STEP  1000					// steps to switch blink rate
#define TASKNUMBER  50

void errorhandler(void);
void ModifyBlinkrate(void);
void SetBrLower(unsigned short *pBr);
void SetBrHigher(unsigned short *pBr);


void main(void)
{
	unsigned int	retval;
	char			   errorstr[80];
	byte           errorclass, errorcode;


   printf("\n***********************************************************\n");
   printf("          ML6DEMO2: loads a program on the board\n");
   printf("***********************************************************\n");

   /* ml6_bib_startup: this procedure must be called before all other
      ml6_xxx procedures because of library initialisation.
      The used language is C
   */
   ml6_bib_startup(LANGUAGE_C);

	/* In Windows NT some Parameters of the board like I/O address and
	   interrupt channel are retained by the registry. Therefore some
		parameters of 'ml6_reset' are not used */
   retval = ml6_reset(
                  0, 			    		// card number
                  0x380, 					// not used in Windows NT
                  0, 						// mode: no interrupts used
                  7, 						// not used in Windows NT
                  1, 						// not used in Windows NT
                  * errorhandler, 		// address of error handler called
													//	back by the library
                  "ROM", 					// operating system for the board
                  20);						// timeout


   if (retval>0)                       // if an error occured
   {
	   printf("\nError in 'ml6_reset': \n");
		errorclass = (byte)(retval >> 8);
		errorcode  = (byte)(retval);
													// get the error message
      ml6_get_error_msg(errorstr, errorclass, errorcode);
      printf("%s\n", errorstr);
	   ml6_exit();
  	   getch();
      return;
   }

	/*----------  Loading the realtime program  -----------*/
	printf("\n ** loading the program **\n");
	retval = ml6_transfer_and_install(
						"c:\\sorcus\\ml6\\rt\\bc\\beisp\\M6P0300.EXE",
                                       // name of program
						0, 						// dummy, must be set to zero
						TASKNUMBER,				// install program under this
													//	task number
						0x300, 					// program number
						0, 						// interrupt, not used here
						0x980, 					// flags
						0);						// data size, not needed

	if (retval) {								// if error occured
	   printf("\nError in 'ml6_transfer_and_install': \n");
		errorclass = (byte)(retval >> 8);
		errorcode  = (byte)(retval);
													// get the error message
      ml6_get_error_msg(errorstr, errorclass, errorcode);
      printf("%s\n", errorstr);
	   ml6_exit();
  	   getch();
      return;
	}

	ml6_wakeup_task(TASKNUMBER);			// start the task

	ModifyBlinkrate();

   ml6_exit();		           /* use ml6_exit to close the library */
   return;
}


/**********************************************************************
*  ModifyBlinkrate:
*     this procedure sets the parameter #1 which is the blinkrate
**********************************************************************/
void ModifyBlinkrate(void)
{
	int      ch = ' ';		  				// holds keyboard input
	unsigned short br;						// holds blink rate

	printf("\n\n  changing of blinking frequency:\n");
	printf("    <h>: higher frequency\n");
	printf("    <l>: lower frequency\n");
	printf("    <q>: quit program\n\n");

	/* read the actual value of the blink rate (parameter #1) */
	ml6_read_par_block(TASKNUMBER,
							 0,					// start parameter
							 sizeof(br),		// number of bytes to read
							 &br);				// pointer to write bytes
	do{
		if(kbhit())
      {
		   ch = getch();
			if(ch == 'l') SetBrHigher(&br);
			if(ch == 'h') SetBrLower (&br);
	      /*------- write the new parameter ----------*/
	      ml6_write_par_block(
	      					TASKNUMBER,
								1,					// start parameter
								sizeof(br),		// number of bytes to write
								&br);				// pointer to read bytes
		}
	  }while( ch != 'q');
}

/**********************************************************************
*  SetBrHigher:
*     increases a value between BLINK_MAX and BLINK_MIN by step
*     BLINK_STEP
**********************************************************************/
void SetBrHigher(unsigned short *pBr)
{
	*pBr = *pBr + BLINK_STEP;			  	// increase Br if not >BLINK_MAX
	if(*pBr > BLINK_MAX) *pBr = BLINK_MAX;
}

/**********************************************************************
*  SetBrLower:
*     decreases a value between BLINK_MAX and BLINK_MIN by step
*     BLINK_STEP
**********************************************************************/
void SetBrLower(unsigned short *pBr)
{
	*pBr = *pBr - BLINK_STEP;				// decrease Br if not <BLINK_MIN
	if(*pBr < BLINK_MIN) *pBr = BLINK_MIN;
}


/********************************************************************
*  errorhandler:
*     This is a callback function. It is called if there's an error
*     in the library.
*********************************************************************/
void errorhandler(void)
{
   char   errstr[80];
	struct ml6_error_info_type  err;

	ml6_get_error_info( &err);

   printf("\n\n\n************************************************\n");
   printf("************** ERROR OCCURED!!! ****************\n");
   printf("************************************************\n\n");
	switch (err.errortype) {
      case ERROR_DLL:
	         ml6_get_error_msg(errstr, err.dll.errorclass, err.dll.errorcode);
	         printf("DLL-Error    : %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.dll.errorclass);
	         printf("errorcode    : %02Xh\n", err.dll.errorcode);
            break;
      case ERROR_COMMUNICATION:
	         ml6_get_error_msg(errstr, err.dll.errorclass, err.dll.errorcode);
	         printf("Communication Error: %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.com.errorclass);
	         printf("errorcode    : %02Xh\n", err.com.errorcode);
            break;
      case ERROR_SYSTEM:
	         printf("System Error: %d(d)\n", err.system.error);
            break;
      case ERROR_DRIVER:
	         printf("Driver Error: \n");
	         printf("expected data length: %d(d)\n", err.drv.dataoutsize);
	         printf("real data length: %d(d)\n", err.drv.retlength);
            break;
      default: printf("unknown error\n");
   }
	getch();
	exit(1);
}

