/************************************************************************
*
*                               ML6DEMO3.C
*
*           Shows the handling of interrupts of a Multi-COM board
*           with Windows NT or 95
*
*					      version      : see history
*							creation 	 : 06.04.98
*							last change  : see history
*							author       : A. Horst
*
*        		(c) by SORCUS Computer GmbH Heidelberg 1998
*************************************************************************/

/************************************************************************
*  description:
*       This sample uses the RT-program M6P0304.EXE. It is loaded onto the
*       Multi-COM board, is configured and then started. It sends
*       interrupts to the PC which are monitored.
*
*	software requirements:
*       Windows NT:
*       To make an EXE-file you have to link NML6BIB.LIB and ML6ERRE.C.
*		  To run the application the NML6BIB.DLL must be in the actual
*       directory or in the systems path.
*       Windows 95:
*       To make an EXE-file you have to link FML6BIB.LIB and ML6ERRE.C.
*		  To run the application the FML6BIB.DLL must be in the actual
*       directory or in the systems path.
*
*       The realtime program M6P0304.EXE must be in the given directory.
*
*  hints:
*		- this program is tested with Borland C 5.0 and MSVC V.4.1 but it
*       should also run with other 32-bit compilers.
*
*     - to compile this example you have to build a 'console application'
*       because of the use of 'printf'.
*
*************************************************************************/

/*************************************************************************
*  history:
*   	1.A. 06.04.98 (AH):
*        - creation of the file
*************************************************************************/

#include "stdio.h"
#include "stdlib.h"
#include "conio.h"

#include "ml6bib.h"          /* Multi-COM library                        */

#define TRUE	1
#define FALSE	0

#define BLINKRATE  0x5000    /* blinkrate for the RT-program M6P0304.EXE */
#define IRQCOUNT   15        /* number of blinkings                      */

#define RTPROG  "c:\\sorcus\\ml6\\rt\\bc\\beisp\\M6P0304.EXE"
#define OS      "ROM"

void errorhandler(void);
void interrupt_service(void);

ushort	    irq_count= 0;	            /* counter for the interrupts */


void main(void)
{
   ushort	w;
   ushort	pgm,
	         task;
   char		s[80];

   /* the RT-program M6P0304.EXE uses byte alignment; therefore the
      following struct must also use byte alignment */

   #ifndef __BORLANDC__
     #pragma pack(push, SORCPACK, 1)
   #else
     #pragma option -a1
   #endif

   struct {
	   byte	   status;		            /* state of the RT-program            */
	   ushort	blink_rate;             /* blinkrate of the RT-program        */
	   byte	   led_status;	            /* state of the LED at beginning      */
      ushort   soft_cnt;               /* soft counter                     */
	   ushort	countdown;	            /* number of blinkings:
                                          0 = no blinking, 0xFFFF = infinite */
	   byte	   SRQ_enable;	            /* send interrupt to PC               */
	   ushort	SRQ_sign;	            /* request message                    */

   } parameter;

   #ifndef __BORLANDC__
     #pragma pack(pop, SORCPACK)
   #else
     #pragma option -a.
   #endif

   printf(" ***********************************************\n");
   printf("     ML6DEMO3.C (demonstrating PC-Interrupts)\n");
   printf(" ***********************************************\n\n");


   ml6_bib_startup(LANGUAGE_C);        /* language: C                        */
				                           /* initialisation of the library      */

   w = ml6_reset(0,                    // the following parameters are given
                 0,                    // by the registry and are therefore
                                       // ignored
                 1,                    // mode: with interrupts
                 0,
                 0,
                 * errorhandler,       // procedure that is called when an
                                       // error occures
                 OS,                   // operating system for the board
                 20);                  // timeout (* 100 ms)

   if(w > 0)                          // if w > 0 then an error occured
   {
	   printf("Error at ml6_reset:\n");
      ml6_get_error_msg(s, (byte)(w >> 8), (byte)(w & 0xFF) );
      printf("Message: %s\nReturn value: %04X\n", s, w);
      ml6_exit();
      exit(1);
   }

   printf("Versions:\n");
   ml6_get_os_version(s);              // get version of OsX
   printf("  OsX Version:    %s\n", s);
   ml6_get_bib_version(s);             // get version of DLL
   printf("  DLL Version:    %s\n", s);
   ml6_get_drv_version(s);             // get version of MLX-Driver
   printf("  Driver Version: %s\n\n", s);

    ml6_set_service(interrupt_service); // set the interrupt service routine

   pgm = 0x0304;                       // number of the RT-program
   task = 16;                          // task number to install M6P0304.EXE

   w = ml6_transfer_and_install(RTPROG,// program name
                              0,       // reserved
                              task,    // task number
                              pgm,     // program number
                              0,       // on-board-interrupt (not needed)
                              0x1980,  // flags: wakeup after install, NI-task
                              0);      // data area

   if(w > 0)                           // if w > 0 then an error occured
   {
    	printf("Error at ml6_transfer_and_install:\n");
      ml6_get_error_msg(s, (byte)(w >> 8), (byte)(w & 0xFF) );
      printf("Message: %s\nReturn value: %04X\n", s, w);
      ml6_exit();
      exit(1);
   }

   parameter.status     = 1;           // set parameter struct for RT-program
   parameter.blink_rate = BLINKRATE;
   parameter.led_status = 0;
   parameter.countdown  = IRQCOUNT;
   parameter.SRQ_enable = TRUE;
   parameter.SRQ_sign   = 0x0080;

   printf("Receiving Interrupts\n\n");
   ml6_allow_requests();               // allow interrupts now
                                       // write parameters to board
                                       // this starts the service requests
   ml6_write_par_block(task, 0, sizeof(parameter), &parameter);

   do {
      Sleep(1);
      //
      // Do anything until all interrupts are received
      //
   } while ((!kbhit()) && (irq_count < IRQCOUNT) );

   ml6_suspend_requests();             // suspend interrupts

   if(irq_count < IRQCOUNT) getch();

   printf("\nInterrupts received: %d\n\n", irq_count);

   ml6_exit();

   printf("<press any key>");
	getch();
   return;
}

/***************************************************************************
*  Interrupt Service Routine
*     this procedure is called if an interrupt from MODULAR-4/486 board
*     was received
***************************************************************************/
void interrupt_service(void)
{
   ushort message;

   message = ml6_get_message();			// get the message sent by the board
   irq_count++;								// increment interrupz counter
   printf(" Interrupt: #%d; Message: %Xh\n", irq_count, message);
}


/********************************************************************
*  errorhandler:
*     This is a callback function. It is called if there's an error
*     in the library.
*********************************************************************/
void errorhandler(void)
{
   char   errstr[80];
	struct ml6_error_info_type  err;

	ml6_get_error_info(&err);

   printf("\n\n\n************************************************\n");
   printf("************** ERROR OCCURED!!! ****************\n");
   printf("************************************************\n\n");
	switch (err.errortype)
   {
      case ERROR_DLL:
	         ml6_get_error_msg(errstr, err.dll.errorclass, err.dll.errorcode);
	         printf("DLL-Error    : %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.dll.errorclass);
	         printf("errorcode    : %02Xh\n", err.dll.errorcode);
            break;
      case ERROR_COMMUNICATION:
	         ml6_get_error_msg(errstr, err.dll.errorclass, err.dll.errorcode);
	         printf("Communication Error: %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.com.errorclass);
	         printf("errorcode    : %02Xh\n", err.com.errorcode);
            break;
      case ERROR_SYSTEM:
	         printf("System Error: %d(d)\n", err.system.error);
            break;
      case ERROR_DRIVER:
	         printf("Driver Error: \n");
	         printf("expected data length: %d(d)\n", err.drv.dataoutsize);
	         printf("real data length: %d(d)\n", err.drv.retlength);
            break;
      default: printf("unknown error\n");
   }
	getch();
	exit(1);
}

