/***********************************************************************
*  MDDDIAGD.C
*
*  PURPOSE
*                This file may be linked to a project with the SORCUS
*                library for MODULAR-4/486. It contains a procedure to
*                convert a diagnosis word provided by the function
*                mdd8_get_diagnosis into a string (german language).
*
*        AUTHORS
*                Dipl.-Ing. H.Doersam (HD)
*
*        COPYRIGHTS
*                SORCUS Computer GmbH Heidelberg (Germany) 1997
***********************************************************************/

/***********************************************************************

HISTORY

18/02/2000 (JD)
   -  Neuer Diagnosecode
      $0504: EEPROM-Wert liegt ausserhalb des zulaessigen Bereiches

18/03/98 (HD)
   -  Neue Diagnosecodes
      0x0503 (Datenverlust)
      0xFFFF (Diagnosewort ungueltig)

15/12/97 (HD)
   -        Creation of this file

***********************************************************************/



#include        "string.h"



/************************************************************************
*        mdd8_get_diagnosis_msg
*
*        PURPOSE
*        -        Converts a diagnosis message received from a MDD into a string
*        -        To receive the string reserve minimum 80 characters
*
*        PARAMETER
*        -        diagstr                        Points to a string object that receives the
*                                                        diagnosis message. The user should reserve
*                    a buffer of 256 characters to receive the error
*                    message.
*        -        code                                Diagnosis code (from mdd8_get_diagnosis)
*
*        RETURN
*        -        Nothing
*************************************************************************/
void mdd8_get_diagnosis_msg (char* diagstr, unsigned short code)
{
        //        If High-Byte = 0x01 then a parameter of an entried data
        //        structure is wrong. The offset of the wrong parameter
        //        is given in the Low-Byte.
        if ((code & 0xFF00) == 0x0100)
        {
                strcpy
                        (diagstr,
                        "Falscher Parameter (Offset = Low-Byte des Diagnosewortes)");
                return;
        }

   switch (code)
        {
        case 0x0000:
                strcpy(diagstr, "Kein Fehler aufgetreten");
                break;

        case 0x0001:
                strcpy(diagstr, "Aufruf hatte keinen Effekt");
                break;

        case 0x0201:
                strcpy(diagstr, "Anzahl Eingabedaten falsch");
                break;

        case 0x0202:
                strcpy(diagstr, "Anzahl Eingabedaten zu gross");
                break;

        case 0x0203:
                strcpy(diagstr, "Anzahl Eingabedaten zu klein");
                break;

        case 0x0211:
                strcpy(diagstr, "Anzahl Ausgabedaten falsch");
                break;

        case 0x0212:
                strcpy(diagstr, "Anzahl angeforderter Ausgabedaten zu gross");
                break;

        case 0x0213:
                strcpy(diagstr, "Anzahl angeforderter Ausgabedaten zu klein");
                break;

        case 0x0221:
                strcpy(diagstr, "Treiberdienst ist gesperrt");
                break;

        case 0x0321:
                strcpy(diagstr, "Bereichsueberschreitung");
                break;

        case 0x0322:
                strcpy(diagstr, "Bereichsunterschreitung");
                break;

        case 0x0323:
                strcpy(diagstr, "Uebergebener Wert ist falsch");
                break;

        case 0x0324:
                strcpy(diagstr, "Ende des Kanaldatenbereichs erreicht");
                break;

        case 0x0331:
                strcpy(diagstr, "Abschlusszeichen des Strings fehlt");
                break;

        case 0x0401:
                strcpy(diagstr, "Nicht genug Speicher mehr verfuegbar");
                break;

        case 0x0411:
                strcpy(diagstr, "Datenpuffer ist leer");
                break;

        case 0x0412:
                strcpy(diagstr, "Datenpuffer ist voll");
                break;

        case 0x0501:
                strcpy(diagstr, "Hardware-Konflikt (Unbekanntes Device)");
                break;

        case 0x0502:
                strcpy(diagstr, "Timeout-Fehler");
                break;

        case 0x0503:
                strcpy(diagstr, "Datenverlust");
                break;

        case 0x0504:
                strcpy(diagstr, "EEPROM-Wort nicht im erlaubten Wertebereich");
                break;

        case 0x0511:
                strcpy(diagstr, "Device ist nicht verfuegbar");
                break;

        case 0x0512:
                strcpy(diagstr, "Device ist bereits geoeffnet");
                break;

        case 0x0531:
                strcpy(diagstr, "Kanal nicht gefunden");
                break;

        case 0x0541:
                strcpy(diagstr, "Angegebener Infotext existiert nicht");
                break;

        case 0x0551:
                strcpy(diagstr, "Kein Caption-Puffer reserviert");
                break;

        case 0x0561:
                strcpy(diagstr, "CPS wird nicht unterstuetzt");
                break;

        case 0x0601:
                strcpy(diagstr, "Fehler beim Setzen der Echtzeituhr");
                break;

        case 0x0602:
                strcpy(diagstr, "Fehler beim Lesen der Echtzeituhr");
                break;

        case 0x0603:
                strcpy(diagstr, "Fehler beim Schreiben in das EEPROM");
                break;

        case 0x0604:
                strcpy(diagstr, "Fehler beim Lesen vom EEPROM");
                break;

        case 0xFFFF:
                strcpy(diagstr, "Diagnosewort ist ungueltig");
                break;

        default:
                strcpy(diagstr, "Diagnosewort ist unbekannt");
                break;
   }
}



//        END OF FILE
