/***********************************************************************
*  MDDDIAGE.C
*
*  PURPOSE
*                This file may be linked to a project with the SORCUS
*                library for MODULAR-4/486. It contains a procedure to
*                convert a diagnosis word provided by the function
*                mdd8_get_diagnosis into a string (english language).
*
*        AUTHORS
*                Dipl.-Ing. H.Doersam (HD)
*
*        COPYRIGHTS
*                SORCUS Computer GmbH Heidelberg (Germany) 1997
***********************************************************************/

/***********************************************************************
HISTORY

18/02/2000 (JD)
   -  New diagnosis code
      $0504 (invalid EEPROM-value)

18/03/98 (HD)
   -  New diagnosis codes
      0x0503 (data lost)
      0xFFFF (diagnosis invalid)

15/12/97 (HD)
   -        Creation of this file

***********************************************************************/



#include        "string.h"



/************************************************************************
*        mdd8_get_diagnosis_msg
*
*        PURPOSE
*        -        Converts a diagnosis message received from a MDD into a string
*        -        To receive the string reserve minimum 80 characters
*
*        PARAMETER
*        -        diagstr                        Points to a string object that receives the
*                                                        diagnosis message. The user should reserve
*                    a buffer of 256 characters to receive the error
*                    message.
*        -        code                                Diagnosis code (from mdd8_get_diagnosis)
*
*        RETURN
*        -        Nothing
*************************************************************************/
void mdd8_get_diagnosis_msg (char* diagstr, unsigned short code)
{
        //        If High-Byte = 0x01 then a parameter of an entried data
        //        structure is wrong. The offset of the wrong parameter
        //        is given in the Low-Byte.
        if ((code & 0xFF00) == 0x0100)
        {
                strcpy
                        (diagstr,
                        "Wrong parameter (offset = Low-Byte of diagnosis word)");
                return;
        }

   switch (code)
        {
        case 0x0000:
                strcpy(diagstr, "No error occured");
                break;

        case 0x0001:
                strcpy(diagstr, "Called without any effect");
                break;

        case 0x0201:
                strcpy(diagstr, "Wrong number of data inputs");
                break;

        case 0x0202:
                strcpy(diagstr, "Number of data inputs too high");
                break;

        case 0x0203:
                strcpy(diagstr, "Number of data inputs too low");
                break;

        case 0x0211:
                strcpy(diagstr, "Wrong number of data outputs");
                break;

        case 0x0212:
                strcpy(diagstr, "Number of data outputs too high");
                break;

        case 0x0213:
                strcpy(diagstr, "Number of data outputs too low");
                break;

        case 0x0221:
                strcpy(diagstr, "Driver service is locked");
                break;

        case 0x0321:
                strcpy(diagstr, "Range crossed over");
                break;

        case 0x0322:
                strcpy(diagstr, "Range crossed under");
                break;

        case 0x0323:
                strcpy(diagstr, "Data is not possible");
                break;

        case 0x0324:
                strcpy(diagstr, "Reached end of data area");
                break;

        case 0x0331:
                strcpy(diagstr, "Missing string termination");
                break;

        case 0x0401:
                strcpy(diagstr, "Not enough memory");
                break;

        case 0x0411:
                strcpy(diagstr, "Data buffer is empty");
                break;

        case 0x0412:
                strcpy(diagstr, "Data buffer is full");
                break;

        case 0x0501:
                strcpy(diagstr, "Hardware conflict (unknown device)");
                break;

        case 0x0502:
                strcpy(diagstr, "Timeout error");
                break;

        case 0x0503:
                strcpy(diagstr, "Data lost");
                break;

        case 0x0504:
                strcpy(diagstr, "EEPROM value out of range");
                break;

        case 0x0511:
                strcpy(diagstr, "Device not available");
                break;

        case 0x0512:
                strcpy(diagstr, "Device already in use");
                break;

        case 0x0531:
                strcpy(diagstr, "Channel not found");
                break;

        case 0x0541:
                strcpy(diagstr, "Specified infotext not available");
                break;

        case 0x0551:
                strcpy(diagstr, "No buffer for caption reserved");
                break;

        case 0x0561:
                strcpy(diagstr, "CPS is not supported");
                break;

        case 0x0601:
                strcpy(diagstr, "Error when setting the real time clock");
                break;

        case 0x0602:
                strcpy(diagstr, "Error when reading the real time clock");
                break;

        case 0x0603:
                strcpy(diagstr, "Error when writing to EEPROM");
                break;

        case 0x0604:
                strcpy(diagstr, "Error when reading from EEPROM");
                break;

        case 0xFFFF:
                strcpy(diagstr, "Diagnosis is invalid");
                break;

        default:
                strcpy(diagstr, "Diagnosis is unknown");
                break;
   }
}



//        END OF FILE
