/************************************************************************
*
*                      ML8ERRD.C/ML6ERRD.C/ML2ERRD.C
*
*          Modul zur Fehlerauswertung fuer SORCUS-Bibliotheken
*
*                    Version          : siehe Historie
*                    Erstellung       : 25.09.97
*                    letzte Aenderung : siehe Historie
*                    Autoren          : M.Haecker
*                                       H.Doersam
*
*     (c) SORCUS Computer GmbH Heidelberg 1995..1997
*************************************************************************/

/************************************************************************
*
*  Beschreibung:
*        Diese Datei kann zu einem Projekt mit einer SORCUS-Bibliothek
*        fuer MODULAR-4/486 oder Multi-LAB/2 gelinkt werden.
*        Sie enthaelt eine Funktion, die zu einem Fehler (Fehlerklasse
*        und Fehlercode) eine Zeichenkette liefert, die den Fehler
*        beschreibt.
*        Die Zeichenkette ist deutschsprachig. Fuer Anwendungen in
*        Englisch wird die Datei 'ML8ERRE.C' bzw. 'ML2ERRE.C' verwendet.
*
*************************************************************************/

/************************************************************************
*  Historie:
*     21/07/98 (JD)
*        -  Fehlerklasse 2, Fehlercode 80h hinzugefuegt
*		03/04/98 (HD)
*			-	Fehlerklasse 11, Fehlercode 1 hinzugefuegt
*			-	Fehlerklasse 2, Fehlercode 41 hinzugefuegt
*     09/02/98 (HD)
*        -	Fehlerklasse 5 erzeugte Warning, 
*				deshalb CASE-Abfrage entfernt
*     20/10/97 (HD)
*        -	Fehlerklasse 12 hinzugefuegt
*     25/09/97 (HD)
*        -	Fehlerklasse 11 hinzugefuegt
*     18/02/96 (MIH)
*        -	Fehlerklasse 2 ab Code 0x40 erweitert
*        -	Fehlerklasse 6 fuer ML2DEB zugefuegt
*        -	Fehlerklasse 4 zugefuegt
*        -	Fehlerklasse 7 zugefuegt
*     12/12/96 (MIH)
*        -	Neuen Fehlercode zugefuegt (0x0817)
*     28/07/96 (MIH)
*        -	Neue Fehlercodes zugefuegt
*     02/02/96 (MIH)
*        -	Fehlercodes 0x0140+ zugefuegt
*     24/01/96 (MIH)
*        -	Include von ML8BIB.H und 'EXPORT' weggenommen;
*        -	Anpassung fr Multi-LAB/2
*     18/12/95 (MIH)
*        -	System-Fehlercodes zugefuegt
*     1.A. 30.11.95 (MIH)
*************************************************************************/

#include "string.h"

/************************************************************************
*  ml8_get_error_msg:
*     liefert den zu einem Fehler (Klasse und Code) gehoerenden
*     String. Fuer Multi-LAB/2 wird in ML2BIB.H 'ml2_get_error_msg' auf
*     'ml8_get_error_msg' umgelenkt.
*
*     OUT errstr:     enthaelt die Fehlermeldung. Die max. Laenge
*                     der Fehlermeldung ist auf 256 Bytes festgelegt!
*     IN  errclass:   Fehlerklasse  
*     IN  code:       Fehlercode
*
*************************************************************************/
void ml8_get_error_msg
	(char *errstr, unsigned char errclass, unsigned char code)
{
   switch (errclass) {
      case 0x00:  /* Fehlerklasse 0 */
         switch (code) {
            case 0x00:
               strcpy(errstr, "kein Fehler");
               break;
            case 0x01:
               strcpy(errstr, "Fehler beim Schreiben zur Karte (TBF high)");
               break;
            case 0x02:
               strcpy(errstr, "Fehler beim Lesen von der Karte (RBF low)");
               break;
            case 0x03:
               strcpy(errstr, "Plausibilitaetsfehler in Anwort");
               break;
            case 0x04:
               strcpy(errstr, "DLP Timeout zu Beginn eines Makrobefehls");
               break;
            case 0x05:
               strcpy(errstr, "Unerwartetes Wort (RBF=1) zu Beginn eines Makros");
               break;
            case 0x06:
               strcpy(errstr, "DLM konnte nicht auf Null gesetzt werden");
               break;
            case 0x07:
               strcpy(errstr, "DLM konnte nicht auf Eins gesetzt werden");
               break;
            case 0x08:
               strcpy(errstr, "DLP konnte nicht auf Null gesetzt werden");
               break;
            case 0x09:
               strcpy(errstr, "DLP konnte nicht auf Eins gesetzt werden");
               break;
            case 0x0b:
               strcpy(errstr, "Resetfehler: Das Statusbit TBF geht nach Reset nicht auf 0");
               break;
            case 0x0e:
               strcpy(errstr, "Resetfehler: Das Statusbit TBF kann bei Reset nicht auf 1 gesetzt werden");
               break;
            case 0x0f:
               strcpy(errstr, "DLP ist gesetzt beim Empfangen von Zeichen");
               break;
            case 0x10:
               strcpy(errstr, "DLP ist gesetzt beim Senden von Zeichen");
               break;
            case 0x12:
               strcpy(errstr, "Karte reagiert nicht");
               break;
            case 0x13:
               strcpy(errstr, "RBF ist bei Interrupt nicht gesetzt");
               break;
            case 0x14:
               strcpy(errstr, "TBF ist bei Interrupt gesetzt");
               break;
            case 0x15:
               strcpy(errstr, "Fehler beim Senden des ersten Wortes eines Makrobefehls");
               break;
				case 0x16:
               strcpy(errstr, "Fehler bei serieller Kommunikation mit dem Target");
					break;
            default:
               strcpy(errstr, "Der Fehlercode ist in Klasse 0 nicht vorgesehen");
         }  
         break;   

      case 0x01:  /* Fehlerklasse 1 */
         switch (code) {
            case 0x00:
               strcpy(errstr, "kein Fehler");
               break;
            case 0x01:
               strcpy(errstr, "MINI Betriebssystem ist nicht aktiv");
               break;
            case 0x02:
               strcpy(errstr, "ROM Betriebssystem konnte nicht aktiviert werden");
               break;
            case 0x03:
               strcpy(errstr, "RAM Betriebssystemdatei nicht gefunden");
               break;
            case 0x04:
               strcpy(errstr, "RAM Betriebssystemdatei: Lesefehler");
               break;
            case 0x05:
               strcpy(errstr, "RAM Betriebssystemdatei: Fehler bim Oeffnen/Schliessen");
               break;
            case 0x06:
               strcpy(errstr, "RAM Betriebssystem konnte nicht aktiviert werden");
               break;
            case 0x11:
               strcpy(errstr, "Programmdatei nicht gefunden");
               break;
            case 0x12:
               strcpy(errstr, "Speicher-Reservierungsfehler auf der Karte");
               break;
            case 0x13:
               strcpy(errstr, "Zuwenig freier Speicher auf der Karte");
               break;
            case 0x14:
               strcpy(errstr, "Programmdatei Lesefehler");
               break;
            case 0x15:
               strcpy(errstr, "Programmdatei: Fehler beim Oeffnen/Schliessen");
               break;
            case 0x16:
               strcpy(errstr, "Falsche Linker-Signatur");
               break;
            case 0x17:
               strcpy(errstr, "Karte laesst sich nicht initialisieren");
               break;
            case 0x18:
               strcpy(errstr, "Debug-Tabelle konnte nicht eingerichtet werden");
               break;
            case 0x20:
               strcpy(errstr, "Kein Modul auf Steckplatz vorhanden");
               break;
            case 0x21:
               strcpy(errstr, "Modul braucht keine Initialisierung");
               break;
            case 0x22:
               strcpy(errstr, "Modul wurde nicht initialisiert wegen EEPROM-Konfiguration");
               break;
            case 0x23:
               strcpy(errstr, "Initialisierungsroutine ist nicht implementiert");
               break;
            case 0x40:
               strcpy(errstr, "Bootfehler: Adresse konnte nicht eingestellt werden");
               break;
            case 0x41:
               strcpy(errstr, "Bootfehler: Zugriffsmodus 'Wort' nicht moeglich");
               break;
            case 0x42:
               strcpy(errstr, "Bootfehler: Zugriffsmodus nicht wie erwartet");
               break;
            case 0x43:
               strcpy(errstr, "Bootfehler: unbekannter Fehler bei Zugriffsmodus");
               break;
            case 0x44:
               strcpy(errstr, "Bootfehler: Fehler beim Schreiben des OsX oder beim Starten");
               break;
            case 0x45:
               strcpy(errstr, "Bootfehler: Fehler beim Ruecksetzen des Befehlszeigers");
               break;
            default:
               strcpy(errstr, "Der Fehlercode ist in Klasse 1 nicht vorgesehen");
         }  
         break;   

      case 0x02:  /* Fehlerklasse 2 */
         switch (code) {
            case 0x00:
               strcpy(errstr, "kein Fehler");
               break;
            case 0x01:
               strcpy(errstr, "Die Kartennummer ist unzulaessig");
               break;
            case 0x02:
               strcpy(errstr, "Basisadresse nicht zulaessig");
               break;
            case 0x03:
               strcpy(errstr, "Betriebsart nicht zulaessig");
               break;
            case 0x04:
               strcpy(errstr, "PC-Interruptkanal nicht zulaessig");
               break;
            case 0x05:
               strcpy(errstr, "PC-DMA-Kanal nicht zulaessig");
               break;
            case 0x06:
               strcpy(errstr, "Die Bibliothek ist noch nicht initialisiert");
               break;
            case 0x07:
               strcpy(errstr, "Programmtyp und Installationsflag stimmen nicht ueberein");
               break;
            case 0x10:
               strcpy(errstr, "Unzulaessiger Parameter (Datum/Zeit)");
               break;
            case 0x11:
               strcpy(errstr, "Datenrueckgabelaenge ueberschreitet den vorgegebenen Wert");
               break;
            case 0x19:
               strcpy(errstr, "Parameternummer fuer EEPROM ungueltig");
               break;
            case 0x20:
               strcpy(errstr, "Vor dem Aufruf von ml8_init_bib muss ml8_bib_startup aufgerufen werden");
               break;
            case 0x21:
               strcpy(errstr, "Aufruf einer Multi-LAB/2-Bibliotheksfunktion fuer eine MODULAR-4/486-Karte");
               break;
            case 0x22:
               strcpy(errstr, "Aufruf einer MODULAR-4/486-Bibliotheksfunktion fuer eine Multi-LAB/2-Karte");
               break;
            case 0x23:
               strcpy(errstr, "Aufruf einer Funktion, die im Augenblick nicht unterstuetzt wird");
               break;
            case 0x24:
               strcpy(errstr, "Multi-LAB/2a unterstuetzt Funktion nicht");
               break;
            case 0x25:
               strcpy(errstr, "Multi-LAB/2d unterstuetzt Funktion nicht");
               break;
            case 0x26:
               strcpy(errstr, "Parameter #1 ist falsch");
               break;
            case 0x27:
               strcpy(errstr, "Parameter #2 ist falsch");
               break;
            case 0x28:
               strcpy(errstr, "Parameter #3 ist falsch");
               break;
				case 0x29:
					strcpy(errstr, "Keine Unterstuetzung von angewaehlter Karte");
					break;
            case 0x30:
               strcpy(errstr, "Maximale Makro-Kommandolaenge ueberschritten");
               break;
            case 0x31:
               strcpy(errstr, "Maximale Makro-Kommandorueckgabelaenge ueberschritten");
               break;
            case 0x32:
               strcpy(errstr, "Erwartete Funktions-Datenlaenge (Hin) ueberschritten");
               break;
            case 0x33:
               strcpy(errstr, "Erwartete Funktions-Datenlaenge (Rueckgabe) ueberschritten");
               break;
            case 0x36:
               strcpy(errstr, "Der angegebene Makrobefehl ist unbekannt");
               break;
            case 0x40:
               strcpy(errstr, "ml8_call_func: outsize unzulaessig");
               break;
            case 0x41:
               strcpy(errstr, "ml8_call_func: insize unzulaessig");
               break;
            case 0x42:
               strcpy(errstr, "ml8_call_func: Funktion der Task nicht vorhanden");
               break;
            case 0x43:
               strcpy(errstr, "ml8_call_func: DDT nicht angelegt");
               break;
            case 0x44:
               strcpy(errstr, "ml8_call_func: unbekannter Fehler");
               break;
            case 0x80:
               strcpy(errstr, "Achtung: Das Jahr 2080 wird als 80 zurueckgegeben");
               break;
            default:
               strcpy(errstr, "Der Fehlercode ist in Klasse 2 nicht vorgesehen");
         }
         break;  
      case 0x04:  /* Fehlerklasse 4 (Fehler bei Serviceroutine) */
         switch (code) {
            case 0x00:
               strcpy(errstr, "kein Fehler");
               break;
            case 0x01:
               strcpy(errstr, "Fehler beim Schreiben zur Karte (TBF high)");
               break;
            case 0x02:
               strcpy(errstr, "Fehler beim Lesen von der Karte (RBF low)");
               break;
            case 0x03:
               strcpy(errstr, "Plausibilitaetsfehler in Anwort");
               break;
            case 0x0E:
               strcpy(errstr, "Service Request ohne RBF");
               break;
            case 0x0F:
               strcpy(errstr, "Service Request ohne DLP");
               break;
            case 0x10:
               strcpy(errstr, "Rekursiver Aufruf der Service-Routine");
               break;
            case 0x11:
               strcpy(errstr, "Message Ueberlauf bei der Service-Routine");
               break;
            case 0x12:
               strcpy(errstr, "DLP konnte in der Service-Routine nicht zurueckgesetzt werden");
               break;
            default:
               strcpy(errstr, "Der Fehlercode ist in Klasse 4 nicht vorgesehen");
         }
         break;  
      case 0x05:  /* Fehlerklasse 5 (Fehler-Request) */
         strcpy(errstr, "Fehlercode ist ungueltig; bitte 'mlx_get_message' benutzen");
         break;  
      case 0x06:  /* Fehlerklasse 6 (Multi-LAB/2 Device-Bibliothek) */
         switch (code) {
            case 0x00:
               strcpy(errstr, "kein Fehler");
               break;
            case 0x01:
               strcpy(errstr, "Die Kartennummer ist unzulaessig");
               break;
            case 0x02:
               strcpy(errstr, "Adresskonflikt oder Karte defekt");
               break;
            case 0x03:
               strcpy(errstr, "Fehler beim Schreiben zur Karte (TBF high)");
               break;
            case 0x04:
               strcpy(errstr, "Fehler beim Lesen von der Karte (RBF low)");
               break;
            case 0x05:
               strcpy(errstr, "Device kann nicht geoeffnet werden");
               break;
            case 0x06:
               strcpy(errstr, "Bibliothek ist noch nicht initialisiert");
               break;
            case 0x07:
               strcpy(errstr, "Die Kanalnummer ist ungueltig");
               break;
            case 0x08:
               strcpy(errstr, "Multi-LAB/2a Karte besitzt keine massebezogenen Eingaenge");
               break;
            case 0x09:
               strcpy(errstr, "Nummer fuer Analogeingang ist ungueltig");
               break;
            case 0x0A:
               strcpy(errstr, "Nummer fuer Analogausgang ist ungueltig");
               break;
            case 0x0B:
               strcpy(errstr, "Nummer fuer digitalen Eingang ist ungueltig");
               break;
            case 0x0C:
               strcpy(errstr, "Nummer fuer digitalen Ausgang ist ungueltig");
               break;
            case 0x0D:
               strcpy(errstr, "Nummer fuer Differenzeingang ist ungueltig");
               break;
            case 0x0E:
               strcpy(errstr, "'ml2_get_data' kann auf den angegebenen Kanal nicht angewendet werden");
               break;
            case 0x0F:
               strcpy(errstr, "'ml2_set_data' kann auf den angegebenen Kanal nicht angewendet werden");
               break;
            case 0x12:
               strcpy(errstr, "Der angegebene Spannungsbereich kann nicht eingestellt werden");
               break;
            case 0x13:
               strcpy(errstr, "Multi-LAB/2d: Fuer Differenzeingaenge ist nur der Bereich +/-10V moeglich");
               break;
            case 0x14:
               strcpy(errstr, "Multi-LAB/2a: Fuer Differenzeingaenge ist nur der Bereich +/-5V moeglich");
               break;
            case 0x15:
               strcpy(errstr, "Multi-LAB/2d: Fuer massebezogene Eingaenge ist nur der Bereich +/-10V moeglich");
               break;
            case 0x16:
               strcpy(errstr, "Multi-LAB/2a: Fuer die analogen Ausgaenge ist nur der Bereich +/-5V moeglich");
               break;
            case 0x17:
               strcpy(errstr, "Multi-LAB/2d: Fuer die analogen Ausgaenge ist nur der Bereich +/-10V moeglich");
               break;
            case 0x18:
               strcpy(errstr, "Unbekannte Versionsnummer");
               break;
            case 0x19:
               strcpy(errstr, "Das angegebene Maskierungsflag kann nicht verwendet werden");
               break;
            case 0x1A:
               strcpy(errstr, "'ml2_get_device_state' kann auf den angegebenen Kanal nicht angewendet werden");
               break;
            case 0x1B:
               strcpy(errstr, "Bei einer Messung mit 'Autowait' trat ein Timeout auf");
               break;
            case 0x1C:
               strcpy(errstr, "Timer B ist uebergelaufen");
               break;
            case 0x1D:
               strcpy(errstr, "Die Hardware ist bereits durch einen anderen Kanal belegt");
               break;
            case 0x1E:
               strcpy(errstr, "Es liegt noch kein gueltiges Messergebnis vor");
               break;
            case 0x1F:
               strcpy(errstr, "Die Hardware fuer den Kanal wurde noch nicht reserviert");
               break;
            case 0x20:
               strcpy(errstr, "Ungueltiges Handle");
               break;
            default:
               strcpy(errstr, "Der Fehlercode ist in Klasse 6 nicht vorgesehen");
         }
         break;  
      case 0x07:  /* Fehlerklasse 7 (nur Win32) */
         switch (code) {
            case 0x00:
               strcpy(errstr, "kein Fehler");
               break;
            case 0x01:
               strcpy(errstr, "Systemfehler ist aufgetreten. Code von 'GetLastError()' in <Struct>.System.error");
               break;
            case 0x02:
               strcpy(errstr, "Fehler im Treiber");
               break;
            default:
               strcpy(errstr, "Der Fehlercode ist in Klasse 7 nicht vorgesehen");
         }
         break;  
      case 0x08:  /* Fehlerklasse 8 : System- oder Treiberfehler */
         switch (code) {
            case 0x00:
               strcpy(errstr, "kein Fehler");
               break;
            case 0x01:
               strcpy(errstr, "Treiber konnte nicht geoeffnet werden");
               break;
            case 0x02:
               strcpy(errstr, "Rueckgabelaenge des Treibers falsch");
               break;
            case 0x03:
               strcpy(errstr, "SRQ-Thread konnte nicht aktiviert werden");
               break;
            case 0x04:
               strcpy(errstr, "SRQ-Event konnte nicht aktiviert werden");
               break;
            case 0x05:
               strcpy(errstr, "SRQ-Hold-Request konnte nicht installiert werden");
               break;
            case 0x06:
               strcpy(errstr, "SRQ-Thread: Prioritaet nicht erhoehbar");
               break;
            case 0x07:
               strcpy(errstr, "User-Service-Thread konnte nicht aktiviert werden");
               break;
            case 0x08:
               strcpy(errstr, "SRQ-Synchronisation: Ereignis konnte nicht geoeffnet werden");
               break;
            case 0x09:
               strcpy(errstr, "SRQ-Synchronisation: Ereignis konnte nicht gesetzt werden");
               break;
            case 0x0A:
               strcpy(errstr, "SRQ-Synchronisation: Ereignis konnte nicht zurueckgesetzt werden");
               break;
            case 0x0B:
               strcpy(errstr, "Prozessspeicher im Treiber konnte nicht angelegt werden");
               break;
            case 0x0C:
               strcpy(errstr, "Prozessspeicher im Treiber konnte nicht freigegeben werden");
               break;
            case 0x0D:
               strcpy(errstr, "Prozess konnte nicht mit dem Treiber verbunden werden");
               break;
            case 0x0E:
               strcpy(errstr, "SRQ-Thread konnte nicht angehalten werden");
               break;
            case 0x10:
               strcpy(errstr, "Falscher Parameter beim Lesen/Schreiben im Treiber"); 
					break;
            case 0x11:
               strcpy(errstr, "Falscher Parameter beim Lesen im Treiber");
               break;
            case 0x12:
               strcpy(errstr, "Falscher Parameter beim Schreiben im Treiber");
               break;
            case 0x13:
               strcpy(errstr, "Parameter kann nicht geschrieben werden");
               break;
            case 0x14:
               strcpy(errstr, "Parametertyp wurde falsch angegeben");
               break;
            case 0x15:
               strcpy(errstr, "Prozess-ID ist nicht gueltig");
               break;
            case 0x16:
               strcpy(errstr, "Protokollpuffer kann nicht gelesen werden");
               break;
            case 0x17:
               strcpy(errstr, "Kartennummer ungueltig oder Karte nicht installiert");
               break;
				case 0x18:
					strcpy(errstr, "Unerwarteter Service-Request");
					break;
				case 0x19:
					strcpy(errstr, "Karte kann nicht exklusiv genutzt werden");
					break;
				case 0x1A:
					strcpy(errstr, "Zugriff auf die Karte gesperrt");
					break;
				case 0x1B:
					strcpy(errstr, "Schnittstelle konnte nicht bereinigt werden");
					break;
				case 0x1C:
					strcpy(errstr, "Zugriff auf IO-Port verweigert");
					break;
				case 0x1D:
					strcpy(errstr, "Service-Request abgebrochen");
					break;
           case 0xFF:
               strcpy(errstr, "Allgemeiner Treiberfehler");
               break;
            default:
               strcpy(errstr, "Der Fehlercode ist in Klasse 8 nicht vorgesehen");
         }
         break;  
      case 0x0B:  /* Fehlerklasse 11 : MDD-Fehler */
         switch (code) {
            case 0x00:
               strcpy(errstr, "Kein Fehler");
               break;
				case 0x01:
					strcpy(errstr, "Neuere OsX Version erforderlich");
					break;
            case 0x40:
               strcpy(errstr, "Handle ungueltig");
               break;
            case 0x41:
               strcpy(errstr, "Verwendeter Datentyp falsch");
               break;
            case 0x42:
               strcpy(errstr, "Fehler in MDD-Dienst (Diagnose moeglich)");
               break;
            case 0x43:
               strcpy(errstr, "Fehler in Kanal-Dienst (Diagnose moeglich)");
               break;
            case 0x44:
               strcpy(errstr, "Dienst nicht verfuegbar");
               break;
            case 0x45:
               strcpy(errstr, "MDD nicht installiert");
               break;
            case 0x47:
                strcpy(errstr, "MDD nicht gestartet (Diagnose moeglich)");
                break;
            default:
               strcpy(errstr, "Der Fehlercode ist unbekannt");
         }
         break;  
      case 0x0C:  /* Fehlerklasse 12 : Fehler bei Flash-Programmierung */
         switch (code) {
            case 0x00:
               strcpy(errstr, "Kein Fehler");
               break;
            case 0x84:
               strcpy(errstr, "Soft-State falsch oder anderer Befehl noch nicht beendet");
               break;
            case 0x85:
               strcpy(errstr, "Eingesetztes Flash-Eprom wird nicht unterstuetzt");
               break;
            case 0x86:
               strcpy(errstr, "Dienst falsch");
               break;
            case 0x87:
               strcpy(errstr, "Kein Flash-Eprom (lt. EEPROM)");
               break;
            case 0x88:
               strcpy(errstr, "Steckplatz oder IC-Nr. falsch");
               break;
            case 0x89:
               strcpy(errstr, "Parameter nicht aligned");
               break;
            case 0x8A:
               strcpy(errstr, "Adresse falsch");
               break;
            case 0x8B:
               strcpy(errstr, "Flash-Eprom nicht geloescht");
               break;
            case 0x8C:
               strcpy(errstr, "Flash-Eprom nicht programmierbar/loeschbar (Timeout)");
               break;
            default:
               strcpy(errstr, "Der Fehlercode ist unbekannt");
         }
         break;  
      default:
         strcpy(errstr, "Fehlerklasse nicht vorgesehen");
   }
}
