/************************************************************************
*
*                   ML8ERRE.C/ML6ERRE.C/ML2ERRE.C
*
*          module for error decoding
*
*                    version          : see history
*                    creation         : 25.09.97
*                    last change      : see history
*                    authors          : M.Haecker
*                                       H.Doersam
*
*     (c) SORCUS Computer GmbH Heidelberg 1995..1997
*************************************************************************/

/************************************************************************
*
*  description:
*        This file may be linked to a project with the SORCUS library
*        for MODULAR-4/486 or Multi-LAB/2.
*        It contains a procedure to convert an error class and error code
*        provided by the library into a string.
*
*************************************************************************/

/************************************************************************
*  History:
*     21/07/98 (JD)
*        -  Error class 2, error code 80h added
*		03/04/98 (HD)
*			-	Error class 11, error code 1 added
*			-	Error class 2, error code 41 added
*     09/02/98 (HD)
*        -	Error class 5 forced a warning, switch construction removed
*     20/10/97 (HD)
*        -	Error class 12 added
*     25/09/97 (HD)
*        -	Error class 11 added
*     18/02/96 (MIH)
*        -	Error class 2 code 0x40+ added
*        -	Error class 6 for ML2DEB added
*        -	Error class 4 added
*        -	Error class 7 added
*     30/1096 (MIH)
*        -	Porting to English
*************************************************************************/

#include "string.h"

/************************************************************************
*  ml8_get_error_msg:
*     This procedure converts an error class and error code provided by the 
*     SORCUS library into a string.
*
*     OUT errstr:     contains the error string. The user should reserve
*                     a buffer of 256 characters to receive the error 
*                     message.
*     IN  errclass:   error class
*     IN  code:       error code
*
*************************************************************************/
void ml8_get_error_msg
	(char *errstr, unsigned char errclass, unsigned char code)
{
   switch (errclass) {
   /****************  error class 0  ********************/
      case 0x00:  
         switch (code) {
            case 0x00:
               strcpy(errstr, "No error");
               break;
            case 0x01:
               strcpy(errstr, "TBF error: TBF did not become low while trying to send");
               break;
            case 0x02:
               strcpy(errstr, "RBF error: RBF did not become high while trying to receive");
               break;
            case 0x03:
               strcpy(errstr, "Plausibility checking failed");
               break;
            case 0x04:
               strcpy(errstr, "DLP timeout at the beginning of a macro command");
               break;
            case 0x05:
               strcpy(errstr, "RBF error: RBF was high at the beginning of a macro command");
               break;
            case 0x06:
               strcpy(errstr, "DLM could not be set low");
               break;
            case 0x07:
               strcpy(errstr, "DLM could not be set high");
               break;
            case 0x08:
               strcpy(errstr, "DLP could not be set low");
               break;
            case 0x09:
               strcpy(errstr, "DLP could not be set high");
               break;
            case 0x0b:
               strcpy(errstr, "Reset error: TBF stayed high after a hard-reset");
               break;
            case 0x0e:
               strcpy(errstr, "Reset error: TBF stayed low after a hard-reset");
               break;
            case 0x0f:
               strcpy(errstr, "DLP was high while trying to receive");
               break;
            case 0x10:
               strcpy(errstr, "DLP was high while trying to send");
               break;
            case 0x12:
               strcpy(errstr, "Board does not react");
               break;
            case 0x13:
               strcpy(errstr, "RBF was not high when a hardware interrupt occured");
               break;
            case 0x14:
               strcpy(errstr, "TBF was high when a hardware interrupt occured");
               break;
            case 0x15:
               strcpy(errstr, "Error when sending the first word of a macro command");
               break;
				case 0x16:
               strcpy(errstr, "Serial communication error");
					break;
            default:
               strcpy(errstr, "The error code is unknown");
         }  
         break;   

   /****************  error class 1  ********************/
      case 0x01:  
         switch (code) {
            case 0x00:
               strcpy(errstr, "No error");
               break;
            case 0x01:
               strcpy(errstr, "MINI operating system is not active");
               break;
            case 0x02:
               strcpy(errstr, "ROM operating system could not be activated");
               break;
            case 0x03:
               strcpy(errstr, "RAM operating system file not found");
               break;
            case 0x04:
               strcpy(errstr, "RAM operating system file: reading error");
               break;
            case 0x05:
               strcpy(errstr, "RAM operating system file: error during opening/closing");
               break;
            case 0x06:
               strcpy(errstr, "RAM operating system could not be activated");
               break;
            case 0x11:
               strcpy(errstr, "Program file not found");
               break;
            case 0x12:
               strcpy(errstr, "Memory allocation error on the board");
               break;
            case 0x13:
               strcpy(errstr, "Not enough memory on the board");
               break;
            case 0x14:
               strcpy(errstr, "Program file: reading error");
               break;
            case 0x15:
               strcpy(errstr, "Program file: error during opening/closing");
               break;
            case 0x16:
               strcpy(errstr, "Wrong linker signature");
               break;
            case 0x17:
               strcpy(errstr, "Board cannot be initialized");
               break;
            case 0x18:
               strcpy(errstr, "Debug table cannot be created");
               break;
            case 0x20:
               strcpy(errstr, "No module found");
               break;
            case 0x21:
               strcpy(errstr, "Module does not need any initialization");
               break;
            case 0x22:
               strcpy(errstr, "Module was not initialized because of the EEPROM configuration");
               break;
            case 0x23:
               strcpy(errstr, "Initialization routine is not implemented");
               break;
            case 0x40:
               strcpy(errstr, "Boot error: address cannot be set");
               break;
            case 0x41:
               strcpy(errstr, "Boot error: access mode 'WORD' is not possible");
               break;
            case 0x42:
               strcpy(errstr, "Boot error: wrong access mode");
               break;
            case 0x43:
               strcpy(errstr, "Boot error: unknown error in access mode");
               break;
            case 0x44:
               strcpy(errstr, "Boot error: error when writing/starting the OsX");
               break;
            case 0x45:
               strcpy(errstr, "Boot error: error when resetting the instruction pointer");
               break;
            default:
               strcpy(errstr, "The errorcode is unknown");
         }  
         break;   

   /****************  error class 2  ********************/
      case 0x02:  
         switch (code) {
            case 0x00:
               strcpy(errstr, "No error");
               break;
            case 0x01:
               strcpy(errstr, "Card number is invalid");
               break;
            case 0x02:
               strcpy(errstr, "Base address is invalid");
               break;
            case 0x03:
               strcpy(errstr, "Operating mode is invalid");
               break;
            case 0x04:
               strcpy(errstr, "Interrupt channel is invalid");
               break;
            case 0x05:
               strcpy(errstr, "DMA Channel is invalid");
               break;
            case 0x06:
               strcpy(errstr, "The library has not been initialized");
               break;
            case 0x07:
               strcpy(errstr, "Program type and installation flags do not agree");
               break;
            case 0x10:
               strcpy(errstr, "Invalid parameter (date/time)");
               break;
            case 0x11:
               strcpy(errstr, "Data return length is greater than allowed");
               break;
            case 0x19:
               strcpy(errstr, "Parameter number for EEPROM is invalid");
               break;
            case 0x20:
               strcpy(errstr, "A library function was called before calling 'mlx_bib_startup'");
               break;
            case 0x21:
               strcpy(errstr, "Call of a MODULAR-4 function for a Multi-LAB/2 board");
               break;
            case 0x22:
               strcpy(errstr, "Call of a Multi-LAB/2 function for a MODULAR-4 board");
               break;
            case 0x23:
               strcpy(errstr, "Call of a function that is not implemented");
               break;
            case 0x24:
               strcpy(errstr, "Call of a function that is not supported by Multi-LAB/2a");
               break;
            case 0x25:
               strcpy(errstr, "Call of a function that is not supported by Multi-LAB/2d");
               break;
            case 0x26:
               strcpy(errstr, "Parameter #1 is wrong");
               break;
            case 0x27:
               strcpy(errstr, "Parameter #2 is wrong");
               break;
            case 0x28:
               strcpy(errstr, "Parameter #3 is wrong");
               break;
				case 0x29:
					strcpy(errstr, "No support by selected card");
					break;
            case 0x30:
               strcpy(errstr, "Maximum macro command length has exceeded");
               break;
            case 0x31:
               strcpy(errstr, "Maximum macro command return length has exceeded");
               break;
            case 0x32:
               strcpy(errstr, "Data length has been exceeded (send)");
               break;
            case 0x33:
               strcpy(errstr, "Data length has been exceeded (receive)");
               break;
            case 0x36:
               strcpy(errstr, "Macro command is unknown");
               break;
            case 0x40:
               strcpy(errstr, "'mlx_call_func': 'outsize' is invalid");
               break;
            case 0x41:
               strcpy(errstr, "'mlx_call_func': 'insize' is invalid");
               break;
            case 0x42:
               strcpy(errstr, "'mlx_call_func': function of a task does not exist");
               break;
            case 0x43:
               strcpy(errstr, "'mlx_call_func': DDT not created");
               break;
            case 0x44:
               strcpy(errstr, "'mlx_call_func': unknown error");
               break;
            case 0x80:
               strcpy(errstr, "Attention: The year 2080 will be returned as 80");
               break;
            default:
               strcpy(errstr, "The error code is unknown");
         }
         break; 
      case 0x04:  /* error class 4 (error in service routine) */
         switch (code) {
            case 0x00:
               strcpy(errstr, "No error");
               break;
            case 0x01:
               strcpy(errstr, "TBF error: TBF did not become low while trying to send");
               break;
            case 0x02:
               strcpy(errstr, "RBF error: RBF did not become high while trying to receive");
               break;
            case 0x03:
               strcpy(errstr, "Plausibility checking failed");
               break;
            case 0x0E:
               strcpy(errstr, "Service request without RBF");
               break;
            case 0x0F:
               strcpy(errstr, "Service request without DLP");
               break;
            case 0x10:
               strcpy(errstr, "Recursive call of the service routine");
               break;
            case 0x11:
               strcpy(errstr, "Message overflow in the service routine");
               break;
            case 0x12:
               strcpy(errstr, "No DLP reset in service routine");
               break;
            default:
               strcpy(errstr, "The error code is unknown");
         }
         break;  
      case 0x05:  /* error class 5 (error request) */
         strcpy(errstr, "The error code is invalid; please use 'mlx_get_message'");
         break;  
      case 0x06:  /* error class 6 (Multi-LAB/2 device library) */
         switch (code) {
            case 0x00:
               strcpy(errstr, "No error");
               break;
            case 0x01:
               strcpy(errstr, "The card number is invalid");
               break;
            case 0x02:
               strcpy(errstr, "Address conflict or defective board");
               break;
            case 0x03:
               strcpy(errstr, "TBF error: TBF did not become low while trying to send");
               break;
            case 0x04:
               strcpy(errstr, "RBF error: RBF did not become high while trying to receive");
               break;
            case 0x05:
               strcpy(errstr, "Device can not be generated");
               break;
            case 0x06:
               strcpy(errstr, "The library has not been initialized");
               break;
            case 0x07:
               strcpy(errstr, "The channel number is invalid");
               break;
            case 0x08:
               strcpy(errstr, "Multi-LAB/2a board does not have single-ended inputs");
               break;
            case 0x09:
               strcpy(errstr, "An incorrect analog input channel number was specified");
               break;
            case 0x0A:
               strcpy(errstr, "An incorrect analog output channel number was specified");
               break;
            case 0x0B:
               strcpy(errstr, "An incorrect number was specified for a digital input");
               break;
            case 0x0C:
               strcpy(errstr, "An incorrect number was specified for a digital output");
               break;
            case 0x0D:
               strcpy(errstr, "An incorrect number was specified for a differential input");
               break;
            case 0x0E:
               strcpy(errstr, "'ml2_get_data' cannot be used for the specified channel");
               break;
            case 0x0F:
               strcpy(errstr, "'ml2_set_data' cannot be used for the specified channel");
               break;
            case 0x12:
               strcpy(errstr, "The specified voltage range cannot be set");
               break;
            case 0x13:
               strcpy(errstr, "Multi-LAB/2d: The range for differential inputs must be +/-10V");
               break;
            case 0x14:
               strcpy(errstr, "Multi-LAB/2a: The range for differential inputs must be +/-5V");
               break;
            case 0x15:
               strcpy(errstr, "Multi-LAB/2d: The range for single-ended inputs must be +/-10V");
               break;
            case 0x16:
               strcpy(errstr, "Multi-LAB/2a: The range for analog outputs must be +/-5V");
               break;
            case 0x17:
               strcpy(errstr, "Multi-LAB/2d: The range for analog outputs must be +/-10V");
               break;
            case 0x18:
               strcpy(errstr, "Unknown version number");
               break;
            case 0x19:
               strcpy(errstr, "The specified mask flag cannot be used");
               break;
            case 0x1A:
               strcpy(errstr, "'ml2_get_device_state' cannot be used for the specified channel");
               break;
            case 0x1B:
               strcpy(errstr, "A timeout occured while measurement with 'autowait'");
               break;
            case 0x1C:
               strcpy(errstr, "Timer B overflow");
               break;
            case 0x1D:
               strcpy(errstr, "The hardware is used by another channel");
               break;
            case 0x1E:
               strcpy(errstr, "No valid measurement result is ready yet");
               break;
            case 0x1F:
               strcpy(errstr, "The hardware for the channel has not been reserved yet");
               break;
            case 0x20:
               strcpy(errstr, "Handle is invalid");
               break;
            default:
               strcpy(errstr, "The error code is unknown");
         }
         break;  
      case 0x07:  /* error class 7 (only Win32) */
         switch (code) {
            case 0x00:
               strcpy(errstr, "No error");
               break;
            case 0x01:
               strcpy(errstr, "System error occured. The code of 'GetLastError()' is in <Struct>.System.error");
               break;
            case 0x02:
               strcpy(errstr, "Error in driver");
               break;
            default:
               strcpy(errstr, "The error code is unknown");
         }
         break;  
      case 0x08:  /* error class 8 : system- or driver error */
         switch (code) {
            case 0x01:
               strcpy(errstr, "Driver could not be opened");
               break;
            case 0x02:
               strcpy(errstr, "Wrong return length");
               break;
            case 0x03:
               strcpy(errstr, "SRQ thread could not be created");
               break;
            case 0x04:
               strcpy(errstr, "SRQ event could not be activated");
               break;
            case 0x05:
               strcpy(errstr, "SRQ hold request could not be installed");
               break;
            case 0x06:
               strcpy(errstr, "SRQ thread: priority could not be increased");
               break;
            case 0x07:
               strcpy(errstr, "User service thread could not be activated");
               break;
            case 0x08:
               strcpy(errstr, "SRQ synchronisation: event could not be opened");
               break;
            case 0x09:
               strcpy(errstr, "SRQ synchronisation: event could not be set");
               break;
            case 0x0A:
               strcpy(errstr, "SRQ synchronisation: event could not be reset");
               break;
            case 0x0B:
               strcpy(errstr, "Process buffer could not be allocated");
               break;
            case 0x0C:
               strcpy(errstr, "Process buffer could not be freed");
               break;
            case 0x0D:
               strcpy(errstr, "Process could not be connected");
               break;
            case 0x0E:
               strcpy(errstr, "SRQ thread could not be stopped");
               break;
            case 0x10:
               strcpy(errstr, "Wrong parameter when reading/writing");
               break;
            case 0x11:
               strcpy(errstr, "Wrong parameter when reading");
               break;
            case 0x12:
               strcpy(errstr, "Wrong parameter when writing");
               break;
            case 0x13:
               strcpy(errstr, "Parameter could not be written");
               break;
            case 0x14:
               strcpy(errstr, "Parameter type is wrong");
               break;
            case 0x15:
               strcpy(errstr, "Process ID is invalid");
               break;
            case 0x16:
               strcpy(errstr, "Protocol buffer could not be read");
               break;
            case 0x17:
               strcpy(errstr, "Card number is invalid or card is not installed");
               break;
				case 0x18:
					strcpy(errstr, "Unexpected service request");
					break;
				case 0x19:
					strcpy(errstr, "Exclusive access denied");
					break;
				case 0x1A:
					strcpy(errstr, "Card locked - access denied");
					break;
				case 0x1B:
					strcpy(errstr, "Interface could not be cleared");
					break;
				case 0x1C:
					strcpy(errstr, "Access to IO port denied");
					break;
				case 0x1D:
					strcpy(errstr, "Service request cancelled");
					break;
            case 0xFF:
               strcpy(errstr, "General driver failure");
               break;
            default:
               strcpy(errstr, "The error code is unknown");
         }
         break; 
      case 0x0B:  /* Error Class 11 : MDD Errors */
         switch (code) {
            case 0x00:
               strcpy(errstr, "No Error");
               break;
				case 0x01:
					strcpy(errstr, "Newer OsX version necessary");
					break;
            case 0x40:
               strcpy(errstr, "Handle invalid");
               break;
            case 0x41:
               strcpy(errstr, "Used Data Type is wrong");
               break;
            case 0x42:
               strcpy(errstr, "Error in MDD Service (Diagnosis possible)");
               break;
            case 0x43:
               strcpy(errstr, "Error in Channel Service (Diagnosis possible)");
               break;
            case 0x44:
               strcpy(errstr, "Service not available");
               break;
            case 0x45:
               strcpy(errstr, "MDD not installed");
               break;
            case 0x47:
                strcpy(errstr, "MDD not started (Diagnosis possible)");
                break;
            default:
               strcpy(errstr, "The Error Code is unknown");
         }
         break;  
      case 0x0C:  /* Error Class 12 : Flash Programming Errors */
         switch (code) {
            case 0x00:
               strcpy(errstr, "No Error");
               break;
            case 0x84:
               strcpy(errstr, "Soft-State wrong or another Command is not finished yet");
               break;
            case 0x85:
               strcpy(errstr, "Used Flash-Eprom is not supported");
               break;
            case 0x86:
               strcpy(errstr, "Service is wrong");
               break;
            case 0x87:
               strcpy(errstr, "No Flash-Eprom (cause EEPROM)");
               break;
            case 0x88:
               strcpy(errstr, "Slot or IC Number is wrong");
               break;
            case 0x89:
               strcpy(errstr, "Parameter is not aligned");
               break;
            case 0x8A:
               strcpy(errstr, "Address is wrong");
               break;
            case 0x8B:
               strcpy(errstr, "Flash-Eprom is not erased");
               break;
            case 0x8C:
               strcpy(errstr, "Flash-Eprom is not programmable/eraseable (Timeout)");
               break;
            default:
               strcpy(errstr, "The Error Code is unknown");
         }
         break;  
      default:
         strcpy(errstr, "Error class is unknown");
   }
}
