/********************************************************************
*	MLXDEF.H
*
*	This header files consists some constants for the 
*	SORCUS libraries used on following platforms:
*
*	Operating System:		DOS
*                       Windows 3.x
*                       Windows 95
*								Windows NT
*
*	SORCUS Boards:			ML8 - MODULAR-4/486
*								ML6 - Multi-COM
*								ML2 - Multi-LAB/2
*								
*
*  Author:					Dipl.-Ing. H.Doersam
*
*  Copyrights:				SORCUS Computer GmbH 1995 .. 1998
*								All Rights Reserved
********************************************************************/


#ifndef _INC_MLXDEF

#define _INC_MLXDEF




// Maximum number of supported cards

#define NUMBEROFCARDS         8



// The different card types

#define NO_ML_CARD            0x0000      // No SORCUS card
#define ML2_CARD              0x0002      // Multi-LAB/2
#define ML6_CARD              0x0006      // Multi-COM
#define ML7_CARD              0x0007      // 'Little' MODULAR-4/486
#define ML8_CARD              0x0008      // MODULAR-4/486
#define ML10_CARD             0x000A      // Reserved



// Flags for card types

#define _ML2_CARD             0x0001
#define _ML8_CARD             0x0002
#define _ML6_CARD             0x0004
#define _ML7_CARD             0x0008



// Booleans

#define TRUE      1
#define FALSE     0



// Programming language (constants ofr mlx_bib_startup)

#define LANGUAGE_C            0x200       // Program written in C
#define LANGUAGE_PASCAL       0x100       // Program written in Pascal



//	Version status

#define FREE_RELEASE          'F'         
#define BETA_VERSION          'B'
#define EPROM_OSX             'E'
#define RAM_OSX               'R'



//	Day of week

#define SUNDAY                0
#define MONDAY                1
#define TUESDAY               2
#define WEDNESDAY             3
#define THURSDAY              4
#define FRIDAY                5
#define SATURDAY              6




// In Windows 95 and Windows NT there are different types 
// of errors: 
//
// ERROR_COMMUNICATION: 
//    the status port of the board was not in the
//    expected state; the communication protocol
//    failed
// ERROR_DRIVER:        
//    the length of data expected to be delivered by
//    driver is not equal to the delivered ones
// ERROR_SYSTEM:        
//    a system error occured on calling the driver;
//    the number in 'syserror' is the value of
//    the Windows NT system error message
// ERROR_DLL:           
//    an error in the DLL occured    

#define ERROR_COMMUNICATION   0x01
#define ERROR_DRIVER          0x02
#define ERROR_SYSTEM          0x04
#define ERROR_DLL             0x08



// Status port

#define TBF                   0x01     // Bit 0 in status byte
#define DLM                   0x02     // Bit 1 in status byte
#define DLP                   0x40     // Bit 6 in status byte
#define RBF                   0x80     // Bit 7 in status byte




// operatin systems

#define MLXWIN95              VER_PLATFORM_WIN32_WINDOWS
#define MLXWINNT              VER_PLATFORM_WIN32_NT
#define MLXWINWDM             MLXWINNT + 1
#define MLXWINNT_EX           MLXWINNT + 2



// Flash programming

#define FLASH_GET_CUSTOMER_ID          0x00
#define FLASH_GET_DEVICE_ID            0x01
#define FLASH_GET_SIZE_INFO            0x02
#define FLASH_GET_ORGANIZATION         0x03
#define FLASH_CHECK_WRITE_PROTECTED    0x04
#define FLASH_GET_ERASE_STATUS         0x05
#define FLASH_COPY_EPROM               0x06
#define FLASH_GET_SOFT_STATE           0x0A
#define FLASH_ERASE_ENABLE             0x0B
#define FLASH_ERASE_DISABLE            0x0C
#define FLASH_PROGRAM_ENABLE           0x0D
#define FLASH_PROGRAM_DISABLE          0x0E




// strategies used by buffer operations 
// (ml8_get_buffer, ml8_set_buffer)

#define BUFFER_ALL_OR_NOTHING    0  // all or nothing
#define BUFFER_MAXIMUM           1  // as much as possible
#define BUFFER_COPY              2  // view buffer, data stays in buffer
#define BUFFER_TRY_MULTIPLE      4  // try until data are available



// strategies for mlx_allocate_ram 

#define ALLOC_GET_SIZE           0  // Check size of free RAM
#define ALLOC_UP_ABS             1  // BOTTOM UP, all or nothing
#define ALLOC_UP_MAX             2  // BOTTOM UP, as much as possible
#define ALLOC_DOWN_ABS           3  // TOP DOWN, all or nothing
#define ALLOC_DOWN_MAX           4  // TOP DOWN, as much as possible



// Constants for the error record

#define MAX_ERR_OUT_CMD          6
#define MAX_ERR_IN_CMD           6
#define MAX_ERR_OUT_DATA         6
#define MAX_ERR_IN_DATA          6

#define STATUSMAP_OLD_ERROR_SEND       1<<0
#define STATUSMAP_OLD_ERROR_RECEIVE    1<<1
#define STATUSMAP_ERROR_REQUEST        1<<6
#define STATUSMAP_LIB_NOT_INITIALIZED  1<<7



// Flags for logging macrowords

#define LOG_CONTROLLED     1<<0
#define LOG_NO_LOG         1<<4
#define LOG_ALL            1<<5
#define LOG_COMMAND        1<<8
#define LOG_PARAMETER      1<<9
#define LOG_DATA           1<<10
#define LOG_TIME           1<<12
#define LOG_COUNTER        1<<13
#define LOG_IRQ	         1<<14



// Types of macrowords

#define MACRO_SEND         1<<0
#define MACRO_RECEIVE      1<<1
#define MACRO_ERROR        1<<2
#define MACRO_COMMAND      1<<4
#define MACRO_PARAMETER    1<<5
#define MACRO_DATA         1<<6
#define MACRO_IRQ          1<<7



// Defines for mlX_watch_error

#define WATCH_ERR_STATUS            0
#define WATCH_ERR_CLASS             1
#define WATCH_ERR_CODE              2
#define WATCH_ERR_STATUS_PORT       3
#define WATCH_ERR_STATUS_MAP        4
#define WATCH_ERR_SYSTEM            5
#define WATCH_ERR_DRV_OUT_SIZE      6
#define WATCH_ERR_DRV_IN_SIZE       7





#endif // !_INC_MLXDEF



