/********************************************************************
*  MLXW32_P.H
*
*  This header files declares the prototypes of the SORCUS libraries
*  for following platforms:
*
*  Operating System:    Windows 95
*                       Windows NT
*
*  SORCUS Boards:       ML8 - long MODULAR-4/486
*                       ML7 - small MODULAR-4/486
*                       ML6 - Multi-COM
*                       ML2 - Multi-LAB/2
*
*
*  Authors:             Dipl.-Ing. H.Doersam
*                       Dipl-Ing. M.Haecker
*
*  Copyrights:          SORCUS Computer GmbH 1995 .. 1998
*                       All Rights Reserved
********************************************************************/




#ifndef _INC_MLXW32_P

#define _INC_MLXW32_P



#ifndef _MLXDRIVER_



#if defined(__cplusplus)
extern "C" {
#endif





// The following two procedures are not in the library.
// They are placed in the files ml8errd.c and mdddiagd.c
// (german) or ml8erre.c and mdddiage.c (english) and
// can be added to your projects as option.
// We recommend to reserve a string buffer of 256 characters!

void ml8_get_error_msg
   (char *errstr, unsigned char errclass, unsigned char code);

void mdd8_get_diagnosis_msg
   (char* diagstr, unsigned short code);





/////////////////////////////////////////////////////////////////////
//
//    INITIALIZATION



/********************************************************************
*  ml8_bib_startup
*
*  PURPOSE
*  -  Initializes the library
*  -  Call is not necessary because it is done by attaching the DLL
********************************************************************/
ML10API void MLXEXPORT ml8_bib_startup (ushort language);






/////////////////////////////////////////////////////////////////////
//
//    START OF COMMUNICATION



/********************************************************************
*  ml8_reset
*  ml7_reset
*  ml6_reset
*  ml2_reset
*
*  PURPOSE
*  -  Resets a MODULAR-4, Multi-COM or a Multi-LAB/2 board
*     and loads an operatings system
*
*  PARAMETER
*  -  card                 Card number
*  -  adr                  Board address (parameter is not
*                          effective, address is taken from
*                          registry)
*  -  mode                 Interrupt mode (set = 1, polling mode
*                          is not supported by driver MLXDRV)
*  -  IRQ_channel          Interrupt channel (parameter is not
*                          effective, channel is taken from
*                          registry)
*  -  DMA_channel          DMA channel (not supported, set = 0)
*  -  error_handling_proc  Callback error routine
*  -  osname               Operating system to install
*  -  timeout              Timeout value in sec/10
********************************************************************/

ML10API ushort MLXEXPORT ml8_reset
   (ushort card, ushort adr, ushort mode, ushort IRQ_channel,
   ushort DMA_channel, ERROR_PROC_P error_handling_proc,
   char *osname, ushort timeout);

ML10API ushort MLXEXPORT ml7_reset
   (ushort card, ushort adr, ushort mode, ushort IRQ_channel,
   ushort DMA_channel, ERROR_PROC_P error_handling_proc,
   char *osname, ushort timeout);

ML10API ushort MLXEXPORT ml6_reset
   (ushort card, ushort adr, ushort mode, ushort IRQ_channel,
   ushort DMA_channel, ERROR_PROC_P error_handling_proc,
   char *osname, ushort timeout);

ML10API ushort MLXEXPORT ml2_reset
   (ushort card, ushort adr, ushort mode, ushort IRQ_channel,
   ushort DMA_channel, ERROR_PROC_P error_handling_proc,
   char *osname, ushort timeout);



/********************************************************************
*  ml8_start
*  ml7_start
*  ml6_start
*  ml2_start
*
*  PURPOSE
*  -  Starts the communication with a MODULAR-4, Multi-COM
*     or a Multi-LAB/2 board
*
*  PARAMETER
*  -  card                 Card number
*  -  adr                  Board address (parameter is not
*                          effective, address is taken from
*                          registry)
*  -  mode                 Interrupt mode (set = 1, polling mode
*                          is not supported by driver MLXDRV)
*  -  IRQ_channel          Interrupt channel (parameter is not
*                          effective, channel is taken from
*                          registry)
*  -  DMA_channel          DMA channel (not supported, set = 0)
*  -  error_handling_proc  Callback error routine
*  -  timeout              Timeout value in sec/10
********************************************************************/

ML10API ushort MLXEXPORT ml8_start
   (ushort card, ushort adr, ushort mode, ushort IRQ_channel,
   ushort DMA_channel, ERROR_PROC_P error_handling_proc,
   ushort timeout);

ML10API ushort MLXEXPORT ml7_start
   (ushort card, ushort adr, ushort mode, ushort IRQ_channel,
   ushort DMA_channel, ERROR_PROC_P error_handling_proc,
   ushort timeout);

ML10API ushort MLXEXPORT ml6_start
   (ushort card, ushort adr, ushort mode, ushort IRQ_channel,
   ushort DMA_channel, ERROR_PROC_P error_handling_proc,
   ushort timeout);

ML10API ushort MLXEXPORT ml2_start
   (ushort card, ushort adr, ushort mode, ushort IRQ_channel,
   ushort DMA_channel, ERROR_PROC_P error_handling_proc,
   ushort timeout);



/********************************************************************
*  ml8_load_op
*
*  PURPOSE
*  -  Loads an operating system
*
*  PARAMETER
*  -  osname               Operating system to install
********************************************************************/

ML10API ushort MLXEXPORT ml8_load_op (void *osname);



/********************************************************************
*  ml8_open
*
*  PURPOSE
*  -  Opens the driver MLXDRV
*
*  PARAMETER
*  -  card                 Card number
********************************************************************/

ML10API ushort MLXEXPORT ml8_open (ushort card);



/********************************************************************
*  ml8_select_card
*
*  PURPOSE
*  -  Selects a board
*
*  PARAMETER
*  -  card                 Card number of board to select
********************************************************************/

ML10API void MLXEXPORT ml8_select_card (ushort card);



/********************************************************************
*  ml8_get_selected_card
*
*  PURPOSE
*  -  Returns the card number of selected board
********************************************************************/

ML10API ushort MLXEXPORT ml8_get_selected_card (void);



/********************************************************************
*  ml8_reacting
*
*  PURPOSE
*  -  Checks, if the selected card is reacting or not
********************************************************************/

ML10API ushort MLXEXPORT ml8_reacting (void);



/********************************************************************
*  ml8_type_check
*
*  PURPOSE
*  -  Checks the type of selected card
********************************************************************/

ML10API byte MLXEXPORT ml8_type_check (void);



/////////////////////////////////////////////////////////////////////
//
//    END OF COMMUNICATION



/********************************************************************
*  ml8_close
*
*  PURPOSE
*  -  Closes the driver MLXDRV
*
*  PARAMETER
*  -  card                 Card number
********************************************************************/

ML10API ushort MLXEXPORT ml8_close (ushort card);



/********************************************************************
*  ml8_exit_card
*
*  PURPOSE
*  -  Finishes the communciation with a card
*
*  PARAMETER
*  -  card                 Card number
********************************************************************/

ML10API void MLXEXPORT ml8_exit_card (ushort card);



/********************************************************************
*  ml8_exit
*
*  PURPOSE
*  -  Finishes the communciation with a cards
********************************************************************/

ML10API void MLXEXPORT ml8_exit (void);





/////////////////////////////////////////////////////////////////////
//
//    VERSION OF LIBRARY, DRIVER, OPERATING SYSTEM



/***********************************************************************
*  ml8_get_lib_version
*  ml8_get_osx_version
*  ml8_get_mlxdrv_version
*
*  PURPOSE
*  -  Reads the VERSION and the DATE CODE of the
*     library, OsX or driver MLXDRV
*
*  PARAMETER
*  -  pulVersion     Points to variable that receives the VERSION CODE
*  -  pulDate        Points to variable that receives the DATE CODE
*
*  RETURN
*  -  Nothing
***********************************************************************/

ML10API void MLXEXPORT ml8_get_lib_version
   (ulong* pulVersion, ulong* pulDate);

ML10API void MLXEXPORT ml8_get_osx_version
   (ulong* pulVersion, ulong* pulDate);

ML10API void MLXEXPORT ml8_get_mlxdrv_version
   (ulong* pulVersion, ulong* pulDate);



// versions

ML10API void MLXEXPORT ml8_get_bib_version(char *version);

ML10API void MLXEXPORT ml8_get_drv_version(char *version);

ML10API void MLXEXPORT ml8_get_os_version(char *version);




/////////////////////////////////////////////////////////////////////
//
//    ERROR HANDLING



ML10API void MLXEXPORT ml8_set_error_handling
   (ERROR_PROC_P error_handling_proc);
ML10API void MLXEXPORT ml8_set_vb_error_handling (ULONG ulWndMsg);

ML10API void MLXEXPORT ml8_get_error_info
   (struct ml8_error_info_type *err_info);

ML10API void MLXEXPORT ml8_set_error_info
   (struct ml8_error_info_type *err_info);

ML10API void MLXEXPORT ml8_get_error_class_and_code
   (byte* error_class, byte* error_code);

ML10API void MLXEXPORT ml8_set_error_message (char *errormessage);

ML10API void MLXEXPORT ml8_get_error_message (char *errormessage);

ML10API void MLXEXPORT ml8_set_mark_message (char *markmessage);

ML10API void MLXEXPORT ml8_get_mark_message (char *markmessage);

ML10API void MLXEXPORT ml8_make_err_msg
   (char *s, byte errclass, byte errcode);

ML10API void MLXEXPORT ml8_set_mark (ushort mark);

ML10API ushort MLXEXPORT ml8_get_mark (void);

ML10API void MLXEXPORT ml8_set_max_error_retry (ushort max);

ML10API M8BOOL MLXEXPORT ml8_error_repeat_test (void);

ML10API void MLXEXPORT ml8_set_repeat_macro (M8BOOL rmp);

ML10API ushort MLXEXPORT ml8_clear (void);

ML10API void MLXEXPORT ml8_clear_error (void);

ML10API ushort MLXEXPORT ml8_produce_error (ushort errtype);

ML10API void MLXEXPORT ml8_call_user_error (void);

ML10API void MLXEXPORT ml8_get_log (ushort number, void *data);

ML10API void MLXEXPORT ml8_get_log_info(void);

ML10API void MLXEXPORT ml8_reset_dlp(void);

ML10API void MLXEXPORT ml8_set_dlp( void );

ML10API byte MLXEXPORT ml8_get_port_status( void );

ML10API void MLXEXPORT ml8_clear_log_buffer(void);

ML10API void MLXEXPORT ml8_get_log_buffer
   (ushort Command, PMLX_LOG_OBJECT PLogObj, ulong *PNumber);

ML10API void MLXEXPORT ml8_log_control(ushort command, ulong parameter);

ML10API void MLXEXPORT ml8_log_init(USHORT mode);

ML10API ulong MLXEXPORT ml8_get_log_state(USHORT command);

/***********************************************************************
*  ml8_watch_error
*
*  PURPOSE
*  -  Reads an error information
*
*  PARAMETER
*  -  usInfoType     Type of error information
*
*  RETURN
*  -  Error information
***********************************************************************/
ML10API ulong MLXEXPORT ml8_watch_error (ushort usInfoType);



/////////////////////////////////////////////////////////////////////
//
//    TRANSFER PROGRAMS



ML10API ushort MLXEXPORT ml8_transfer_and_install
   (char *pgmname, ushort usage, ushort task, ushort programnr,
   ushort interruptnr, ulong flag, ulong datasize);

ML10API ushort MLXEXPORT ml8_transfer_pgm
   (ushort task, ushort usage, char *pgmname, ulong * loadadr,
   ulong * prepadr, ulong * flag);

ML10API void MLXEXPORT ml8_install_task
   (ushort task, ushort programnr, ushort interruptnr,
   ulong flag, ulong datasize, ulong adr);

ML10API void MLXEXPORT ml8_start_pgm (void);

/************************************************************
* ml8_enable_remote_debug
*     task         tasknumber
*     pgmname      path and name of the program file
*     loadadr      startaddress of the program in memory
*     prepadr      addres of the prepare-section of the program
*     (loadadr and prepadr are returned from ml8_transfer_pgm)
*     RETURN:      = 0: no error occured
*                  !=0: error occured
* to enable remote debugging for programs downloaded with
* ml8_transfer_pgm (ml8_transfer_and_install calls this also)
************************************************************/
ML10API ushort MLXEXPORT ml8_enable_remote_debug (ushort task,
               char *pgmname, ulong loadadr, ulong prepadr);


/************************************************************
* ml8_send_macro
* send a macro command to the card
* parameter: notation see manual chapter 12, except
*            pout which is a pointer to the ram-address where
*            all answer data will be stored (CA, s, w, v, a)
*     RETURN:      = 0: no error occured
*                  !=0: error occured
************************************************************/
ML10API ushort MLXEXPORT ml8_send_macro(byte CB, byte format,
                                     ushort n, ushort m,
                                     void *b, void *pout);

/////////////////////////////////////////////////////////////////////
//
//    TASK CONTROL AND INFORMATION



ML10API M8BOOL MLXEXPORT ml8_prog_in_rom (ushort pgm);

ML10API void MLXEXPORT ml8_get_task_info
   (ushort task, ushort callnr, ulong * result);

ML10API ushort MLXEXPORT ml8_get_task_number
   (ushort prognumber, ushort *installnumber);

ML10API void MLXEXPORT ml8_get_int_task
   (ushort inter, ushort *task, byte *dummy);

ML10API byte MLXEXPORT ml8_get_task_status (ushort task);

ML10API void MLXEXPORT ml8_wakeup_task (ushort task);

ML10API void MLXEXPORT ml8_sleep_task (ushort task);

ML10API void MLXEXPORT ml8_wakeup_ti_task
   (ushort task, byte prior, ulong count, ulong intval, ulong hoff);

ML10API void MLXEXPORT ml8_sleep_ti_task (ushort task);

ML10API ushort MLXEXPORT ml8_get_pgm_installed (ushort task);





/////////////////////////////////////////////////////////////////////
//
//    CALL OF TASK PROCEDURES AND FUNCTIONS



ML10API void MLXEXPORT ml8_call_func
   (ushort task, ushort func, ushort outsize, void * outdata_var,
   ushort maxinsize, ushort * insize, void * indata_var, byte * error);

ML10API void MLXEXPORT ml8_call_function
   (ushort task, ushort func, ushort * outsize, void * outdata_var,
   ushort * insize, void * indata_var, byte * error);

ML10API void MLXEXPORT ml8_call_io_func
   (ushort handle, ushort func, ushort outsize, void * outdata_var,
   ushort maxinsize, ushort * insize, void * indata_var, byte * error);

ML10API void MLXEXPORT ml8_call_proc (ushort task, ushort procedurenr);




/////////////////////////////////////////////////////////////////////
//
//    SERVICE REQUESTS


ML10API void MLXEXPORT  ml8_set_service(SERVICE_PROC_P ml8_servProc);
ML10API void MLXEXPORT        ml8_set_vb_service (ULONG WndMsg);

/***************************************************************************
*   setting service procedures for specified SRQ-Codes
*      WhichSrqs:     USER_SRQ  : SRQ messages from 80h to BFh (low byte)
*                     ERROR_SRQ : all other SRQ messages
*                  !! the following parameters refer to these SRQ messages !!
*      service_handling_proc: callback routine that is called if a
*                             corresponding SRQ occured
*      Mode:          SEND_ALL_SRQS: the process receives all corresponding
*                                    SRQ messages
*                     SEND_NO_SRQS:  the process receives no corresponding
*                                    SRQ messages
*                     SEND_SELECTED_SRQS: the process receives only SRQ
*                                    messages specified by 'rg'
*      *rg:           address of SRQRANGE struct which specifies the first and
*                     the last SRQ message that will be received by the actual
*                     process. If rg==NULL then this parameter is ignored.
*****************************************************************************/

ML10API void MLXEXPORT ml8_set_srq_handling
   (byte WhichSrqs, SERVICE_PROC_P service_handling_proc,
   byte Mode, SRQRANGE *rg);

ML10API void MLXEXPORT ml8_suspend_requests(void);

ML10API void MLXEXPORT ml8_allow_requests(void);

ML10API ushort MLXEXPORT ml8_get_message(void);

ML10API M8BOOL MLXEXPORT ml8_message_available(void);

ML10API M8BOOL MLXEXPORT ml8_poll_request(void);

ML10API void MLXEXPORT ml8_get_srq_handle( HANDLE *SrqHandle);




/////////////////////////////////////////////////////////////////////
//
//    TIMEOUT


ML10API void MLXEXPORT ml8_auto_timeout(void);

ML10API void MLXEXPORT ml8_change_timeout( ushort tenthsec );

ML10API ushort MLXEXPORT ml8_propose_timeout(ushort tenthsec);

ML10API void MLXEXPORT ml8_set_timeout(ushort timeout);

ML10API ushort MLXEXPORT ml8_get_timeout(void);





/////////////////////////////////////////////////////////////////////
//
//    INTERFACE CONTROL


ML10API void MLXEXPORT     ml8_set_macro_interruptible(M8BOOL on_off);

ML10API void MLXEXPORT     ml8_cache_control(byte mode);

// ML10API void MLXEXPORT ml8_lock_async(void);

// ML10API void MLXEXPORT ml8_lock_sync(void);

// ML10API void MLXEXPORT ml8_unlock(void);



// internal procedures

ML10API ushort MLXEXPORT ml8_hard_reset(void);

ML10API ushort MLXEXPORT ml8_init_test(void);

ML10API ushort MLXEXPORT ml8_init_bib
   (ushort card, ushort adr, ushort mode,
   ushort IRQ_channel, ushort DMA_channel);



// special Multi-LAB/2

ML10API void MLXEXPORT ml2_card_check
   ( byte *cardtype, byte *version, byte *revision);

ML10API void MLXEXPORT ml2_ga_version
   (byte *ic14, byte *ic16, byte *ic21 );

ML10API byte MLXEXPORT ml2_get_license( void );

ML10API ushort MLXEXPORT ml2_get_reserve1( void );

ML10API void MLXEXPORT ml2_set_reserve1(ushort wert );



/***************************************************************************
*  ml8_send_srq:
*     sends an SRQ from the card to the PC
*
*     target:      host that shall receive the SRQ
*                  1 = PC
*     protocol:    reserved
*     SrqCode:     SRQ code, that will be sent
*
*     RETURN:      0: no error
*                  else: error occured
****************************************************************************/
ML10API ushort MLXEXPORT ml8_send_srq
   (byte target, byte protocol, ushort SrqCode);

/***************************************************************************
*  ml8_interprete_ins_file:
*     Interpreting an INS file
*
*     FileName:    path and name of the INS file
*     RETURN:      = 0: no error occured
*                  !=0: error occured
****************************************************************************/
ML10API ushort MLXEXPORT ml8_interpret_ins_file
   (char *FileName, char *Parameters);



////////////////////////////////////////////////////////////////////////
// Task parameter



/***********************************************************************
*  ml8_read_par_byte
*  ml8_read_par_word
*
*  PURPOSE
*  -  Reads a task parameter (byte/word)
*
*  PARAMETER
*  -  task           Task number
*  -  start          Read address (relative offset)
*
*  RETURN
*  -  Read parameter
***********************************************************************/
ML10API byte MLXEXPORT ml8_read_par_byte (ushort task, ushort start);
ML10API ushort MLXEXPORT ml8_read_par_word (ushort task, ushort start);

/***********************************************************************
*  ml8_read_par_dword
*
*  PURPOSE
*  -  Reads a task parameter (dword)
*
*  PARAMETER
*  -  task           Task number
*  -  start          Read address (relative offset)
*  -  datavar        Points to variable that receives the parameter
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_read_par_dword
   (ushort task, ushort start, ulong *datavar);

/***********************************************************************
*  ml8_read_par_block
*
*  PURPOSE
*  -  Reads a task parameter block
*
*  PARAMETER
*  -  task           Task number
*  -  start          Read address (relative offset)
*  -  size           Size of block to read
*  -  data_var       Points to the object that receives the parameter
*                    block
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_read_par_block
   (ushort task, ushort start, ushort size, void * data_var);

/***********************************************************************
*  ml8_write_par_byte
*  ml8_write_par_word
*  ml8_write_par_dword
*
*  PURPOSE
*  -  Writes a task parameter (byte, word or dword)
*
*  PARAMETER
*  -  task           Task number
*  -  start          Read address (relative offset)
*  -  data           Data to write
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_write_par_byte
   (ushort task, ushort start, byte data);
ML10API void MLXEXPORT ml8_write_par_word
   (ushort task, ushort start, ushort data);
ML10API void MLXEXPORT ml8_write_par_dword
   (ushort task, ushort start, ulong data);

/***********************************************************************
*  ml8_write_par_block
*
*  PURPOSE
*  -  Writes a task parameter block
*
*  PARAMETER
*  -  task           Task number
*  -  start          Write address (relative offset)
*  -  size           Size of block to write
*  -  data_var       Points to the parameter block to write
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_write_par_block
   (ushort task, ushort start, ushort size, void * data_var);



////////////////////////////////////////////////////////////////////////
// Task data



/***********************************************************************
*  ml8_reset_r_pointer
*  ml8_reset_w_pointer
*
*  PURPOSE
*  -  Sets the read/write pointer of a task to the beginning of the
*     tasks data area
*
*  PARAMETER
*  -  task           Task number
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_reset_r_pointer (ushort task);
ML10API void MLXEXPORT ml8_reset_w_pointer (ushort task);

/***********************************************************************
*  ml8_move_r_pointer
*  ml8_move_w_pointer
*
*  PURPOSE
*  -  Moves the read/write pointer of a task relative to the
*     actual position of the pointer
*  -  Moving can be forward (offset > 0) and backward (offset < 0)
*
*  PARAMETER
*  -  task           Task number
*  -  offset         Direction (sign) and jump width (absolute value)
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_move_r_pointer (ushort task, long offset);
ML10API void MLXEXPORT ml8_move_w_pointer (ushort task, long offset);

/***********************************************************************
*  ml8_read_data_byte
*  ml8_read_data_word
*
*  PURPOSE
*  -  Reads a data (byte/word) from the tasks data read pointer
*  -  After reading the data read pointer moves forward one (if byte)
*     or two (if word) bytes
*
*  PARAMETER
*  -  task           Task number
*
*  RETURN
*  -  Read data
***********************************************************************/
ML10API byte MLXEXPORT ml8_read_data_byte (ushort task);
ML10API ushort MLXEXPORT ml8_read_data_word (ushort task);

/***********************************************************************
*  ml8_read_data_dword
*
*  PURPOSE
*  -  Reads a data (dword) from the tasks data read pointer
*  -  After reading the data read pointer moves forward four bytes
*
*  PARAMETER
*  -  task           Task number
*  -  datavar        Points to a variable that receives the data
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_read_data_dword (ushort task, ulong *datavar);

/***********************************************************************
*  ml8_read_data_block
*
*  PURPOSE
*  -  Reads a data block from the tasks data read pointer
*  -  After reading the data read pointer moves forward n bytes
*     (n = size  of data block)
*
*  PARAMETER
*  -  task           Task number
*  -  size           Size of data block to read
*  -  data_var       Points to an object that receives the data
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_read_data_block
   (ushort task, ushort size, void * data_var);

/***********************************************************************
*  ml8_read_data
*
*  PURPOSE
*  -  Sets the data read pointer of the task and reads a data block
*     from the pointer
*  -  After reading the data read pointer moves forward n bytes
*     (n = size  of data block)
*  -  After the call the data read pointer has following relative
*     position: rel_ofs + size
*
*  PARAMETER
*  -  task           Task number
*  -  rel_ofs        Relative address to start reading
*  -  size           Size of data block to read
*  -  data           Points to an object that receives the data
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_read_data
   (ushort task, ulong rel_ofs, ushort size, void* data);

/***********************************************************************
*  ml8_write_data_byte
*  ml8_write_data_word
*  ml8_write_data_dword
*
*  PURPOSE
*  -  Writes a data (byte/word/dword) to the tasks data write pointer
*  -  After writing the data write pointer moves forward one (if byte),
*     two (if word) or four (if dword) bytes
*
*  PARAMETER
*  -  task           Task number
*  -  data           Data to write
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_write_data_byte (ushort task, byte data);
ML10API void MLXEXPORT ml8_write_data_word (ushort task, ushort data);
ML10API void MLXEXPORT ml8_write_data_dword (ushort task, ulong data);

/***********************************************************************
*  ml8_write_data_block
*
*  PURPOSE
*  -  Writes a data block to the tasks data write pointer
*  -  After writing the data write pointer moves forward n bytes
*     (n = size  of data block)
*
*  PARAMETER
*  -  task           Task number
*  -  size           Size of data block to write
*  -  data_var       Points to the data block to write
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_write_data_block
   (ushort task, ushort size, void * data_var);

/***********************************************************************
*  ml8_write_data
*
*  PURPOSE
*  -  Sets the data write pointer of the task and writes a data block
*     to the pointer
*  -  After writing the data write pointer moves forward n bytes
*     (n = size  of data block)
*  -  After the call the data write pointer has following relative
*     position: rel_ofs + size
*
*  PARAMETER
*  -  task           Task number
*  -  rel_ofs        Relative address to start reading
*  -  size           Size of data block to read
*  -  data           Points to an object that receives the data
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_write_data
   (ushort task, ulong rel_ofs, ushort size, void* data);




////////////////////////////////////////////////////////////////////////
// RAM



/***********************************************************************
*  ml8_allocate_ram
*
*  PURPOSE
*  -  Allocates RAM on the MODULAR-4 or Multi-LAB/2 board
*  -  The allocation can be controlled by parameter
*     'strategy':
*     1  =  From bottom, allocate all or nothing
*     2  =  From bottom, allacate as much as possible
*     3  =  From top, allocate all or nothing
*     4  =  From top, allocate as much as possible
*
*  PARAMETER
*  -  task           Task number the ram belongs to
*  -  usage          Reserved (set = 0)
*  -  strategy       Strategy for RAM allocation (see above)
*  -  align          Alignment 2**n (0 = Byte, 1 = Word, 2 = Dword, ...)
*  -  size           Points to a variable which stores the size of
*                    RAM to be allocated and returns the real size
*  -  adr            Points to a variable that receives the physical
*                    address of the allocated RAM
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_allocate_ram
   (ushort task, ushort usage, byte strategy, byte align,
   ulong *size, ulong * adr);

/***********************************************************************
*  ml8_get_free_ram_size
*
*  PURPOSE
*  -  Determines the free ram size
*
*  PARAMETER
*  -  align          Alignment 2**n (0 = Byte, 1 = Word, 2 = Dword, ...)
*  -  size           Points to a variable which returns the free RAM size
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_get_free_ram_size (byte align, ulong * size);

/***********************************************************************
*  ml8_set_ram_pointer
*
*  PURPOSE
*  -  Sets the RAM pointer for RAM data I/O
*
*  PARAMETER
*  -  adr            Physical address the pointer has to be set
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_set_ram_pointer (ulong adr);

/***********************************************************************
*  ml8_read_ram
*
*  PURPOSE
*  -  Reads a data block from the RAM pointer
*  -  After call the RAM pointer has moved forword for the size
*     of the read data block
*
*  PARAMETER
*  -  size           Size of data block to read
*  -  data_var       Points to an object that receives the data
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_read_ram (ushort size, void * data_var);

/***********************************************************************
*  ml8_write_ram
*
*  PURPOSE
*  -  Writes a data block to the RAM pointer
*  -  After call the RAM pointer has moved forword for the size
*     of the written data block
*
*  PARAMETER
*  -  size           Size of data block to write
*  -  data_var       Points to the data to write
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_write_ram (ushort size, void * data_var);

/****************************************************************************
*  ml8_read_memory
*
*  PURPOSE
*  -  Reads a data block from RAM of the MODULAR-4
*  -  Only supported by a MODULAR-4 board, OsX from ml8-3B.01r on
*
*  PARAMETER
*  -  start_adr      Physical source address (RAM)
*  -  size           Size of data block
*  -  data_ptr       Points to destination
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_read_memory
   (ulong start_adr, ushort size, void* data_ptr);

/****************************************************************************
*  ml8_write_memory
*
*  PURPOSE
*  -  Writes a data block to RAM of the MODULAR-4
*  -  Only supported by a MODULAR-4 board, OsX from ml8-3B.01r on
*
*  PARAMETER
*  -  start_adr      Physical destination address (RAM)
*  -  size           Block size
*  -  data_ptr       Points to source data
****************************************************************************/
ML10API void MLXEXPORT ml8_write_memory
   (ulong start_adr, ushort size, void* data_ptr);

/****************************************************************************
*  ml8_get_physical_address
*
*  PURPOSE
*  -  Returns the physical address to a seg:off address
*
*  PARAMETER
*  -  ulSegOff       seg:off address
*
*  RETURN
*  -  Physical address
****************************************************************************/
ML10API ulong MLXEXPORT ml8_get_physical_address (ulong ulSegOff);


////////////////////////////////////////////////////////////////////////
// Buffer
// MODULAR-4/486: OsX from ml8-3A.02r on
// Multi-LAB/2:   Procedures are not available



/***********************************************************************
*  ml8_create_buffer
*
*  PURPOSE
*  -  Creates a new buffer
*  -  To create a buffer the operating system must allocate RAM on
*     the MODULAR-4. This allocation can be controlled by parameter
*     'strategy':
*     1  =  From bottom, allocate all or nothing
*     2  =  From bottom, allacate as much as possible
*     3  =  From top, allocate all or nothing
*     4  =  From top, allocate as much as possible
*
*  PARAMETER
*  -  task           Task number the buffer belongs to
*  -  strategy       Strategy for RAM allocation (see above)
*  -  align          Alignment of buffer
*                    (see ml8_allocate_ram in manual)
*  -  usage          Reserved (set = 0)
*  -  size           Size of the buffer
*  -  handle         Points to a variable that receives the handle
*                    of the created buffer
*
*  RETURN
*  -  0  =  creation successful
*  -  otherwise creation not successful
***********************************************************************/
ML10API byte MLXEXPORT ml8_create_buffer
   (ushort task, byte strategy, byte align, ushort usage,
   ulong *size, ulong *handle);

/***********************************************************************
*  ml8_delete_buffer
*
*  NOTES
*  -  This function is not supported yet
*
*  PURPOSE
*  -  Deletes a buffer
*
*  PARAMETER
*  -  buffer         Handle of buffer to delete
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_delete_buffer (ulong buffer);

/***********************************************************************
*  ml8_clear_buffer
*
*  PURPOSE
*  -  Deletes the contents of a buffer
*
*  PARAMETER
*  -  buffer         Handle of buffer to clear
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_clear_buffer(ulong buffer);

/***********************************************************************
*  ml8_read_buffer_byte
*  ml8_read_buffer_word
*  ml8_read_buffer_dword
*
*  PURPOSE
*  -  Reads a byte/word/dword from a buffer
*
*  PARAMETER
*  -  buffer         Handle of buffer to read
*  -  data           Points to a variable that receives the data
*
*  RETURN
*  -  Error status
*     0  =  No error
*     2  =  Wrong parameter in call to procedure
*     22 =  Another task is just writing to buffer
*     23 =  Another task is just reading from buffer
*     24 =  Not enough place in buffer
***********************************************************************/
ML10API byte MLXEXPORT ml8_read_buffer_byte (ulong buffer, byte *data);
ML10API byte MLXEXPORT ml8_read_buffer_word (ulong buffer, ushort *data);
ML10API byte MLXEXPORT ml8_read_buffer_dword (ulong buffer, ulong *data);

/***********************************************************************
*  ml8_get_buffer
*
*  PURPOSE
*  -  Reads a data block from a buffer
*  -  Reading is controlled by parameter 'strategy':
*     Bit-0 = 0   Read all or nothing
*     Bit-0 = 1   Read as much as possible
*     Bit-1 = 0   Read buffer
*     Bit-1 = 1   View buffer (data stay in buffer)
*     Bit-2 = 0   Try once
*     Bit-2 = 1   Try multiple until reading was possible
*
*  PARAMETER
*  -  buffer         Handle of buffer to read
*  -  strategy       Strategy of writing (see above)
*  -  size           Points to a variable that consists the size of
*                    the data block to read and receives the size
*                    of the data block that was really read
*  -  datavar        Points to an object that receives the data block
*
*  RETURN
*  -  Error status
*     0  =  No error
*     2  =  Wrong parameter in call to procedure
*     22 =  Another task is just writing to buffer
*     23 =  Another task is just reading from buffer
*     24 =  Not enough place in buffer
***********************************************************************/
ML10API byte MLXEXPORT ml8_get_buffer
   (ulong buffer, byte strategy, ushort *size, void *datavar);

/***********************************************************************
*  ml8_write_buffer_byte
*  ml8_write_buffer_word
*  ml8_write_buffer_dword
*
*  PURPOSE
*  -  Writes a byte/word/dword to a buffer
*
*  PARAMETER
*  -  buffer         Handle of buffer to write
*  -  data           Data to write to buffer
*
*  RETURN
*  -  Error status
*     0  =  No error
*     2  =  Wrong parameter in call to procedure
*     22 =  Another task is just writing to buffer
*     23 =  Another task is just reading from buffer
*     24 =  Not enough place in buffer
***********************************************************************/
ML10API byte MLXEXPORT ml8_write_buffer_byte (ulong buffer, byte data);
ML10API byte MLXEXPORT ml8_write_buffer_word (ulong buffer, ushort data);
ML10API byte MLXEXPORT ml8_write_buffer_dword (ulong buffer, ulong data);

/***********************************************************************
*  ml8_set_buffer
*
*  PURPOSE
*  -  Writes a data block to a buffer
*  -  Writing is controlled by parameter 'strategy':
*     Bit-0 = 0   Write all or nothing
*     Bit-0 = 1   Write as much as possible
*     Bit-1 = 0   Reserved
*     Bit-2 = 0   Try once
*     Bit-2 = 1   Try multiple until writing was possible
*
*  PARAMETER
*  -  buffer         Handle of buffer to set
*  -  strategy       Strategy of writing (see above)
*  -  size           Points to a variable that consists the size of
*                    the data block to write and receives the size
*                    of the data block that was really written
*  -  datavar        Points to the data block to write
*
*  RETURN
*  -  Error status
*     0  =  No error
*     2  =  Wrong parameter in call to procedure
*     22 =  Another task is just writing to buffer
*     23 =  Another task is just reading from buffer
*     24 =  Not enough place in buffer
***********************************************************************/
ML10API byte MLXEXPORT ml8_set_buffer
   (ulong buffer, byte strategy, ushort *size, void *datavar);

/***********************************************************************
*  ml8_get_buffer_status
*
*  PURPOSE
*  -  Reads the state of a buffer
*
*  PARAMETER
*  -  buffer         Handle of buffer
*  -  freesize       Points to a variable that receives the number
*                    of free bytes in buffer
*  -  usedsize       Points to a variable that receives the number
*                    of used bytes in buffer
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_get_buffer_status
   (ulong buffer, ulong *freesize, ulong *usedsize);

/***********************************************************************
*  ml8_get_prev_buffer_status
*
*  PURPOSE
*  -  Returns the state of the buffer that was called al last by PC
*  -  If free size or used size of buffer is 0xFFFF, the value is
*     greater or equal as 0xFFFF (use ml8_get_buffer_status which
*     uses 'long' parameters)
*  -  If no buffer was called by PC, the error handler is called
*
*  PARAMETER
*  -  freesize       Points to a variable that receives the number
*                    of free bytes in buffer
*  -  usedsize       Points to a variable that receives the number
*                    of used bytes in buffer
*                    of used bytes in buffer
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_get_prev_buffer_status
   (ushort *freesize, ushort *usedsize);



////////////////////////////////////////////////////////////////////////
// Local device access



/***********************************************************************
*  ml8_in8_port
*  ml8_in16_port
*
*  PURPOSE
*  -  Reads a local I/O port (8 or 16 bit)
*
*  PARAMETER
*  -  port           Port address
*
*  RETURN
*  -  Read data (8 or 16 bit)
***********************************************************************/
ML10API byte MLXEXPORT ml8_in8_port (ushort port);
ML10API ushort MLXEXPORT ml8_in16_port (ushort port);

/***********************************************************************
*  ml8_out8_port
*  ml8_out16_port
*
*  PURPOSE
*  -  Writes to a local I/O port (8 or 16 bit)
*
*  PARAMETER
*  -  port           Port address
*  -  data_var       Data to write (8 or 16 bit)
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_out8_port (ushort port, byte data_var);
ML10API void MLXEXPORT ml8_out16_port (ushort port, ushort data_var);

/***********************************************************************
*  ml8_local_led_on
*  ml8_local_led_off
*  ml8_external_led_on
*  ml8_external_led_off
*
*  PURPOSE
*  -  Controls the local or external LED (on/off)
*
*  PARAMETER
*  -  None
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_local_led_on (void);
ML10API void MLXEXPORT ml8_local_led_off (void);
ML10API void MLXEXPORT ml8_external_led_on (void);
ML10API void MLXEXPORT ml8_external_led_off (void);

/***********************************************************************
*  ml8_get_local_led_status
*
*  PURPOSE
*  -  Reads the status of the local LED
*
*  PARAMETER
*  -  None
*
*  RETURN
*  -  LED status in bit-0 (0 = off, 1 = on)
***********************************************************************/
ML10API byte MLXEXPORT ml8_get_local_led_status (void);

/***********************************************************************
*  ml8_read_eeprom_direct
*  ml8_read_eeprom_copy
*
*  PURPOSE
*  -  Reads a word from the eeprom (direct or from eeprom copy)
*
*  PARAMETER
*  -  modul          Number of module
*                    (0 = base card, 1 = microslot-1, ...)
*  -  reladr         Word number
*
*  RETURN
*  -  Read word
***********************************************************************/
ML10API ushort MLXEXPORT ml8_read_eeprom_direct (byte modul, byte reladr);
ML10API ushort MLXEXPORT ml8_read_eeprom_copy (byte modul, byte reladr);

/***********************************************************************
*  ml8_write_eeprom_direct
*  ml8_write_eeprom_copy
*
*  PURPOSE
*  -  Writes a word to the eeprom (direct or to eeprom copy)
*
*  PARAMETER
*  -  modul          Number of module
*                    (0 = base card, 1 = microslot-1, ...)
*  -  reladr         Word number
*  -  data_var       Data to write
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_write_eeprom_direct
   (byte modul, byte reladr, ushort data_var);
ML10API void MLXEXPORT ml8_write_eeprom_copy
   (byte modul, byte reladr, ushort data_var);

/***********************************************************************
*  ml8_get_rtc_status
*
*  PURPOSE
*  -  Returns the status of the real-time-clock (RTC)
*
*  PARAMETER
*  -  None
*
*  RETURN
*  -  Status of the RTC
***********************************************************************/
ML10API byte MLXEXPORT ml8_get_rtc_status (void);

/***********************************************************************
*  ml8_set_rtc_mode
*
*  PURPOSE
*  -  Sets the mode of the real-time-clock (RTC)
*
*  PARAMETER
*  -  mode           Mode to be set
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_set_rtc_mode (byte mode);

/***********************************************************************
*  ml8_get_time
*  ml8_get_date_and_time      (year range 00..99)
*  ml8_get_date_and_time_2000 (year range 00..179)
*
*  PURPOSE
*  -  Reads the time or date and time on the board
*
*  PARAMETER
*  -  year           Points to variable to receive 'year'
*  -  month          Points to variable to receive 'month
*  -  day            Points to variable to receive 'day
*  -  dow            Points to variable to receive 'day of week'
*  -  hour           Points to variable to receive 'hours'
*  -  min            Points to variable to receive 'minutes'
*  -  sec            Points to variable to receive 'seconds'
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_get_date_and_time
   (byte* year, byte* month, byte* day, byte* dow,
   byte* hour, byte* min, byte* sec);
ML10API void MLXEXPORT ml8_get_time (byte* hour, byte* min, byte* sec);
ML10API void MLXEXPORT ml8_get_date_and_time_2000
   (byte* year, byte* month, byte* day, byte* dow,
   byte* hour, byte* min, byte* sec);

/***********************************************************************
*  ml8_get_rtc_date_code
*  ml8_get_rtc_time_code
*
*  PURPOSE
*  -  Returns the date/time of the on-board real-time-clock
*  -  See also ml8_create_date_string
*  -  See also ml8_create_time_string
*
*  RETURN
*  -  Date/Time code
***********************************************************************/
ML10API ulong MLXEXPORT ml8_get_rtc_date_code (void);
ML10API ulong MLXEXPORT ml8_get_rtc_time_code (void);

/***********************************************************************
*  ml8_set_date_and_time
*  ml8_set_date_and_time_2000
*
*  PURPOSE
*  -  Sets the date and time on the board
*
*  PARAMETER
*  -  year           'year' to be set
*  -  month          'month' to be set
*  -  day            'day'to be set
*  -  dow            'day of week' to be set
*  -  hour           'hours' to be set
*  -  min            'minutes' to be set
*  -  sec            'seconds' to be set
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_set_date_and_time
   (byte year, byte month, byte day, byte dow, byte hour,
   byte min, byte sec);

ML10API void MLXEXPORT ml8_set_date_and_time_2000
   (byte year, byte month, byte day, byte dow, byte hour,
   byte min, byte sec);

/***********************************************************************
*  ml8_init_io
*
*  PURPOSE
*  -  Initializes the outputs of a module as it is given by EEPROM
*     or initializes the base board
*
*  NOTES
*  -  MODULAR-4/486: OsX must be newer than ML8-3A.02R
*  -  MULTI-LAB/2:   Procedure not avaialble
*
*  PARAMETER
*  -  microchannel   Microslot of module to initialize (0 = base board)
*  -  optional       Option
*                       0  =  Initialize only if Bit-0 of Word-1 in the
*                             EEPROM is = 1
*                       1  =  Initialize in any case
*
*     MODULAR-4/486: OsX newer than ml8-3A.02r
*     Multi-LAB/2:   procedure is not available
****************************************************************************/
ML10API void MLXEXPORT     ml8_init_io(byte microchannel, byte optional);



////////////////////////////////////////////////////////////////////////
// MODULAR device drivers
// MODULAR-4/486: OsX ML8-3B or higher
// Multi-LAB/2:   OsX in preparation



/***********************************************************************
*  mdd8_get_version
*
*  PURPOSE
*  -  Reads the VERSION and the DATE CODE of the MDD
*
*  PARAMETER
*  -  usMDD          Task number of MDD
*  -  pulVersion     Points to variable that receives the VERSION CODE
*  -  pulDate        Points to variable that receives the DATE CODE
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_get_version
   (ushort usMDD, ulong* pulVersion, ulong* pulDate);

/***********************************************************************
*  mdd8_open_channel
*
*  PURPOSE
*  -  Opens a channel that is specified by the entried CPS
*
*  PARAMETER
*  -  usMDD          Task/Slot number of MDD
*  -  usStrucSize    Size of CPS
*  -  pCPS           Points to the CPS
*
*  RETURN
*  -  Handle for the opened channel
*  -  If the function fails then the returned handle is = 0
*
*  REMARKS
*  WIN32 libraries since Version 7.C.003 support MDD autoload. Following steps are done:
*  1. Check slot number (usMDD).
*     Number 0 can be used for base board. In this case the MDD of the base board is
*     installed with task number 11.
*  2. check if there's a task installed with task number usMDD. If so, go to step 8.
*  3. read EEPROM settings of the module on slot usMDD, find out module type.
*  4. search registry subkeys of HKEY_LOCAL_MACHINE\\SOFTWARE\\SORCUS\\MDD. 
*     If there are informations about a MDD for the module used, goto step 6
*  5. search in library internal MDD table for module type.
*  6. search the mdd file:
*     - in the path set by ml8_set_search path
*     - in the current directory
*     - in MDD directory of SNW32.EXE:
*       HKEY_CURRENT_USER\\SOFTWARE\\SORCUS\\SNW32\\MLx\\mdd_path
*       MLx is the type of the SORCUS board: ML2, ML6, ML7 or ML8.
*  7. Install the mdd 
*  8. Check state of the mdd task
*  9. open mdd channel
*
***********************************************************************/
ML10API HMDD8 MLXEXPORT mdd8_open_channel
   (ushort usMDD, ushort usStrucSize, void *pCPS);

/***********************************************************************
*  mdd8_open_channel
*
*  PURPOSE
*  -  Opens a channel that is specified by the entried CPS
*
*  PARAMETER
*  -  usMDD          Task number of MDD
*  -  usStrucSize    Size of CPS
*  -  pCPS           Points to the CPS
*        -  ulPar                                reserved parameter = 0
*        -        pfnUserFunc                user callback procedure
*        -        mode                                = 0 for PC programs
*
*  RETURN
*  -  Handle for the opened channel
*  -  If the function fails then the returned handle is = 0
***********************************************************************/
ML10API HMDD8 MLXEXPORT mdd8_open_channel_callback
   (USHORT usMDD, USHORT usStrucSize, void *pCPS,
         ULONG ulPar, void *pfnUserFunc, USHORT mode);

/***********************************************************************
*  mdd8_read_infotext
*
*  PURPOSE
*  -  Reads an infotext of the MDD
*
*  PARAMETER
*  -  usMDD          Task number of MDD
*  -  usTxtNr        Number of the infotext
*  -  ucMaxLen       Mamimum allowed number of returning characters
*  -  pacInfotext    Points to a string variable that receives the
*                    infotext
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_read_infotext
   (ushort usMDD, ushort usTxtNr, byte ucMaxLen, char *pacInfotext);

/***********************************************************************
*  mdd8_get_device_status
*
*  PURPOSE
*  -  Reads the status of a device
*
*  PARAMETER
*  -  usMDD          Task number of MDD
*  -  usDevice       Type of device
*  -  usIndex        Index of device
*  -  usExtIndex     External index of device
*
*  RETURN
*  -  Status of specified device (= number of channels that are
*     opened to the device)
*  -  If value = 0xFFFF (= DSC_IS_EXCLUSIVE) then the device is opened
*     to an exclusive channel
***********************************************************************/
ML10API ushort MLXEXPORT mdd8_get_device_status
   (ushort usMDD, ushort usDevice, ushort usIndex, ushort usExtIndex);

/***********************************************************************
*  mdd8_scan_channel
*
*  PURPOSE
*  -  Reads information of a channel
*  -  Channel can be given by his handle or by his ordinal number
*
*  PARAMETER
*  -  usMDD          Task number of MDD
*  -  usInfoType     Type of information
*  -  hChannel       Handle or ordinal number of channel
*  -  usCount        Maximum allowed number of returning bytes
*  -  pInfoData      Points to object that receives the information
*
*  RETURN
*  -  Number of valid bytes of the returning information
***********************************************************************/
ML10API ushort MLXEXPORT mdd8_scan_channel
   (ushort usMDD, ushort usInfoType, HMDD8 hChannel,
   ushort usCount, void *pInfoData);

/***********************************************************************
*  mdd8_reset_driver
*
*  PURPOSE
*  -  Resets the MDD
*  -  Each channel, that is opened by the MDD, will be closed
*  -  The module will be reinitialized
*
*  PARAMETER
*  -  usMDD          Task number of MDD
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_reset_driver (ushort usMDD);

/***********************************************************************
*  mdd8_write_channel_byte
*  mdd8_write_channel_word
*  mdd8_write_channel_short
*  mdd8_write_channel_dword
*
*  PURPOSE
*  -  Writes a Byte/Word/Short/Dword to the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  ucData         Data to write
*  -  usData         Data to write
*  -  sData          Data to write
*  -  ulData         Data to write
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_write_channel_byte
   (HMDD8 hChannel, byte ucData);
ML10API void MLXEXPORT mdd8_write_channel_word
   (HMDD8 hChannel, ushort usData);
ML10API void MLXEXPORT mdd8_write_channel_short
   (HMDD8 hChannel, short sData);
ML10API void MLXEXPORT mdd8_write_channel_dword
   (HMDD8 hChannel, ulong ulData);

/***********************************************************************
*  mdd8_write_channel_block
*
*  PURPOSE
*  -  Writes a data block to the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usCount        Size of data block
*  -  pData          Points to data block
*
*  RETURN
*  -  Number of bytes that could not be written
***********************************************************************/
ML10API ushort MLXEXPORT mdd8_write_channel_block
   (HMDD8 hChannel, ushort usCount, void *pData);

/***********************************************************************
*  mdd8_trigger_channel
*
*  PURPOSE
*  -  Triggers the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_trigger_channel (HMDD8 hChannel);

/***********************************************************************
*  mdd8_read_channel_byte
*  mdd8_read_channel_word
*  mdd8_read_channel_short
*  mdd8_read_channel_dword
*
*  PURPOSE
*  -  Reads a Byte/Word/Short/Dword from the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*
*  RETURN
*  -  Read data
***********************************************************************/
ML10API byte MLXEXPORT mdd8_read_channel_byte (HMDD8 hChannel);
ML10API ushort MLXEXPORT mdd8_read_channel_word (HMDD8 hChannel);
ML10API short MLXEXPORT mdd8_read_channel_short (HMDD8 hChannel);
ML10API ulong MLXEXPORT mdd8_read_channel_dword (HMDD8 hChannel);

/***********************************************************************
*  mdd8_read_channel_block
*
*  PURPOSE
*  -  Reads a data block from the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usCount        Size of expected data block
*  -  pData          Points to an object that receives the data block
*
*  RETURN
*  -  Number of returned bytes
***********************************************************************/
ML10API ushort MLXEXPORT mdd8_read_channel_block
   (HMDD8 hChannel, ushort usCount, void *pData);

/***********************************************************************
*  mdd8_send_channel_command
*
*  PURPOSE
*  -  Sends a channel command to the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usCmd          Channel command
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_send_channel_command
   (HMDD8 hChannel, ushort usCmd);

/***********************************************************************
*  mdd8_send_channel_control
*
*  PURPOSE
*  -  Sends a channel control command and control data to the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usCtrl         Channel control command
*  -  ulCtrlData     Channel control data
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_send_channel_control
   (HMDD8 hChannel, ushort usCtrl, ulong ulCtrlData);

/***********************************************************************
*  mdd8_send_channel_control_block
*
*  PURPOSE
*  -  Sends a channel control command and control data block to
*     the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usCtrl         Channel control command
*  -  usSize         Size of channel control data block
*  -  pCtrlData      Points to the channel control data block
*
*  RETURN
*  -  Number of bytes that could not be written
***********************************************************************/
ML10API ushort MLXEXPORT mdd8_send_channel_control_block
   (HMDD8 hChannel, ushort usCtrl, ushort usSize, void* pCtrlData);

/***********************************************************************
*  mdd8_get_channel_info
*
*  PURPOSE
*  -  Sends a channel info command and reads an information data from
*     the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usInfo         Channel info command
*
*  RETURN
*  -  Information data
***********************************************************************/
ML10API ulong MLXEXPORT mdd8_get_channel_info
   (HMDD8 hChannel, ushort usInfo);

/***********************************************************************
*  mdd8_get_channel_info_block
*
*  PURPOSE
*  -  Sends a channel info command and reads an information data block
*     from the channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usInfo         Channel info command
*  -  usSize         Maximum allowed number of return bytes
*  -  pInfoData      Points to an objetct that receives the information
*                    data block
*
*  RETURN
*  -  Number of returned bytes
***********************************************************************/
ML10API ushort MLXEXPORT mdd8_get_channel_info_block
   (HMDD8 hChannel, ushort usInfo, ushort usSize, void* pInfoData);

/***********************************************************************
*  mdd8_set_channel_caption
*
*  PURPOSE
*  -  Sets the caption of a channel to store a short description or
*     the usage of the channel. A channel gets a caption buffer
*     when he is opened. The size of reserved buffer is taken from
*     the MDD tasks parameter area (Byte, relative offset 1). The
*     default size for the caption buffer is 16 bytes.
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usLen          Length of string to set (must be lower than
*                    the caption buffer size)
*  -  pcCaption      Points to the caption to set
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_set_channel_caption
   (HMDD8 hChannel, ushort usLen, char* pcCaption);

/***********************************************************************
*  mdd8_get_channel_caption
*
*  PURPOSE
*  -  Reads the caption of a channel
*
*  PARAMETER
*  -  hChannel       Handle of channel
*  -  usLen          Maximum length of string to receive
*  -  pcCaption      Points to a variable to receive the caption
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_get_channel_caption
   (HMDD8 hChannel, ushort usLen, char* pcCaption);

/***********************************************************************
*  mdd8_close_channel
*
*  PURPOSE
*  -  Closes the channel
*  -  If successful then the handle changes to 0
*
*  PARAMETER
*  -  phChannel      Points to the handle of channel to close
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT mdd8_close_channel (HMDD8* phChannel);

/***********************************************************************
*  mdd8_check_handle_valid
*
*  PURPOSE
*  -  Checks the validity of a channel
*
*  PARAMETER
*  -  hChannel       Handle of channel to check
*
*  RETURN
*  -  >0:   Task number of MDD the channel is opened
*     0:    The handle is invalid
***********************************************************************/
ML10API ushort MLXEXPORT mdd8_check_handle_valid (HMDD8 hChannel);

/***********************************************************************
*  mdd8_get_diagnosis
*
*  PURPOSE
*  -  Reads the actual diagnosis word of a MDD
*  -  The MDD, that stores the diagnosis word, is stored in the
*     library
*
*  PARAMETER
*  -  None
*
*  RETURN
*  -  Diagnosis word
***********************************************************************/
ML10API ushort MLXEXPORT mdd8_get_diagnosis (void);




////////////////////////////////////////////////////////////////////////
// Flash programming
// MODULAR-4/486: OsX from ml8-3B.01r on
// Multi-LAB/2:   Procedures are not available



/***********************************************************************
*  ml8_set_flash_mode
*
*  PURPOSE
*  -  Sets the mode for flash programming
*
*  PARAMETER
*  -  ucDevNo        Number of device (0 = base card, 1 = module-1, ...)
*  -  ucICNo         Number of flash chip
*  -  ucMode         Set mode
*  -  ucOption       Option
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_set_flash_mode
   (byte ucDevNo, byte ucICNo, byte ucMode, byte ucOption);

/***********************************************************************
*  ml8_get_flash_info
*
*  PURPOSE
*  -  Reads an information from the flash
*
*  PARAMETER
*  -  ucDevNo        Number of device (0 = base card, 1 = module-1, ...)
*  -  ucICNo         Number of flash chip
*  -  ucMode         Read mode
*  -  ucOption       Option
*
*  RETURN
*  -  Information
***********************************************************************/
ML10API ushort MLXEXPORT ml8_get_flash_info
   (byte ucDevNo, byte ucICNo, byte ucMode, byte ucOption);

/***********************************************************************
*  ml8_erase_flash_sector
*
*  PURPOSE
*  -  Reads an information from the flash
*
*  PARAMETER
*  -  ucDevNo        Number of device (0 = base card, 1 = module-1, ...)
*  -  ucICNo         Number of flash chip
*  -  ulFirstAdr     First address (start) of sectors to be erased
*  -  ulLastAdr      Last address (stop) of sectors to be erased
*
*  RETURN
*  -  Number of an erased sector
***********************************************************************/
ML10API ushort MLXEXPORT ml8_erase_flash_sector
   (byte ucDevNo, byte ucICNo, ulong ulFirstAdr, ulong ulLastAdr);

/***********************************************************************
*  ml8_program_flash
*
*  PURPOSE
*  -  Programs the flash
*
*  PARAMETER
*  -  ucDevNo        Number of device (0 = base card, 1 = module-1, ...)
*  -  ucICNo         Number of flash chip
*  -  ulStartAdr     Start address for flash programming
*  -  usSize         Size of data block to be written
*  -  pData          Points to the data block to be written to flash
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_program_flash
   (byte ucDevNo, byte ucICNo, ulong ulStartAdr,
   ushort usSize, void* pData);

/***********************************************************************
*  ml8_read_flash
*
*  PURPOSE
*  -  Reads the flash
*
*  PARAMETER
*  -  ucDevNo        Number of device (0 = base card, 1 = module-1, ...)
*  -  ucICNo         Number of flash chip
*  -  ulStartAdr     Start address for flash reading
*  -  usSize         Size of data block to be read
*  -  pData          Points to an object that receives the data block
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_read_flash
   (byte ucDevNo, byte ucICNo, ulong ulStartAdr,
   ushort usSize, void* pData);



////////////////////////////////////////////////////////////////////////
// Converting VERSION and DATE CODE



/***********************************************************************
*  ml8_create_version_string
*
*  PURPOSE
*  -  Converts a VERSION CODE to a version string
*  -  String returns with format "AA.B.CCC (X)"
*        AA    Version (p.e. "01")
*        B     Revision (p.e. "A")
*        CCC   Version counter (p.e. "003")
*        X     Version status
*                 F  =  Free release
*                 B  =  Beta
*                 E  =  Eprom OsX release
*                 R  =  Ram Osx release
*
*  PARAMETER
*  -  pacVerStr      Points to the string variable which receives
*                    the converted version string
*  -  ulVerCode      VERSION CODE to convert
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_create_version_string
   (char* pacVerStr, ulong ulVerCode);

/***********************************************************************
*  ml8_create_date_string
*
*  PURPOSE
*  -  Converts a DATE CODE to a date string
*  -  String returns with format "AAA BB/CC/DDDD"
*        AAA   Day of week (p.e. "MON")
*        BB    Day (p.e. "01")
*        CC    Month (p.e. "07")
*        DDDD  Year (p.e. "1997")
*
*  PARAMETER
*  -  pacDateStr     Points to the string variable which receives
*                    the converted date string
*  -  ulDateCode     DATE CODE to convert
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_create_date_string
   (char* pacDateStr, ulong ulDateCode);

/***********************************************************************
*  ml8_create_time_string
*
*  PURPOSE
*  -  Converts a TIME CODE to a time string
*  -  String returns with format "AA:BB:CC"
*        AA    Hours (p.e. "09")
*        BB    Minutes (p.e. "05")
*        CC    Seconds (p.e. "59")
*
*  PARAMETER
*  -  pacTimeStr     Points to the string variable which receives
*                    the converted time string
*  -  ulTimeCode     TIME CODE to convert
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_create_time_string
   (char* pacTimeStr, ulong ulTimeCode);

/***********************************************************************
*  ml8_create_micro_time_string
*
*  PURPOSE
*  -  Converts a MICRO TIME CODE to a micro time string
*  -  String returns with format "AA:BB:CC.DDDEEE"
*        AA    Hours (p.e. "09")
*        BB    Minutes (p.e. "05")
*        CC    Seconds (p.e. "59")
*        DDD   Milliseconds (p.e. "999")
*        EEE   Milliseconds (p.e. "999")
*
*  PARAMETER
*  -  pacTimeStr     Points to the string variable which receives
*                    the converted micro time string
*  -  prcTimeCode    Points to the MICRO TIME CODE to convert
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml8_create_micro_time_string
   (char* pacTimeStr, MICRO_TIME_CODE *prcTimeCode);


////////////////////////////////////////////////////////////////////////
// Converting C and Pascal strings



/***********************************************************************
*  ml_cstr
*
*  PURPOSE
*  -  Copies a PASCAL string to a C string
*  -  Source and destination string address must be different!
*
*  PARAMETER
*  -  pcDest         Points to destination (C) string
*  -  pcSrc          Points to source (Pascal) string
*  -  cMaxLen        Max. string length (incl. one control character)
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml_cstr (char* pcDest, char* pcSrc, byte ucMaxLen);

/***********************************************************************
*  ml_pstr
*
*  PURPOSE
*  -  Copies a C string to a PASCAL string
*  -  Source and destination string address must be different!
*
*  PARAMETER
*  -  pcDest         Points to destination (PASCAL) string
*  -  pcSrc          Points to source (C) string
*  -  cMaxLen        Max. string length (incl. one control character)
*
*  RETURN
*  -  Nothing
***********************************************************************/
ML10API void MLXEXPORT ml_pstr (char* pcDest, char* pcSrc, byte ucMaxLen);

/***********************************************************************
*  ml8_write_dma
*
*  PURPOSE
*  -  writes data to SORCUS board using DMA
*
*  PARAMETER
*  -  pbuffer                                pointer to buffer containing output data
*  -  ulBufferSize                number of bytes to write
*  -  pulBytesWritten        contains number of bytes written when
*                                                                function returns
*  RETURN
*  -  error code,                        see MLXERROR.H
*
*        REQUIREMENTS:
*        -        requires Windows NT or Windows 98 and MLXDRV.SYS/MLXWDM.SYS
*                greater than or equal 7B.003
*        -        DMA must be enabled by registry entry
*        -        only supported by MODULAR-4/486
***********************************************************************/
ML10API USHORT MLXEXPORT ml8_write_dma
        (void *pbuffer, ULONG ulBufferSize, PULONG pulBytesWritten);

/***********************************************************************
*  ml8_read_dma
*
*  PURPOSE
*  -  reads data from SORCUS board using DMA
*
*  PARAMETER
*  -  pbuffer                                pointer to buffer receiving input data
*  -  ulBufferSize                max. number of bytes to read
*  -  pulBytesWritten        contains number of bytes received when
*                                                                function returns
*  RETURN
*  -  error code,                        see MLXERROR.H
*
*        REQUIREMENTS:
*        -        requires Windows NT or Windows 98 and MLXDRV.SYS/MLXWDM.SYS
*                greater than or equal 7B.003
*        -        DMA must be enabled by registry entry
*        -        only supported by MODULAR-4/486
***********************************************************************/
ML10API USHORT MLXEXPORT ml8_read_dma
        (void *pbuffer, ULONG ulBufferSize, PULONG pulBytesRead);

/***********************************************************************
*  ml8_set_search_path
*
*  PURPOSE
*  -  set user defined search path for MDD autoload function
*
*  PARAMETER
*  -  path      buffer containing one or more path names separated by ';'
*
*  RETURN
*  -  TRUE      ok
*  -  FALSE     path too long (more than 1024 bytes)
*
***********************************************************************/
ML10API ULONG   MLXEXPORT   ml8_set_search_path (CHAR *path);

/***********************************************************************
*  ml8_get_config
*
*  PURPOSE
*  -  get sorcus board configuration
*
*  PARAMETER
*  - board      board number
*  - prcParams  board parameter struct to be filled. See MLXW32_T.H
*               prcParams->ulStructSize has to be initialized
*               to sizeof(CONNECTIONPARAMS) before call!
*
*  RETURN
*  -  TRUE      ok
*  -  FALSE     error
*
***********************************************************************/
ML10API BOOL        MLXEXPORT ml8_get_config
        (DWORD board, struct _CONNECTIONPARAMS *prcParams);

/***********************************************************************
*  mlx_chm_init_config
*
*  PURPOSE
*  -  initialize channel manager
*
*  PARAMETER
*  -  pacConfigName     name of configuration file
*
*  RETURN
*  -  0         success
*  -  !=0       error
*
***********************************************************************/
ML10API ULONG MLXEXPORT mlx_chm_init_config(char *pacConfigName);

/***********************************************************************
*
*        mlx_chm_close_config
*
*   PURPOSE
*   - close channel configuration
*   - close configuration file
*
*   RETURN
*   -  0        OK
*   -  !=0      error
*
******************************************************************************/
ML10API ULONG MLXEXPORT mlx_chm_close_config();

/***********************************************************************
*
*        mlx_chm_open_channel
*
*   PURPOSE
*   - open MDD channel using channel manager
*
*   PARAMETER
*   - pacChannelName symbolic channel name
*	- phChannel pointer to  handle
*
*   RETURN
*   -  0        ok
*   -  != 0     error
*
******************************************************************************/
ML10API unsigned long MLXEXPORT mlx_chm_open_channel(char* pacChannelName, HMDD8 *phChannel);

/******************************************************************************
*		mlx_chm_open_channel_callback
*
*	PURPOSE
*		- open MDD callback channel using channel manager
*
*	PARAMETER
*		pacChannelName		name of channel
*		phChannel			pointer to handle
*		pCallbackFunction	pointer to user callback function
*		usMode				mode
*		ulParam				parameter
*
*   RETURN
*   -  0        ok
*   -  != 0     error
*
******************************************************************************/
ML10API unsigned long MLXEXPORT mlx_chm_open_channel_callback(char *pacChannelName, HMDD8 *phChannel, void* pCallbackFunction, unsigned short usMode, unsigned long ulParam);

#if defined(__cplusplus)
}
#endif



#endif  /* !_MLXDRIVER_*/



#endif // !_INC_MLXW32_P