/********************************************************************
*	MLXW32_T.H
*
*	This header files consists some types for the 
*	SORCUS libraries used on following platforms:
*
*	Operating System:		Windows 95
*								Windows NT
*
*	SORCUS Boards:			ML8 - MODULAR-4/486
*								ML6 - Multi-COM
*								ML2 - Multi-LAB/2
*								
*
*  Authors:					Dipl.-Ing. H.Doersam
*								Dipl-Ing. M.Haecker
*
*  Copyrights:				SORCUS Computer GmbH 1995 .. 1998
*								All Rights Reserved
********************************************************************/



#ifndef _INC_MLXW32_T

#define _INC_MLXW32_T



// Callback procedures
typedef void ERROR_PROC (void);        // error handler
typedef void SERVICE_PROC (void);      // interrupt handler

typedef void (*ERROR_PROC_P) (void);   // pointer on error handler
typedef void (*SERVICE_PROC_P) (void); // pointer on interrupt handler



// Type definitions
#ifndef  byte
   #define  byte  unsigned char
#endif

// Handle type for the MODULAR device drivers
typedef  unsigned long  HMDD8;

#define M8BOOL    unsigned char
#define M2BOOL    unsigned char
#define ushort    unsigned short
#define ulong     unsigned long



/*******************************************************************
* The following struct uses byte alignment which is set by the
* 'pragma pack' command
*******************************************************************/
   /* this struct tells us about the reason an error occured */
#ifndef __BORLANDC__
   #pragma pack(push, SORCPACK, 8)
#else
   #pragma option -a8
#endif
typedef struct ml8_error_info_type {
   M8BOOL   ok;                        // =0 if an error occured
   M8BOOL   repeatmacro;               // not used in Windows NT
   /******************************************************************/
   // there are two possibilities to identify errors:
   // 1. identifying by four possible errortypes
   byte     errortype;                 // what error occured? 
                                       // see previous error explanation.
                                       // There are different error
                                       // variables for different error 
                                       // types
   union 
   {                             
      struct 
      {                         // ERROR_SYSTEM
         ulong    error;
      } system;
      struct 
      {                         // ERROR_COMMUNICATION
         byte     errorcode;           
         byte     errorclass;
      } com;
      struct 
      {                         // ERROR_DLL
         byte     errorcode;
         byte     errorclass;
      } dll;
      struct 
      {                         // ERROR_DRV
         ushort   dataoutsize;  
         ushort   retlength;
      } drv;
   };
   // 2. compatible to DOS/Windows 3.1 by using errorcode and -class
   /* if errorclass==7 and errorcode==1: see struct 'system' for more
         information
      if errorclass==7 and errorcode==2: see struct 'drv' for more
         information     */
   byte     errorcode;
   byte     errorclass;          
   /******************************************************************/
   byte     statusport;                // value of status port if an error
                                       // occured
   byte     statusmap;        
                   /* bitmap: !=0 if an error occured:
                      0 = error without calling ml8_clear_error (send)
                      1 = error without calling ml8_clear_error (receive)
                      2 - 6 = reserved
                      7 = library is not initialized 
                   */
   ushort   errorrequest;              // not used in Windows NT
   ushort   sndcount;                  // sended words of a macro command
   ushort   rcvcount;                  // received words of a macro command
   ushort   mark;                      // mark could be set by user
   char     markmessage[80];           // mark string
   ushort   outwords[6];               // not used yet in Windows NT
   ushort   inwords[6];                // not used yet in Windows NT
   ushort   datawords[6];              // not used yet in Windows NT
   char     errormessage[80];          // not used in Windows NT
   ushort   maxerrorretry;             // not used yet in Windows NT
   ushort   errorretry;                // not used yet in Windows NT
} ml8_error_info_typ ;


/**********************************************************************
*  Types and constants for controlling SRQs
**********************************************************************/
typedef struct _SRQRANGE
{
   byte  FirstSrq;                     // first SRQ code to receive
   byte  LastSrq;                      // last SRQ code to receive
} SRQRANGE, *PSRQRANGE;

// log information for macro commands
typedef struct _MLX_LOG_OBJECT 
{
    USHORT   Word;                     // sended word
    UCHAR    Mode;                     // mode: receive or transmit
    UCHAR    ProcessID;                // internal ID of the corresponding
                                       // process
    UCHAR    SrqCount;                 // number of SRQs after this word
    UCHAR    PortState;                // error: state of I/O port
    USHORT   Error;                    // error: errorcode
    LARGE_INTEGER   Time;              // time stamp
    USHORT   WaitTimer;                // loop counter at polling
} MLX_LOG_OBJECT, *PMLX_LOG_OBJECT;

#ifndef __BORLANDC__
   #pragma pack(pop, SORCPACK)            // recover default pragma
#else
   #pragma option -a.
#endif


typedef enum 
{
   SEND_NO_SRQS = 0,
   SEND_ALL_SRQS,
   SEND_SELECTED_SRQS,
   USER_SRQ,
   ERROR_SRQ
   } CONTROL_SRQS;


/**********************************************************************
*  constants for controlling driver information/variables
**********************************************************************/
typedef enum 
{
   PARAMETER_READ=1,
   PARAMETER_WRITE,
   PARAMETER_HARDSTRUCT,
   PARAMETER_HARDWARE,
   PARAMETER_VERSION,
   PARAMETER_SRQ,
   PARAMETER_LOG,
   PARAMETER_HELP,
   PARAMETER_DMATASK,
	PARAMETER_DRIVER
} CONTROL_PARAMETER;


// commands for log procedures
typedef enum 
{
   LOG_GET_BUFFERSIZE=1,
   LOG_GET_NUMBER,
   LOG_GET_MODE,
   LOG_CONTROL_INIT,
   LOG_CONTROL_SIZE,
   LOG_COPY_BUFFER,
   LOG_READ_BUFFER,
   LOG_CLEAR_BUFFER,
	LOG_CONTROL_TIME,
	LOG_CONTROL_BUFSIZE
} CONTROL_LOG;


#ifndef __BORLANDC__
   #pragma pack(push, SORCPACK, 1)
#else
   #pragma option -a1
#endif

typedef struct _MICRO_TIME_CODE
{
	byte		ucRes;				//	Reserved
	byte		ucHours;				//	Hours (0..23)
	byte		ucMinutes;			//	Minutes (0..59)
	byte		ucSec;				//	Seconds (0..59)
	ushort	usMilliSec;			//	Milliseconds (0..999)
	ushort	usMicroSec;			//	Microseconds (0..999)
} MICRO_TIME_CODE, *PMICRO_TIME_CODE;

/**********************************************************************
*  new types needed for functions ml8_get_config / ml8_put_config     *
*  added in Version 7.C.000														 *
**********************************************************************/

typedef struct _LOCAL_BOARD_PARAMS
{
	ULONG ulBoardAddress;
	ULONG ulBoardInterrupt;
	ULONG ulBoardDMA;
	ULONG	ulPollCount;
}
LOCAL_BOARD_PARAMS, *PLOCAL_BOARD_PARAMS;

typedef struct _SERIAL_BOARD_PARAMS
{
	ULONG	ulSerialPort;
	ULONG	ulSerialSpeed;
	ULONG	ulSerialPCParam;
	ULONG	ulSerialRTParam;
	ULONG ulSerialBlockSize;
}
SERIAL_BOARD_PARAMS, *PSERIAL_BOARD_PARAMS;

typedef struct _REMOTE_BOARD_PARAMS
{
	CHAR	szServerName [32];
	ULONG	ulConnectionNumber;
}
REMOTE_BOARD_PARAMS, *PREMOTE_BOARD_PARAMS;

typedef struct _CONNECTIONPARAMS
{
	ULONG	ulStructSize;
	ULONG	ulStructVersion;

	ULONG	ulConnectionType;
	ULONG	ulBoardType;
	
	union
	{
		LOCAL_BOARD_PARAMS	local;
		SERIAL_BOARD_PARAMS	serial;
		REMOTE_BOARD_PARAMS	remote;
		CHAR						fill [52];
	};
	ULONG	ulAuthnLevel;
	ULONG	ulVirtualBase;
	ULONG	ulVirtualInterrupt;
}
CONNECTIONPARAMS, *PCONNECTIONPARAMS;

#define MAX_CONNECTIONS	16

#define CONNECT_STRUCT_TYPE 3

enum
{
	RCONF_TYPE_UNUSED = 0xFFFFFFFF,
	RCONF_TYPE_LOCAL_MLXDRV = 0,
	RCONF_TYPE_SERIAL, 
	RCONF_TYPE_REMOTE_SERVER
};

#ifndef __BORLANDC__
   #pragma pack(pop, SORCPACK)            // recover default pragma
#else
   #pragma option -a.
#endif

#endif // !_INC_MLXW32_T

