{********************************************************************
*  This is the source file to build the libraries for following
*  platforms:
*
*  Board:               ML2 - Multi-LAB/2
*                       ML6 - Multi-COM
*                       ML7 - small MODULAR-4/486
*                       ML8 - long MODULAR-4/486
*
*  Operating Systems:   Windows 95
*                          (file has to be named 'fmlXbib.pas',
*                          where X = 2, 6, 7 or 8)
*                       Windows NT
*                          (file has to be named 'nmlXbib.pas',
*                          where X = 2, 6, 7 or 8)
*                       Windows32 (NT & 95)
*                          (file has to be named 'mlxw32.pas')
*
*  Author:              HD, JD
*
*  Last Change:         22/03/99
*  (bug: for ML7 the ml6int.inc and ml6imp.inc were included,
*        now ml7int.inc and ml7imp.inc are included)
*
*  Copyrights           SORCUS Computer GmbH 1998-99
*                       All rights reserved
*
********************************************************************}



{********************************************************************
*
*  Defines for Preprocessor:
*
*  Platform specification:
*  _WIN_95_    To build the library for Windows 95
*              (additional card specification necessary)
*  _WIN_NT_    To build the library for Windows NT
*              (additional card specification necessary)
*  _MLXW32_    To build the MLXW32 library for Windows 95
*              and Windows NT and for all cards
*
*  Card specification:
*  _ML2_       To build the library for the ML2 card
*  _ML6_       To build the library for the ML6 card
*  _ML7_       To build the library for the ML6 card
*  _ML8_       To build the library for the ML8 card
*
********************************************************************}

{$ifdef _WIN_95_}

{$ifdef _ML2_}
UNIT FML2BIB;
INTERFACE
USES FML2TYPE, SYSUTILS, WINPROCS;
{$endif}

{$ifdef _ML6_}
UNIT FML6BIB;
INTERFACE
USES FML6TYPE, SYSUTILS, WINPROCS;
{$endif}

{$ifdef _ML7_}
UNIT FML7BIB;
INTERFACE
USES FML7TYPE, SYSUTILS, WINPROCS;
{$endif}

{$ifdef _ML8_}
UNIT FML8BIB;
INTERFACE
USES FML8TYPE, SYSUTILS, WINPROCS;
{$endif}

{$endif}


{$ifdef _WIN_NT_}

{$ifdef _ML2_}
UNIT NML2BIB;
INTERFACE
USES NML2TYPE, SYSUTILS, WINPROCS;
{$endif}

{$ifdef _ML6_}
UNIT NML6BIB;
INTERFACE
USES NML6TYPE, SYSUTILS, WINPROCS;
{$endif}

{$ifdef _ML7_}
UNIT NML7BIB;
INTERFACE
USES NML7TYPE, SYSUTILS, WINPROCS;
{$endif}

{$ifdef _ML8_}
UNIT NML8BIB;
INTERFACE
USES NML8TYPE, SYSUTILS, WINPROCS;
{$endif}
{$endif}

{$ifdef _MLXW32_}
UNIT MLXW32;
INTERFACE
USES MLXTYPE, SYSUTILS, WINPROCS;
{$endif}


CONST

{********************************************************************
*   DLL REFERENCE
********************************************************************}
{$ifdef _WIN_95_}
   DLL_REF                             = 'FMLXBIB.DLL';
{$endif}

{$ifdef _WIN_NT_}
   DLL_REF                             = 'NMLXBIB.DLL';
{$endif}

{$ifdef _MLXW32_}
   DLL_REF                             = 'MLXW32.DLL';
{$endif}



   NUMBEROFCARDS                       = 8;
   LANGUAGE_C                          = $200;
   LANGUAGE_PASCAL                     = $100;

   PARITY_NO                           = 0;
   PARITY_ODD                          = 1;
   PARITY_EVEN                         = 2;

   ALLOC_GET_SIZE                      = 0;
   ALLOC_UP_ABS                        = 1;
   ALLOC_UP_MAX                        = 2;
   ALLOC_DOWN_ABS                      = 3;
   ALLOC_DOWN_MAX                      = 4;

   BUFFER_ALL_OR_NOTHING               = 0;
   BUFFER_MAXIMUM                      = 1;
   BUFFER_COPY                         = 2;
   BUFFER_TRY_MULTIPLE                 = 4;

   FLASH_GET_CUSTOMER_ID               = $00;
   FLASH_GET_DEVICE_ID                 = $01;
   FLASH_GET_SIZE_INFO                 = $02;
   FLASH_GET_ORGANIZATION              = $03;
   FLASH_CHECK_WRITE_PROTECTED         = $04;
   FLASH_GET_ERASE_STATUS              = $05;
   FLASH_COPY_EPROM                    = $06;
   FLASH_GET_SOFT_STATE                = $0A;
   FLASH_ERASE_ENABLE                  = $0B;
   FLASH_ERASE_DISABLE                 = $0C;
   FLASH_PROGRAM_ENABLE                = $0D;
   FLASH_PROGRAM_DISABLE               = $0E;

   WATCH_ERR_STATUS                    = 0;
   WATCH_ERR_CLASS                     = 1;
   WATCH_ERR_CODE                      = 2;
   WATCH_ERR_STATUS_PORT               = 3;
   WATCH_ERR_STATUS_MAP                = 4;
   WATCH_ERR_SYSTEM                    = 5;
   WATCH_ERR_DRV_OUT_SIZE              = 6;
   WATCH_ERR_DRV_IN_SIZE               = 7;

   STARTUP_DONE: BOOLEAN               = FALSE;
   OS_TASK                             = 0;
   EEPROM_PAR                          = 100;

{********************************************************************
*  INTERFACE
********************************************************************}

PROCEDURE   ml_cstr
            (VAR pDestStr; VAR pSrcStr; ucMaxLen: BYTE);
            {$ifndef _MLXW32_} cdecl; {$else} stdcall; {$endif}

PROCEDURE   ml_pstr
            (VAR pDestStr; VAR pSrcStr; ucMaxLen: BYTE);
            {$ifndef _MLXW32_} cdecl; {$else} stdcall; {$endif}

FUNCTION    Cmlx_chm_init_config (pCfgName : PChar): LONGINT;
            {$ifndef _MLXW32_} cdecl; {$else} stdcall; {$endif}

FUNCTION    mlx_chm_init_config (pCfgName : STRING): LONGINT;

FUNCTION    Cmlx_chm_open_channel (pChannelName : PChar; VAR phChannel : HMDD8): LONGINT;
            {$ifndef _MLXW32_} cdecl; {$else} stdcall; {$endif}

FUNCTION    mlx_chm_open_channel (pChannelName : STRING; VAR phChannel : HMDD8): LONGINT;

FUNCTION    Cmlx_chm_open_channel_callback (pChannelName : PChar; VAR phChannel : HMDD8;
                                            pCallbackFunction : POINTER; usMode : WORD; ulParam : LONGINT): LONGINT;
            {$ifndef _MLXW32_} cdecl; {$else} stdcall; {$endif}

FUNCTION    mlx_chm_open_channel_callback (pChannelName : STRING; VAR phChannel : HMDD8;
                                           pCallbackFunction : POINTER; usMode : WORD; ulParam : LONGINT) : LONGINT;

FUNCTION    mlx_chm_close_config : LONGINT;
            {$ifndef _MLXW32_} cdecl; {$else} stdcall; {$endif}

{$ifdef _ML2_}
{$I ml2int.inc}
{$endif}

{$ifdef _ML6_}
{$I ml6int.inc}
{$endif}

{$ifdef _ML7_}
{$I ml7int.inc}
{$endif}

{$ifdef _ML8_}
{$I ml8int.inc}
{$endif}

{$ifdef _MLXW32_}
{$I ml2int.inc}
{$I ml6int.inc}
{$I ml7int.inc}
{$I ml8int.inc}
{$endif}


{********************************************************************
*  IMPLEMENTATION
********************************************************************}
IMPLEMENTATION


PROCEDURE   ml_cstr
            (VAR pDestStr; VAR pSrcStr; ucMaxLen: BYTE);
            EXTERNAL DLL_REF;

PROCEDURE   ml_pstr
            (VAR pDestStr; VAR pSrcStr; ucMaxLen: BYTE);
            EXTERNAL DLL_REF;

FUNCTION    Cmlx_chm_init_config (pCfgName : PChar): LONGINT;
            EXTERNAL DLL_REF NAME 'mlx_chm_init_config';

FUNCTION    mlx_chm_init_config (pCfgName : STRING): LONGINT;
VAR   acCfg   :  ARRAY [0..255] OF CHAR;
BEGIN
   ml_cstr(acCfg, pCfgName, 255);
   mlx_chm_init_config := Cmlx_chm_init_config (acCfg);
END;

FUNCTION    Cmlx_chm_open_channel (pChannelName : PChar; VAR phChannel : HMDD8) : LONGINT;
            EXTERNAL DLL_REF NAME 'mlx_chm_open_channel';

FUNCTION    mlx_chm_open_channel (pChannelName : STRING; VAR phChannel : HMDD8) : LONGINT;
VAR   acChannel   :  ARRAY [0..255] OF CHAR;
BEGIN
   ml_cstr(acChannel, pChannelName, 255);
   mlx_chm_open_channel := Cmlx_chm_open_channel (acChannel, phChannel);
END;

FUNCTION    Cmlx_chm_open_channel_callback (pChannelName : PChar; VAR phChannel : HMDD8;
                                            pCallbackFunction : POINTER; usMode : WORD; ulParam : LONGINT): LONGINT;
            EXTERNAL DLL_REF NAME 'mlx_chm_open_channel_callback';

FUNCTION    mlx_chm_open_channel_callback (pChannelName : STRING; VAR phChannel : HMDD8;
                                           pCallbackFunction : POINTER; usMode : WORD; ulParam : LONGINT) : LONGINT;
VAR   acChannel   :  ARRAY [0..255] OF CHAR;
BEGIN
   ml_cstr(acChannel, pChannelName, 255);
   mlx_chm_open_channel_callback := Cmlx_chm_open_channel_callback
                                 (acChannel, phChannel, pCallbackFunction, usMode, ulParam);
END;

FUNCTION    mlx_chm_close_config : LONGINT;
            EXTERNAL DLL_REF;

{$ifdef _ML2_}
{$I ml2imp.inc}
{$endif}

{$ifdef _ML6_}
{$I ml6imp.inc}
{$endif}

{$ifdef _ML7_}
{$I ml7imp.inc}
{$endif}

{$ifdef _ML8_}
{$I ml8imp.inc}
{$endif}

{$ifdef _MLXW32_}
{$I ml2imp.inc}
{$I ml6imp.inc}
{$I ml7imp.inc}
{$I ml8imp.inc}
{$endif}



{********************************************************************
*  INITIALIZATION
********************************************************************}

BEGIN

END.