{********************************************************************
*  MDDCPS.PAS
*
*  This is a source file for the SORCUS libraries (all platforms,
*  all boards). It defines the channel property structures (CPS)
*  and constants for the MODULAR-Device-Drivers (MDD).
*
*  Author         Dipl.-Ing. H.Doersam
*
*  Last change    See HISTORY
*
*  (C) SORCUS Computer GmbH 1997 .. 1998
*      All rights reserved
********************************************************************}

{********************************************************************

   Defines for Preprocessor:

   __RT__         Must be done exclusive for real-time-projects

********************************************************************}



{

                           !!! IMPORTANT !!!

   This file defines some data structures that must be included with
   BYTE alignment.

}


{********************************************************************
*
*  HISTORY
*
*  17/02/00 BUILD 0x64021104 (JD)
*                - support for M-CAN-1 (CPS_MCAN1) and Message-MDD
*                - new constants:
*                  CAN_BUS_ON; CAN_BUS_OFF; CAN_BUS_HEAVY
*                  CAN_BUS_CTRL_INDEX, CAN_ERR_CTRL_INDEX
*                  _CAN_NO_INT, _CAN_EXCL_BUFFER
*                  CAN_REMOTE_FRAME
*                  CAN_DATA_VALID, CAN_MSG_ACTIVE, CAN_MSG_LOST, CAN_DOUBLE_REQ
*                  DIAG_WRONG_EEPROM_WORD,
*                  CTRL_SET_CB_CHANNEL, CBP_SYNC_CALL
*                  DEVICE_CAN_IN, DEVICE_CAN_OUT
*
*  08/05/98 BUILD $62050804 (HD)
*     -  New constants
*        ERR_MDD_WRONG_OSX
*        _CP_NO_FLAGS
*        _MC163_NO_TIME
*     -  BUG: Wrong defines for constants _MC163_FREEZE_DIN_...
*
*  27/04/98 BUILD $62041B01 (HD)
*     -  New constant
*        CDT_ID_CHANNEL_VALID
*
*  17/04/98 BUILD $62041105 (HD)
*     -  Support of MDD for module M-AX-32/SSI
*     -  Support of MDD for 5B panels
*
*  09/04/98 BUILD $62040904 (HD)
*     -  New constant
*        DEVICE_SSI
*
*  18/03/98 BUILD $62031203 (HD)
*     -  Support of MDD for Multi-LAB/2 board
*     -  Error in constants for M-DC15-2
*        (.._IPx_... replaced by .._IP_x_...)
*
*  11/03/98 BUILD $62030B03 (HD)
*     -  All CPS structure redefined
*
*  09/03/98 BUILD $62030901 (HD)
*     -  Support of MDD for module M-AD16-3
*
*  03/03/98 BUILD $62030302 (HD)
*     -  Support of MDD for 5Bx64 panels
*     -  New constants for M-D40-2
*     -  New constants
*        DSC_SHARED_MAX
*        DSC_IS_NOT_AVAILABLE
*        DSC_IS_LOCKED
*
*  26/02/98 BUILD $62021A04 (HD)
*     -  New constants
*        ML8_WATCHDOG_x
*        DIAG_DATA_LOST
*     -  BUGFIX: Wrong values for constants INFO_x corrected
*
*  17/02/98 BUILD $62021102 (HD)
*     -  New constants DIAG_xxx (diagnosis words)
*
*  11/02/98 BUILD $62020B03 (HD)
*     -  New constants for M-SH12-8
*
*  10/02/98 BUILD $62020A02 (HD)
*     -  File consists all constants for the MDDs
*
*  09/02/98 BUILD $62020901 (HD)
*     -  Support of MDD for following modules:
*        M-DC15-2, M-C16-3, ML8 (Base Board)
*     -  Redefinition of CPS CPS_MSH128
*     -  Redefinition of CPS CPS_MOPT1B
*     -  Redefinition of CPS CPS_MRU82
*
*  25/09/97 BUILD $61091904 (HD)
*     -  Creation of this file
*     -  Support of MDDs fir following modules:
*        M-D40-2, M-OPT-1/A, M-OPT-1/B, M-RU8-2, M-AD16-4, M-DA16-2,
*        M-DA2-2, M-DA4-2, M-AD12-16, M-SH12-8, M-5B-1/U
*
********************************************************************}


UNIT     MDDCPS;


INTERFACE


CONST

         { Date of build this file }

         BUILD_MDDCPS                     : LONGINT = $64021104;


         { Commands for mdd8_send_channel_command }
         { Do not use CMD_CLOSE, use instead mdd8_close_channel! }

         CMD_CLOSE                        : WORD = $A0;
         CMD_SUSP_WRITE                   : WORD = $A1;
         CMD_CONT_WRITE                   : WORD = $A2;
         CMD_SUSP_READ                    : WORD = $A3;
         CMD_CONT_READ                    : WORD = $A4;
         CMD_RESET                        : WORD = $A5;
         CMD_START                        : WORD = $A6;
         CMD_STOP                         : WORD = $A7;
         CMD_CONTINUE                     : WORD = $A8;
         CMD_LATCH_OUT                    : WORD = $A9;
         CMD_LATCH_IN                     : WORD = $AA;


         { Commands for mdd8_send_channel_control }

         CTRL_DEVICE                      : WORD = $60;
         CTRL_RW_PTR                      : WORD = $61;
         CTRL_R_PTR                       : WORD = $62;
         CTRL_W_PTR                       : WORD = $63;
         CTRL_SET_CB_CHANNEL              : WORD = $64;


         { Commands for mdd8_send_channel_control_block }

               {  Do not use CTRL_CAPTION,
                  use instead mdd8_set_channel_caption! }

         CTRL_CAPTION                     : WORD = $90;


         { Commands for mdd8_get_channel_info }

         INFO_STATUS                      : WORD = $40;
         INFO_DATA_TYPE                   : WORD = $42;
         INFO_TRANSFER_MODE               : WORD = $43;
         INFO_MINSIZE                     : WORD = $44;
         INFO_MAXSIZE                     : WORD = $45;
         INFO_RANGE                       : WORD = $46;
         INFO_RESOLUTION                  : WORD = $47;
         INFO_DEVICE                      : WORD = $48;
         INFO_RW_PTR                      : WORD = $50;
         INFO_R_PTR                       : WORD = $51;
         INFO_W_PTR                       : WORD = $52;


         { Commands for mdd8_get_channel_info_block }

               {  Do not use INFO_CAPTION,
                  use instead mdd8_get_channel_caption! }

         INFO_CAPTION                     : WORD = $80;


         { Infotextures }

         ITNO_DEVICE_NAME                 : WORD = $0000;
         ITNO_DEVICE_REVISION             : WORD = $0100;
         ITNO_FIRM_NAME                   : WORD = $0001;
         ITNO_AUTHOR_NAME                 : WORD = $0101;


         { Constant for mdd8_get_device_status }

         DSC_SHARED_MAX                   : WORD = $FFF0;
         DSC_IS_NOT_AVAILABLE             : WORD = $FFF1;
         DSC_IS_LOCKED                    : WORD = $FFF2;
         DSC_IS_EXCLUSIVE                 : WORD = $FFFF;

         { Returns of command INFO_DATA_TYPE }

         DATA_VOID                        : LONGINT = $00000001;
         DATA_BIT                         : LONGINT = $00000002;
         DATA_BYTE                        : LONGINT = $00000003;
         DATA_CHAR                        : LONGINT = $00000004;
         DATA_WORD                        : LONGINT = $00000005;
         DATA_SHORT                       : LONGINT = $00000006;
         DATA_DWORD                       : LONGINT = $00000007;
         DATA_LONG                        : LONGINT = $00000008;
         DATA_BLOCK                       : LONGINT = $00000009;
         DATA_STREAM                      : LONGINT = $0000000A;


         { Returns of command INFO_TRANSFER_MODE }

         R_MODE                           : LONGINT = $00000001;
         W_MODE                           : LONGINT = $00000002;
         RW_MODE                          : LONGINT = $00000003;
         CALLBACK_MODE                    : LONGINT = $00000004;


         { Returns of command INFO_RANGE }

         RNG_VOID                         : LONGINT = $00000001;
         RNG_UPP_312MV5                   : LONGINT = $00000021;
         RNG_UPP_625MV                    : LONGINT = $00000022;
         RNG_UPP_1V25                     : LONGINT = $00000023;
         RNG_UPP_2V5                      : LONGINT = $00000024;
         RNG_UPP_5V                       : LONGINT = $00000025;
         RNG_UPP_10V                      : LONGINT = $00000026;
         RNG_UPN_312MV5                   : LONGINT = $00000041;
         RNG_UPN_625MV                    : LONGINT = $00000042;
         RNG_UPN_1V25                     : LONGINT = $00000043;
         RNG_UPN_2V5                      : LONGINT = $00000044;
         RNG_UPN_5V                       : LONGINT = $00000045;
         RNG_UPN_10V                      : LONGINT = $00000046;
         RNG_BIP_312MV5                   : LONGINT = $00000061;
         RNG_BIP_625MV                    : LONGINT = $00000062;
         RNG_BIP_1V25                     : LONGINT = $00000063;
         RNG_BIP_2V5                      : LONGINT = $00000064;
         RNG_BIP_5V                       : LONGINT = $00000065;
         RNG_BIP_10V                      : LONGINT = $00000066;
         RNG_20MA                         : LONGINT = $00000081;


         { Returns of command INFO_STATUS }

         _CSR_EXCLUSIVE                   : LONGINT = $00000001;
         _CSR_HW_FORMAT                   : LONGINT = $00000002;
         _CSR_UNCORRECTED                 : LONGINT = $00000004;
         _CSR_OUT_SUSP                    : LONGINT = $00010000;
         _CSR_IN_SUSP                     : LONGINT = $00020000;


         { Device types }

         DEVICE_DIN                       : WORD = $0101;
         DEVICE_DOUT                      : WORD = $0102;
         DEVICE_DIO                       : WORD = $0103;
         DEVICE_AIN_SE                    : WORD = $0201;
         DEVICE_AIN_DIFF                  : WORD = $0202;
         DEVICE_AOUT                      : WORD = $0203;
         DEVICE_TRIG                      : WORD = $0301;
         DEVICE_CTRL                      : WORD = $0401;
         DEVICE_LED                       : WORD = $0402;
         DEVICE_TIMER                     : WORD = $0501;
         DEVICE_WATCHDOG                  : WORD = $0503;
         DEVICE_COUNTER                   : WORD = $0601;
         DEVICE_CLOCK                     : WORD = $0701;
         DEVICE_CALENDAR                  : WORD = $0702;
         DEVICE_SCC                       : WORD = $0801;
         DEVICE_SQRWAVE                   : WORD = $0901;
         DEVICE_EEPROM                    : WORD = $0A01;
         DEVICE_HW_INT                    : WORD = $0B01;
         DEVICE_SSI                       : WORD = $0C01;
         DEVICE_BUS_IN                    : WORD = $0D01;
         DEVICE_BUS_OUT                   : WORD = $0D02;
         DEVICE_ALARM                     : WORD = $0F01;


         { Range adjustment }

         RANGE_VOID                       : WORD = $0001;
         RANGE_UPP_312MV5                 : WORD = $0021;
         RANGE_UPP_625MV                  : WORD = $0022;
         RANGE_UPP_1V25                   : WORD = $0023;
         RANGE_UPP_2V5                    : WORD = $0024;
         RANGE_UPP_5V                     : WORD = $0025;
         RANGE_UPP_10V                    : WORD = $0026;
         RANGE_UPN_312MV5                 : WORD = $0041;
         RANGE_UPN_625MV                  : WORD = $0042;
         RANGE_UPN_1V25                   : WORD = $0043;
         RANGE_UPN_2V5                    : WORD = $0044;
         RANGE_UPN_5V                     : WORD = $0045;
         RANGE_UPN_10V                    : WORD = $0046;
         RANGE_BIP_312MV5                 : WORD = $0061;
         RANGE_BIP_625MV                  : WORD = $0062;
         RANGE_BIP_1V25                   : WORD = $0063;
         RANGE_BIP_2V5                    : WORD = $0064;
         RANGE_BIP_5V                     : WORD = $0065;
         RANGE_BIP_10V                    : WORD = $0066;
         RANGE_20MA                       : WORD = $0081;


         { Flags in CPS }

         _CP_NO_FLAGS                     : WORD = $0000;
         _CP_EXCLUSIVE                    : WORD = $0001;
         _CP_HW_FORMAT                    : WORD = $0002;
         _CP_UNCORRECTED                  : WORD = $0004;

         { flag for the 'mode' parameter in mdd_open_channel_callback }

         CBP_SYNC_CALL                    : WORD = 2;        {synchronous callback without buffer (RT-only)}


         { Read/Write modes in CPS }

         IO_MODE_DIRECT                   : WORD = $0001;
         IO_MODE_LATCH                    : WORD = $0002;
         IO_MODE_RAM                      : WORD = $0004;
         IO_MODE_RAM_LATCH                : WORD = $0006;


         { Commands for mdd8_scan_channel }

         SCAN_SERVICE_LIST                : WORD = 1;
         SCAN_CDT                         : WORD = 2;
         SCAN_HANDLE                      : WORD = 3;
         SCAN_CPS                         : WORD = 4;
         SCAN_PARAMETER                   : WORD = 5;
         SCAN_MSG_OBJ                     : WORD = 11;      { for can channels }


         { Size of CDT header }

         CDT_HEADER_SIZE                  = 60;


         { ID of a valid channel-descriptor-table (CDT) }

         CDT_ID_CHANNEL_VALID             = $55;


         { Handle of a closed channel }

         MDD_NULL_HANDLE                  : LONGINT = $00000000;


         { Error codes from MDD }

{$ifdef __RT__}
         ERR_MDD_HANDLE_INVALID           : WORD = $40E0;
         ERR_MDD_WRONG_DATA_TYPE          : WORD = $41E0;
         ERR_MDD_DRV_SERVICE              : WORD = $42E0;
         ERR_MDD_CHANNEL_SERVICE          : WORD = $43E0;
         ERR_MDD_SERVICE_NOT_AVAILABLE    : WORD = $44E0;
         ERR_MDD_DRV_NOT_INSTALLED        : WORD = $45E0;
         ERR_MDD_UNKNOWN_ERROR            : WORD = $46E0;
{$else}
         ERR_MDD_HANDLE_INVALID           : BYTE = $40;
         ERR_MDD_WRONG_DATA_TYPE          : BYTE = $41;
         ERR_MDD_DRV_SERVICE              : BYTE = $42;
         ERR_MDD_CHANNEL_SERVICE          : BYTE = $43;
         ERR_MDD_SERVICE_NOT_AVAILABLE    : BYTE = $44;
         ERR_MDD_DRV_NOT_INSTALLED        : BYTE = $45;
         ERR_MDD_UNKNOWN_ERROR            : BYTE = $46;
         ERR_MDD_WRONG_OSX                : BYTE = $01;
{$endif}

         { Diagnosis words }

         DIAG_NO_ERROR                    : WORD = $0000;
         DIAG_CALL_WITHOUT_EFFECT         : WORD = $0001;
         DIAG_WRONG_PARAMETER             : WORD = $0100;
         DIAG_WRONG_PARAMETER_MAX         : WORD = $01FF;
         DIAG_WRONG_NUMBER_OF_INPUTS      : WORD = $0201;
         DIAG_ABOVE_NUMBER_OF_INPUTS      : WORD = $0202;
         DIAG_BELOW_NUMBER_OF_INPUTS      : WORD = $0203;
         DIAG_WRONG_NUMBER_OF_RETURNS     : WORD = $0211;
         DIAG_ABOVE_NUMBER_OF_RETURNS     : WORD = $0212;
         DIAG_BELOW_NUMBER_OF_RETURNS     : WORD = $0213;
         DIAG_FUNCTION_LOCKED             : WORD = $0221;
         DIAG_RANGE_CROSS_OVER            : WORD = $0321;
         DIAG_RANGE_CROSS_UNDER           : WORD = $0322;
         DIAG_DATA_IMPOSSIBLE             : WORD = $0323;
         DIAG_END_OF_DATA                 : WORD = $0324;
         DIAG_MISSING_NULL_TERMINATION    : WORD = $0331;
         DIAG_NOT_ENOUGH_MEMORY           : WORD = $0401;
         DIAG_BUFFER_EMPTY                : WORD = $0411;
         DIAG_BUFFER_FULL                 : WORD = $0412;
         DIAG_HARDWARE_CONFLICT           : WORD = $0501;
         DIAG_TIMEOUT                     : WORD = $0502;
         DIAG_DATA_LOST                   : WORD = $0503;
         DIAG_WRONG_EEPROM_WORD           : WORD = $0504;  {* hardware init according to eeprom not possible *}
         DIAG_DEVICE_NOT_AVAILABLE        : WORD = $0511;
         DIAG_DEVICE_ALREADY_IN_USE       : WORD = $0512;
         DIAG_CHANNEL_NOT_FOUND           : WORD = $0531;
         DIAG_INFOTEXT_NOT_AVAILABLE      : WORD = $0541;
         DIAG_NO_CAPTION_BUFFER           : WORD = $0551;
         DIAG_CPS_NOT_SUPPORTED           : WORD = $0561;
         DIAG_RTC_WRITE_ACCESS            : WORD = $0601;
         DIAG_RTC_READ_ACCESS             : WORD = $0602;
         DIAG_EEPROM_WRITE_ACCESS         : WORD = $0603;
         DIAG_EEPROM_READ_ACCESS          : WORD = $0604;
         DIAG_INVALID                     : WORD = $FFFF;



         { Some module specific constants ... }


         { M-D40-2 }

         _MD402_OUTPUT_ENABLE_0_7         : BYTE = $01;
         _MD402_OUTPUT_ENABLE_8_15        : BYTE = $02;
         _MD402_OUTPUT_ENABLE_16_23       : BYTE = $04;
         _MD402_OUTPUT_ENABLE_24_31       : BYTE = $08;
         _MD402_OUTPUT_ENABLE_32_39       : BYTE = $10;
         _MD402_OUTPUT_DISABLE_0_7        : BYTE = $00;
         _MD402_OUTPUT_DISABLE_8_15       : BYTE = $00;
         _MD402_OUTPUT_DISABLE_16_23      : BYTE = $00;
         _MD402_OUTPUT_DISABLE_24_31      : BYTE = $00;
         _MD402_OUTPUT_DISABLE_32_39      : BYTE = $00;

         _MD402_POS_TRIGGER               : BYTE = $01;
         _MD402_NEG_TRIGGER               : BYTE = $00;
         _MD402_EXT_TRIGGER               : BYTE = $02;
         _MD402_SOFT_TRIGGER              : BYTE = $00;

         _MD402_ENABLE_INT_0              : BYTE = $01;
         _MD402_ENABLE_INT_1              : BYTE = $02;
         _MD402_ENABLE_INT_2              : BYTE = $04;
         _MD402_ENABLE_INT_3              : BYTE = $08;
         _MD402_DISABLE_INT_0             : BYTE = $00;
         _MD402_DISABLE_INT_1             : BYTE = $00;
         _MD402_DISABLE_INT_2             : BYTE = $00;
         _MD402_DISABLE_INT_3             : BYTE = $00;

         MD402_OUTPUT_CTRL                : WORD = 0;
         MD402_TRIG_CTRL                  : WORD = 1;
         MD402_INT_CTRL                   : WORD = 2;
         MD402_SAMPLE_TRIGGER             : WORD = 0;


         { M-OPT-1/A }

         _MOPT1A_CON_DIN_0_IRQ_E          : BYTE = $01;
         _MOPT1A_CON_DIN_1_IRQ_B          : BYTE = $02;


         { M-OPT-1/B }

         _MOPT1B_ENABLE_DOUT_0_15         : BYTE = $01;

         _MOPT1B_WATCHDOG_ENABLE          : BYTE = $02;
         _MOPT1B_CON_WATCHDOG_IRQ_B       : BYTE = $01;


         { M-RU8-2 }

         MRU82_MODE_0                     : BYTE = $00;
         MRU82_MODE_1                     : BYTE = $01;
         MRU82_MODE_2                     : BYTE = $02;
         MRU82_MODE_3                     : BYTE = $03;


         { M-SH12-8 }

         MSH128_SW_EXT_DIG_TRIG           : BYTE = $00;
         MSH128_SW_TIMER_A                : BYTE = $01;
         MSH128_TIMER_A_POS_EXT_DIG_TRIG  : BYTE = $02;
         MSH128_TIMER_A_POS_TIMER_A       : BYTE = $03;
         MSH128_TIMER_A_NEG_EXT_DIG_TRIG  : BYTE = $04;
         MSH128_TIMER_A_NEG_TIMER_A       : BYTE = $05;
         MSH128_EXT_DIG_POS_EXT_DIG_TRIG  : BYTE = $06;
         MSH128_EXT_DIG_NEG_EXT_DIG_TRIG  : BYTE = $07;
         MSH128_SW_EXT_AN_TRIG            : BYTE = $08;
         MSH128_TIMER_A_POS_EXT_AN_TRIG   : BYTE = $0A;
         MSH128_TIMER_A_NEG_EXT_AN_TRIG   : BYTE = $0C;
         MSH128_EXT_AN_TRIG_A_EXT_AN_TRIG : BYTE = $0E;
         MSH128_EXT_AN_TRIG_B_EXT_AN_TRIG : BYTE = $0F;

         MSH128_NONE                      : BYTE = $00;
         MSH128_IRQ_B                     : BYTE = $05;
         MSH128_IRQ_C                     : BYTE = $06;
         MSH128_IRQ_D                     : BYTE = $07;



         { M-DC15-2 }

         _MDC152_LED_0_ON                 : BYTE = $01;
         _MDC152_LED_1_ON                 : BYTE = $02;
         _MDC152_LED_2_ON                 : BYTE = $04;
         _MDC152_LED_3_ON                 : BYTE = $08;
         _MDC152_LED_4_ON                 : BYTE = $10;
         _MDC152_LED_5_ON                 : BYTE = $20;
         _MDC152_LED_6_ON                 : BYTE = $40;
         _MDC152_LED_7_ON                 : BYTE = $80;

         _MDC152_CON_IP_0_IRQ_B           : BYTE = $01;
         _MDC152_CON_IP_1_IRQ_E           : BYTE = $02;
         _MDC152_CON_IP_2_IRQ_C           : BYTE = $04;
         _MDC152_CON_IP_3_IRQ_D           : BYTE = $08;


         { M-C16-3 }

         _MC163_NO_IRQ                    : BYTE = $00;
         _MC163_IRQ_A                     : BYTE = $01;
         _MC163_IRQ_B                     : BYTE = $02;
         _MC163_IRQ_C                     : BYTE = $03;
         _MC163_IRQ_D                     : BYTE = $04;
         _MC163_IRQ_E                     : BYTE = $05;
         _MC163_IRQ_F                     : BYTE = $06;
         _MC163_NMI                       : BYTE = $07;
         _MC163_IRQ_POS_EDGE              : BYTE = $00;
         _MC163_IRQ_NEG_EDGE              : BYTE = $10;

         _MC163_DEMASK_INT_0              : LONGINT = $00000001;
         _MC163_DEMASK_INT_1              : LONGINT = $00000002;
         _MC163_DEMASK_INT_2              : LONGINT = $00000004;
         _MC163_DEMASK_INT_3              : LONGINT = $00000008;
         _MC163_DEMASK_INT_4              : LONGINT = $00000010;
         _MC163_DEMASK_INT_5              : LONGINT = $00000020;
         _MC163_DEMASK_INT_6              : LONGINT = $00000040;
         _MC163_DEMASK_INT_7              : LONGINT = $00000080;
         _MC163_DEMASK_INT_8              : LONGINT = $00000100;
         _MC163_DEMASK_INT_9              : LONGINT = $00000200;
         _MC163_DEMASK_INT_10             : LONGINT = $00000400;
         _MC163_DEMASK_INT_11             : LONGINT = $00000800;
         _MC163_DEMASK_INT_12             : LONGINT = $00001000;
         _MC163_DEMASK_INT_13             : LONGINT = $00002000;
         _MC163_DEMASK_INT_14             : LONGINT = $00004000;
         _MC163_DEMASK_INT_15             : LONGINT = $00008000;

         _MC163_INT_0_NEG_EDGE            : LONGINT = $00010000;
         _MC163_INT_1_NEG_EDGE            : LONGINT = $00020000;
         _MC163_INT_2_NEG_EDGE            : LONGINT = $00040000;
         _MC163_INT_3_NEG_EDGE            : LONGINT = $00080000;
         _MC163_INT_4_NEG_EDGE            : LONGINT = $00100000;
         _MC163_INT_5_NEG_EDGE            : LONGINT = $00200000;
         _MC163_INT_6_NEG_EDGE            : LONGINT = $00400000;
         _MC163_INT_7_NEG_EDGE            : LONGINT = $00800000;
         _MC163_INT_8_NEG_EDGE            : LONGINT = $01000000;
         _MC163_INT_9_NEG_EDGE            : LONGINT = $02000000;
         _MC163_INT_10_NEG_EDGE           : LONGINT = $04000000;
         _MC163_INT_11_NEG_EDGE           : LONGINT = $08000000;

         _MC163_LATCH_POS_EDGE            : BYTE = $00;
         _MC163_LATCH_NEG_EDGE            : BYTE = $20;
         _MC163_LATCH_DISABLE             : BYTE = $00;
         _MC163_LATCH_ENABLE              : BYTE = $40;

         _MC163_DIN_0_LATCH               : BYTE = $00;
         _MC163_DIN_1_LATCH               : BYTE = $01;
         _MC163_DIN_2_LATCH               : BYTE = $02;
         _MC163_DIN_3_LATCH               : BYTE = $03;
         _MC163_DIN_4_LATCH               : BYTE = $04;
         _MC163_DIN_5_LATCH               : BYTE = $05;
         _MC163_DIN_6_LATCH               : BYTE = $06;
         _MC163_DIN_7_LATCH               : BYTE = $07;
         _MC163_DIN_8_LATCH               : BYTE = $08;
         _MC163_DIN_9_LATCH               : BYTE = $09;
         _MC163_DIN_10_LATCH              : BYTE = $0A;
         _MC163_DIN_11_LATCH              : BYTE = $0B;

         _MC163_INACTIVE                  : WORD = $0000;
         _MC163_COUNTER_UP                : WORD = $0001;
         _MC163_COUNTER_DN                : WORD = $0002;
         _MC163_COUNTER_UP_DN_A           : WORD = $0003;
         _MC163_COUNTER_UP_DN_B           : WORD = $0004;
         _MC163_TIMER                     : WORD = $0005;
         _MC163_INCREMENT_A               : WORD = $0006;
         _MC163_INCREMENT_B               : WORD = $0007;
         _MC163_FREQUENCY                 : WORD = $0009;
         _MC163_PULSEWIDTH                : WORD = $000A;
         _MC163_PERIOD                    : WORD = $000B;
         _MC163_VELOCITY                  : WORD = $000C;
         _MC163_MULTIPLE_PERIOD           : WORD = $1000;

         _MC163_AUTOSTART                 : WORD = $0020;
         _MC163_CONTINUE                  : WORD = $0040;
         _MC163_EXTERN                    : WORD = $0080;
         _MC163_SINGLE_A                  : WORD = $0000;
         _MC163_SINGLE_B                  : WORD = $0040;
         _MC163_DOUBLE_A                  : WORD = $0080;
         _MC163_DOUBLE_B                  : WORD = $00C0;
         _MC163_QUADRUPLE                 : WORD = $0100;
         _MC163_AUTOFREEZE                : WORD = $0100;
         _MC163_AUTORESET                 : WORD = $0200;
         _MC163_AUTOLOAD                  : WORD = $0400;
         _MC163_OVERRIDE                  : WORD = $0800;
         _MC163_CASCADE_0_1               : WORD = $2000;
         _MC163_CASCADE_1_2               : WORD = $4000;
         _MC163_CASCADE_0_1_2             : WORD = $8000;

         _MC163_DIN_0_1_CNT_0             : WORD = $0000;
         _MC163_DIN_2_3_CNT_0             : WORD = $1000;
         _MC163_DIN_4_5_CNT_0             : WORD = $2000;
         _MC163_DIN_6_7_CNT_0             : WORD = $3000;
         _MC163_DIN_8_9_CNT_0             : WORD = $4000;
         _MC163_DIN_10_11_CNT_0           : WORD = $5000;
         _MC163_DIN_6_CNT_1               : WORD = $6000;
         _MC163_CNT_0_CNT_1               : WORD = $7000;
         _MC163_DIN_4_CNT_2               : WORD = $8000;
         _MC163_CNT_0_CNT_2               : WORD = $9000;

         _MC163_DIN_0_INV                 : WORD = $0001;
         _MC163_DIN_1_INV                 : WORD = $0002;
         _MC163_DIN_2_INV                 : WORD = $0004;
         _MC163_DIN_3_INV                 : WORD = $0008;
         _MC163_DIN_4_INV                 : WORD = $0010;
         _MC163_DIN_5_INV                 : WORD = $0020;
         _MC163_DIN_6_INV                 : WORD = $0040;
         _MC163_DIN_7_INV                 : WORD = $0080;
         _MC163_DIN_8_INV                 : WORD = $0100;
         _MC163_DIN_9_INV                 : WORD = $0200;
         _MC163_DIN_10_INV                : WORD = $0400;
         _MC163_DIN_11_INV                : WORD = $0800;

         _MC163_DOUT_0_CNT_0              : WORD = $0001;
         _MC163_DOUT_1_CNT_1              : WORD = $0002;
         _MC163_DOUT_2_CNT_2              : WORD = $0004;
         _MC163_DOUT_0_DIRECT             : WORD = $0000;
         _MC163_DOUT_1_DIRECT             : WORD = $0000;
         _MC163_DOUT_2_DIRECT             : WORD = $0000;

         _MC163_NO_START                  : WORD = $0000;
         _MC163_START_DIN_0               : WORD = $0010;
         _MC163_START_DIN_1               : WORD = $0020;
         _MC163_START_DIN_2               : WORD = $0030;

         _MC163_NO_STOP                   : WORD = $0000;
         _MC163_STOP_DIN_1                : WORD = $0040;
         _MC163_STOP_DIN_2                : WORD = $0080;
         _MC163_STOP_DIN_3                : WORD = $00C0;
         _MC163_NO_STOP_UFL               : WORD = $0000;
         _MC163_STOP_UFL_CNT_0            : WORD = $0100;
         _MC163_STOP_UFL_CNT_1            : WORD = $0200;
         _MC163_STOP_UFL_CNT_2            : WORD = $0300;

         _MC163_NO_LOAD                   : WORD = $0000;
         _MC163_LOAD_DIN_0                : WORD = $0400;
         _MC163_LOAD_DIN_1                : WORD = $0800;
         _MC163_LOAD_DIN_2                : WORD = $0C00;

         _MC163_NO_FREEZE                 : WORD = $0000;
         _MC163_FREEZE_DIN_1              : WORD = $1000;
         _MC163_FREEZE_DIN_2              : WORD = $2000;
         _MC163_FREEZE_DIN_3              : WORD = $3000;

         _MC163_NO_RESET                  : WORD = $0000;
         _MC163_RESET_DIN_0               : WORD = $4000;
         _MC163_RESET_DIN_1               : WORD = $8000;
         _MC163_RESET_DIN_2               : WORD = $C000;

         _MC163_NO_INT                    : WORD = $0000;
         _MC163_INT_CNT_0_UFL             : WORD = $0001;
         _MC163_INT_CNT_0_OVL             : WORD = $0002;
         _MC163_INT_CNT_0_END             : WORD = $0004;
         _MC163_INT_CNT_0_INVALID         : WORD = $0008;
         _MC163_INT_CNT_1_UFL             : WORD = $0010;
         _MC163_INT_CNT_1_OVL             : WORD = $0020;
         _MC163_INT_CNT_1_END             : WORD = $0040;
         _MC163_INT_CNT_2_UFL             : WORD = $0080;
         _MC163_INT_CNT_2_OVL             : WORD = $0100;
         _MC163_INT_CNT_2_END             : WORD = $0200;

         _MC163_NO_FREQ                   : WORD = $0000;
         _MC163_10_MHZ                    : WORD = $0002;
         _MC163_5_MHZ                     : WORD = $0003;
         _MC163_2_MHZ                     : WORD = $0004;
         _MC163_1_MHZ                     : WORD = $0005;
         _MC163_500_KHZ                   : WORD = $0006;
         _MC163_200_KHZ                   : WORD = $0007;
         _MC163_100_KHZ                   : WORD = $0008;
         _MC163_50_KHZ                    : WORD = $0009;
         _MC163_20_KHZ                    : WORD = $000A;
         _MC163_10_KHZ                    : WORD = $000B;
         _MC163_5_KHZ                     : WORD = $000C;
         _MC163_2_KHZ                     : WORD = $000D;
         _MC163_1_KHZ                     : WORD = $000E;
         _MC163_500_HZ                    : WORD = $000F;
         _MC163_200_HZ                    : WORD = $0010;
         _MC163_100_HZ                    : WORD = $0011;
         _MC163_50_HZ                     : WORD = $0012;
         _MC163_20_HZ                     : WORD = $0013;
         _MC163_10_HZ                     : WORD = $0014;

         _MC163_NO_PERIOD                 : WORD = $0000;
         _MC163_NO_TIME                   : WORD = $0000;
         _MC163_100_NS                    : WORD = $0002;
         _MC163_200_NS                    : WORD = $0003;
         _MC163_500_NS                    : WORD = $0004;
         _MC163_1_US                      : WORD = $0005;
         _MC163_2_US                      : WORD = $0006;
         _MC163_5_US                      : WORD = $0007;
         _MC163_10_US                     : WORD = $0008;
         _MC163_20_US                     : WORD = $0009;
         _MC163_50_US                     : WORD = $000A;
         _MC163_100_US                    : WORD = $000B;
         _MC163_200_US                    : WORD = $000C;
         _MC163_500_US                    : WORD = $000D;
         _MC163_1_MS                      : WORD = $000E;
         _MC163_2_MS                      : WORD = $000F;
         _MC163_5_MS                      : WORD = $0010;
         _MC163_10_MS                     : WORD = $0011;
         _MC163_20_MS                     : WORD = $0012;
         _MC163_50_MS                     : WORD = $0013;
         _MC163_100_MS                    : WORD = $0014;

         _MC163_CMD_START_COUNTER         : BYTE = $01;
         _MC163_CMD_STOP_COUNTER          : BYTE = $02;
         _MC163_CMD_LOAD_COUNTER          : BYTE = $04;
         _MC163_CMD_FREEZE_COUNTER        : BYTE = $08;
         _MC163_CMD_RESET_COUNTER         : BYTE = $10;

         _MC163_COUNTER_0                 : BYTE = $20;
         _MC163_COUNTER_1                 : BYTE = $40;
         _MC163_COUNTER_2                 : BYTE = $80;

         _MC163_NO_LED                    : BYTE = $00;
         _MC163_LED_0                     : BYTE = $01;
         _MC163_LED_1                     : BYTE = $02;


         {* M-CAN-1 *}
         {* value for bus control and bus error report *}
         CAN_BUS_ON          : WORD =  0;
         CAN_BUS_OFF         : WORD =  2;
         CAN_BUS_HEAVY       : WORD =  1;
         {* values for usIndexFirst for DEVICE_CTRL devices *}
         CAN_BUS_CTRL_INDEX  : WORD =  100;
         {* values for usFlags (can be used with + or |) *}
         _CAN_NO_INT         : WORD = $10;
         _CAN_EXCL_BUFFER    : WORD = $20;
         _CAN_REMOTE         : WORD = $40;
         {* value of ucSize in the call of the service procedure for unconfigured  *}
         {* messages, if the received message was a remote frame                   *}
         CAN_REMOTE_FRAME    : WORD =  $FF;
         {* Defines for usStatus (returned by mddx_get_channel_info(handle, INFO_DEVICE)) *}
         {* more than one bit can be set at a time *}
         CAN_DATA_VALID      : WORD = $0001;  {* set if msg obj has received new data *}
                                              {* or whilst transmit data is valid to be sent *}
                                              {* reset only through special command CMD_STOP *}
         CAN_MSG_ACTIVE      : WORD = $0002;  {* set at the beginning of a transmission *}
                                              {* reset in the interrupt  *}
         CAN_MSG_LOST        : WORD = $0004;  {* set if a frame for the msg obj was overwritten *}
                                              {* reset only through special command CMD_STOP *}
         CAN_DOUBLE_REQ      : WORD = $0008;  {* set if a second channel service (read or write) *}
                                              {* is called before the first one was transmitted to the bus *}
                                              {* reset only through special command CMD_STOP *}


         { 5Bx64 }

         FBX64_SAMPLE_TRIGGER             : WORD = 0;
         FBX64_WD_TRIGGER                 : WORD = 1;
         FBX64_WD_STATUS                  : WORD = 0;

         FBX64_STATUS_OK                  : WORD = $0000;
         FBX64_STATUS_WARNING             : WORD = $0001;
         FBX64_STATUS_ERROR               : WORD = $0101;


         { M-AX-32/SSI }

         _MAX32SSI_BINARY                 : WORD = $0000;
         _MAX32SSI_GRAYCODE               : WORD = $0080;

         _MAX32SSI_CLK312KHZ50            : WORD = $0001;
         _MAX32SSI_CLK208KHZ33            : WORD = $0002;
         _MAX32SSI_CLK156KHZ25            : WORD = $0003;
         _MAX32SSI_CLK125KHZ00            : WORD = $0004;
         _MAX32SSI_CLK104KHZ17            : WORD = $0005;
         _MAX32SSI_CLK89KHZ29             : WORD = $0006;
         _MAX32SSI_CLK78KHZ13             : WORD = $0007;
         _MAX32SSI_CLK69KHZ44             : WORD = $0008;
         _MAX32SSI_CLK62KHZ50             : WORD = $0009;
         _MAX32SSI_CLK56KHZ81             : WORD = $000A;
         _MAX32SSI_CLK52KHZ08             : WORD = $000B;
         _MAX32SSI_CLK48KHZ08             : WORD = $000C;
         _MAX32SSI_CLK44KHZ64             : WORD = $000D;
         _MAX32SSI_CLK41KHZ67             : WORD = $000E;
         _MAX32SSI_CLK39KHZ06             : WORD = $000F;


         { ML8 (Base Board) }

         ML8_EXTERNAL_LED                 : WORD = 0;
         ML8_LOCAL_LED                    : WORD = 1;

         ML8_TIMER_A                      : WORD = 0;
         ML8_TIMER_B                      : WORD = 1;
         ML8_TIMER_C                      : WORD = 2;
         ML8_TIMER_D                      : WORD = 3;
         ML8_TIMER_E                      : WORD = 4;
         ML8_TIMER_F                      : WORD = 5;

         ML8_SQRWAVE_A                    : WORD = 0;
         ML8_SQRWAVE_B                    : WORD = 1;
         ML8_SQRWAVE_C                    : WORD = 2;

         ML8_SCC_A                        : WORD = 0;
         ML8_SCC_B                        : WORD = 1;

         ML8_INT_NMI                      : WORD = 0;
         ML8_INT_IRQ_A                    : WORD = 1;
         ML8_INT_IRQ_B                    : WORD = 2;
         ML8_INT_IRQ_C                    : WORD = 3;
         ML8_INT_IRQ_D                    : WORD = 4;
         ML8_INT_IRQ_E                    : WORD = 5;
         ML8_INT_IRQ_F                    : WORD = 6;
         ML8_INT_IRQ_G                    : WORD = 7;
         ML8_INT_IRQ_H                    : WORD = 8;
         ML8_INT_TIMER_A                  : WORD = 9;
         ML8_INT_TIMER_B                  : WORD = 10;
         ML8_INT_TIMER_C                  : WORD = 11;
         ML8_INT_TIMER_D                  : WORD = 12;
         ML8_INT_TIMER_E                  : WORD = 13;
         ML8_INT_TIMER_F                  : WORD = 14;
         ML8_INT_SCC_A                    : WORD = 15;
         ML8_INT_SCC_B                    : WORD = 16;

         ML8_WATCHDOG                     : WORD = 0;
         ML8_WATCHDOG_A                   : WORD = 1;
         ML8_WATCHDOG_B                   : WORD = 2;
         ML8_WATCHDOG_C                   : WORD = 3;

         ML8_UNMASK_INT                   : LONGINT = $00000000;
         ML8_MASK_INT                     : LONGINT = $00000001;
         ML8_POS_INT_EDGE                 : LONGINT = $00000002;
         ML8_NEG_INT_EDGE                 : LONGINT = $00000003;
         ML8_CLR_INT                      : LONGINT = $00000004;
         ML8_END_INT                      : LONGINT = $00000005;

         ML8_SET_RTS                      : LONGINT = $00000000;
         ML8_CLR_RTS                      : LONGINT = $00000001;
         ML8_SET_DTR                      : LONGINT = $00000002;
         ML8_CLR_DTR                      : LONGINT = $00000003;

         _ML8_COM_110                     : WORD = $0000;
         _ML8_COM_150                     : WORD = $0020;
         _ML8_COM_300                     : WORD = $0040;
         _ML8_COM_600                     : WORD = $0060;
         _ML8_COM_1200                    : WORD = $0080;
         _ML8_COM_2400                    : WORD = $00A0;
         _ML8_COM_4800                    : WORD = $00C0;
         _ML8_COM_9600                    : WORD = $00E0;
         _ML8_COM_19200                   : WORD = $0100;
         _ML8_COM_38400                   : WORD = $0200;

         _ML8_COM_CHR7                    : WORD = $0002;
         _ML8_COM_CHR8                    : WORD = $0003;

         _ML8_COM_STOP1                   : WORD = $0000;
         _ML8_COM_STOP2                   : WORD = $0004;
         _ML8_COM_NO_PARITY               : WORD = $0000;
         _ML8_COM_ODD_PARITY              : WORD = $0008;
         _ML8_COM_EVEN_PARITY             : WORD = $0018;



         { Multi-LAB/2 }

         ML2D_LATCH_SOFTWARE              : WORD = 0;
         ML2D_LATCH_IP_0_POS              : WORD = 2;
         ML2D_LATCH_IP_0_NEG              : WORD = 3;

         ML2D_OUTPUT_DISABLE              : WORD = 0;
         ML2D_OUTPUT_ENABLE               : WORD = 1;

         ML2D_START_SOFTWARE              : WORD = 0;
         ML2D_START_IP_0_EDGE_POS         : WORD = 3;
         ML2D_START_IP_0_EDGE_NEG         : WORD = 2;

         _ML2D_COUNTER_EVENT              : WORD = 0;
         _ML2D_COUNTER_FREQ               : WORD = 1;
         _ML2D_COUNTER_PULSE              : WORD = 2;
         _ML2D_COUNTER_PERIOD             : WORD = 3;
         _ML2D_COUNTER_INCR_1             : WORD = 5;
         _ML2D_COUNTER_INCR_2             : WORD = 6;
         _ML2D_COUNTER_INCR_4             : WORD = 7;

         _ML2D_COUNTER_EDGE_POS           : WORD = $0000;
         _ML2D_COUNTER_EDGE_NEG           : WORD = $0008;

         _ML2D_COUNTER_START              : WORD = $0040;

         _ML2D_COUNTER_INPUT_8            : WORD = $0000;
         _ML2D_COUNTER_INPUT_9            : WORD = $0100;
         _ML2D_COUNTER_INPUT_10           : WORD = $0200;
         _ML2D_COUNTER_INPUT_11           : WORD = $0300;
         _ML2D_COUNTER_INPUT_12           : WORD = $0400;
         _ML2D_COUNTER_INPUT_13           : WORD = $0500;
         _ML2D_COUNTER_INPUT_14           : WORD = $0600;
         _ML2D_COUNTER_INPUT_15           : WORD = $0700;

         _ML2D_COUNTER_32BIT              : WORD = $8000;

         _ML2D_COUNTER_REF_TIMER_A        : WORD = $0000;
         _ML2D_COUNTER_REF_IP_2           : WORD = $0010;

         _ML2D_COUNTER_RESET_POS          : WORD = $0000;
         _ML2D_COUNTER_RESET_NEG          : WORD = $0100;
         _ML2D_COUNTER_LATCH_POS          : WORD = $0000;
         _ML2D_COUNTER_LATCH_NEG          : WORD = $0200;




TYPE


         { M-D40-2 }

         CPS_MD402      = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-OPT-1/A }

         CPS_MOPT1A     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-OPT-1/B }

         CPS_MOPT1B     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-RU8-2 }

         CPS_MRU82      = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-DA16-2 }

         CPS_MDA162     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-DA2-2 }

         CPS_MDA22      = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-DA4-2 }

         CPS_MDA42      = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-AD16-4 }

         CPS_MAD164     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usOverSampling : WORD;
                              END;


         { M-AD16-3 }

         CPS_MAD163     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usRange        : WORD;
                              usSettleTime   : WORD;
                              END;


         { M-AD12-16 }

         CPS_MAD1216    = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usRange        : WORD;
                              END;


         { M-SH12-8 }

         CPS_MSH128     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-5B-1/U }

         CPS_M5B1U      = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              usSettleTime   : WORD;
                              usRange        : WORD;
                              END;



         { 5B panels }

         CPS_M5BP          = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              usSettleTime   : WORD;
                              usRange        : WORD;
                              END;



         { M-DC15-2 }

         CPS_MDC152     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { M-C16-3 }

         CPS_MC163      = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              usMode         : WORD;
                              usCounterInput : WORD;
                              usCounterOutput: WORD;
                              usCommandInput : WORD;
                              usInterrupt    : WORD;
                              usTime         : WORD;
                              usMultiple     : WORD;
                              usValueSize    : WORD;
                              END;

         { M-CAN-1 }

         CPS_MCAN1      = PACKED RECORD
                              usDevice     : WORD;
                              usIndexFirst : WORD;
                              usIndexLast  : WORD;
                              usFlags      : WORD;
                              ulCanID      : LONGINT;
                              usTimeout    : WORD;
                              end;

         { 5Bx64 }

         CPS_5BX64      = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usIndexExtern  : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              END;


         { Base board (ML8) }

         CPS_ML8     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              ulTimeOut      : LONGINT;
                              usMode         : WORD;
                              END;


         { Base board (ML6) }

         CPS_ML6     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              ulTimeOut      : LONGINT;
                              usMode         : WORD;
                              END;


         { Multi-LAB/2 }

         CPS_ML2     = PACKED RECORD
                              usDevice       : WORD;
                              usIndexFirst   : WORD;
                              usIndexLast    : WORD;
                              usFlags        : WORD;
                              usReadMode     : WORD;
                              usWriteMode    : WORD;
                              usRange        : WORD;
                              usMode         : WORD;
                              END;


         { Channel-Descriptor-Table (CDT) for ML8 }

         MDD8_CDT_HEAD  = PACKED RECORD
                              pfnServiceDataOut     : LONGINT;
                              pfnServiceDataIn      : LONGINT;
                              pfnServiceSpecial     : LONGINT;
                              pfnServiceRes1        : LONGINT;
                              ucCdtID               : BYTE;
                              ucDataTypeID          : BYTE;
                              ucCdtType             : BYTE;
                              ucMddTaskNo           : BYTE;
                              usDataSizeMin         : WORD;
                              usDataSizeMax         : WORD;
                              ucPhysIORange         : BYTE;
                              ucResolution          : BYTE;
                              ucTransferMode        : BYTE;
                              ucServiceListNo       : BYTE;
                              ulCSR                 : LONGINT;
                              ulPreviousCDT         : LONGINT;
                              pfnServiceCopy1       : LONGINT;
                              pfnServiceCopy2       : LONGINT;
                              ulRes2                : LONGINT;
                              usCdtSize             : WORD;
                              ucParSize             : BYTE;
                              ucCpsCopySize         : BYTE;
                              ucCaptionSize         : BYTE;
                              ucRes3                : BYTE;
                              usRelOfsCpsCopy       : WORD;
                              usRelOfsCaption       : WORD;
                              usRes4                : WORD;
                              END;


         { Channel-Descriptor-Table (CDT) for ML2 }

         MDD2_CDT_HEAD  = PACKED RECORD
                              pfnServiceDataOut     : LONGINT;
                              pfnServiceDataIn      : LONGINT;
                              pfnServiceSpecial     : LONGINT;
                              pfnServiceRes1        : LONGINT;
                              ucCdtID               : BYTE;
                              ucDataTypeID          : BYTE;
                              ucCdtType             : BYTE;
                              ucMddTaskNo           : BYTE;
                              usDataSizeMin         : WORD;
                              usDataSizeMax         : WORD;
                              ucPhysIORange         : BYTE;
                              ucResolution          : BYTE;
                              ucTransferMode        : BYTE;
                              ucServiceListNo       : BYTE;
                              ulCSR                 : LONGINT;
                              ulPreviousCDT         : LONGINT;
                              pfnServiceCopy1       : LONGINT;
                              pfnServiceCopy2       : LONGINT;
                              ulRes2                : LONGINT;
                              usCdtSize             : WORD;
                              ucParSize             : BYTE;
                              ucCpsCopySize         : BYTE;
                              ucCaptionSize         : BYTE;
                              ucRes3                : BYTE;
                              usRelOfsCpsCopy       : WORD;
                              usRelOfsCaption       : WORD;
                              usRes4                : WORD;
                              END;

         { Channel-Descriptor-Table (CDT) for ML6 }

         MDD6_CDT_HEAD  = PACKED RECORD
                              pfnServiceDataOut     : LONGINT;
                              pfnServiceDataIn      : LONGINT;
                              pfnServiceSpecial     : LONGINT;
                              pfnServiceRes1        : LONGINT;
                              ucCdtID               : BYTE;
                              ucDataTypeID          : BYTE;
                              ucCdtType             : BYTE;
                              ucMddTaskNo           : BYTE;
                              usDataSizeMin         : WORD;
                              usDataSizeMax         : WORD;
                              ucPhysIORange         : BYTE;
                              ucResolution          : BYTE;
                              ucTransferMode        : BYTE;
                              ucServiceListNo       : BYTE;
                              ulCSR                 : LONGINT;
                              ulPreviousCDT         : LONGINT;
                              pfnServiceCopy1       : LONGINT;
                              pfnServiceCopy2       : LONGINT;
                              ulRes2                : LONGINT;
                              usCdtSize             : WORD;
                              ucParSize             : BYTE;
                              ucCpsCopySize         : BYTE;
                              ucCaptionSize         : BYTE;
                              ucRes3                : BYTE;
                              usRelOfsCpsCopy       : WORD;
                              usRelOfsCaption       : WORD;
                              usRes4                : WORD;
                              END;



IMPLEMENTATION


BEGIN

END.