{***********************************************************************
*  MDDDIAGD.C
*
*  PURPOSE
*                This file may be linked to a project with the SORCUS
*                library for MODULAR-4/486. It contains a procedure to
*                convert a diagnosis word provided by the function
*                mdd8_get_diagnosis into a string (german language).
*
*        AUTHORS
*                Dipl.-Ing. H.Doersam (HD)
*
*        COPYRIGHTS
*                SORCUS Computer GmbH Heidelberg (Germany) 1997
***********************************************************************}

{***********************************************************************

HISTORY

18/02/2000 (JD)
   -  Neuer Diagnosecode
      $0504 (ungueltiger EEPROM-Wert)

18/03/98 (HD)
   -  Neue Diagnosecodes
      $0503 (Datenverlust)
      $FFFF (Diagnosewort ungueltig)

15/12/97 (HD)
   -        Creation of this file

***********************************************************************}


UNIT MDDDIAGD;

INTERFACE

PROCEDURE mdd8_get_diagnosis_msg (VAR diagstr: string; code: word);


IMPLEMENTATION



{************************************************************************
*        mdd8_get_diagnosis_msg
*
*        PURPOSE
*        -        Converts a diagnosis message received from a MDD into a string
*        -        To receive the string reserve minimum 80 characters
*
*        PARAMETER
*        -        diagstr                        Points to a string object that receives the
*                                                        diagnosis message
*        -        code                                Diagnosis code (from mdd8_get_diagnosis)
*
*        RETURN
*        -        Nothing
*************************************************************************}
PROCEDURE mdd8_get_diagnosis_msg (VAR diagstr: string; code: word);
BEGIN
        {        If High-Byte = $01 then a parameter of an entried data
                structure is wrong. The offset of the wrong parameter
                is given in the Low-Byte. }
        IF ((code AND $FF00) = $0100)
   THEN
                BEGIN
                        diagstr
                                := 'Falscher Parameter (Offset = Low-Byte des Diagnosewortes)';
                END

        ELSE
                CASE (code) OF
                        $0000:        diagstr        := 'Kein Fehler aufgetreten';
                        $0001:        diagstr        := 'Aufruf hatte keinen Effekt';
                        $0201:        diagstr        :=        'Anzahl Eingabedaten falsch';
                        $0202:        diagstr        := 'Anzahl Eingabedaten zu gross';
                        $0203:        diagstr        := 'Anzahl Eingabedaten zu klein';
                        $0211:        diagstr        := 'Anzahl Ausgabedaten falsch';
                        $0212:        diagstr        := 'Anzahl angeforderter Ausgabedaten zu gross';
                        $0213:        diagstr        := 'Anzahl angeforderter Ausgabedaten zu klein';
                        $0221:        diagstr        := 'Treiberdienst ist gesperrt';
                        $0321:        diagstr        := 'Bereichsueberschreitung';
                        $0322:        diagstr        := 'Bereichsunterschreitung';
                        $0323:        diagstr        := 'Uebergebener Wert ist falsch';
                        $0324:        diagstr        := 'Ende des Kanaldatenbereichs erreicht';
                        $0331:        diagstr        := 'Abschlusszeichen des Strings fehlt';
                        $0401:        diagstr        := 'Nicht genug Speicher mehr verfuegbar';
                        $0411:        diagstr        := 'Datenpuffer ist leer';
                        $0412:        diagstr        := 'Datenpuffer ist voll';
                        $0501:        diagstr        := 'Hardware-Konflikt (Unbekanntes Device)';
                        $0502:        diagstr        := 'Timeout-Fehler';
                        $0503:        diagstr        := 'Datenverlust';
                        $0504:        diagstr        := 'EEPROM-Wort nicht im erlaubten Wertebereich';
                        $0511:        diagstr        := 'Device ist nicht verfuegbar';
                        $0512:        diagstr        := 'Device ist bereits geoeffnet';
                        $0531:        diagstr        := 'Kanal nicht gefunden';
                        $0541:        diagstr        := 'Angegebener Infotext existiert nicht';
                        $0551:        diagstr        :=        'Kein Caption-Puffer reserviert';
                        $0561:        diagstr        := 'CPS wird nicht unterstuetzt';
                        $0601:        diagstr        := 'Fehler beim Setzen der Echtzeituhr';
                        $0602:        diagstr        := 'Fehler beim Lesen der Echtzeituhr';
                        $0603:        diagstr        := 'Fehler beim Schreiben in das EEPROM';
                        $0604:        diagstr        := 'Fehler beim Lesen vom EEPROM';
         $FFFF:   diagstr  := 'Diagnosewort ist ungueltig';
                ELSE
                        diagstr := 'Diagnosewort ist unbekannt';
                END;
END;



BEGIN

END.
