{***********************************************************************
*  MDDDIAGE.C
*
*  PURPOSE
*                This file may be linked to a project with the SORCUS
*                library for MODULAR-4/486. It contains a procedure to
*                convert a diagnosis word provided by the function
*                mdd8_get_diagnosis into a string (english language).
*
*        AUTHORS
*                Dipl.-Ing. H.Doersam (HD)
*
*        COPYRIGHTS
*                SORCUS Computer GmbH Heidelberg (Germany) 1997
***********************************************************************}

{***********************************************************************

HISTORY

29/04/2003 (JD)
   - Unit name changed from mdddiagd
   
18/02/2000 (JD)
   -  New diagnosis code
      $0504 (invalid EEPROM-value)

18/03/98 (HD)
   -  New diagnosis codes
      $0503 (data lost)
      $FFFF (diagnosis invalid)

15/12/97 (HD)
   -        Creation of this file

***********************************************************************}


UNIT MDDDIAGE;

INTERFACE

PROCEDURE mdd8_get_diagnosis_msg (VAR diagstr: string; code: word);


IMPLEMENTATION



{************************************************************************
*        mdd8_get_diagnosis_msg
*
*        PURPOSE
*        -        Converts a diagnosis message received from a MDD into a string
*        -        To receive the string reserve minimum 80 characters
*
*        PARAMETER
*        -        diagstr                        Points to a string object that receives the
*                                                        diagnosis message
*        -        code                                Diagnosis code (from mdd8_get_diagnosis)
*
*        RETURN
*        -        Nothing
*************************************************************************}
PROCEDURE mdd8_get_diagnosis_msg (VAR diagstr: string; code: word);
BEGIN
        {        If High-Byte = $01 then a parameter of an entried data
                structure is wrong. The offset of the wrong parameter
                is given in the Low-Byte. }
        IF ((code AND $FF00) = $0100)
   THEN

                BEGIN
                        diagstr
                                := 'Wrong parameter (offset = Low-Byte of diagnosis word)';
                END

        ELSE
                CASE (code) OF
                        $0000:        diagstr        := 'No error occured';
                        $0001:        diagstr        := 'Called without any effect';
                        $0201:        diagstr        :=        'Wrong number of data inputs';
                        $0202:        diagstr        := 'Number of data inputs too high';
                        $0203:        diagstr        := 'Number of data inputs too low';
                        $0211:        diagstr        := 'Wrong number of data outputs';
                        $0212:        diagstr        := 'Number of data outputs too high';
                        $0213:        diagstr        := 'Number of data outputs too low';
                        $0221:        diagstr        := 'Driver service is locked';
                        $0321:        diagstr        := 'Range crossed over';
                        $0322:        diagstr        := 'Range crossed under';
                        $0323:        diagstr        := 'Data is not possible';
                        $0324:        diagstr        := 'Reached end of data area';
                        $0331:        diagstr        := 'Missing string termination';
                        $0401:        diagstr        := 'Not enough memory';
                        $0411:        diagstr        := 'Data buffer is empty';
                        $0412:        diagstr        := 'Data buffer is full';
                        $0501:        diagstr        := 'Hardware conflict (unknown device)';
                        $0502:        diagstr        := 'Timeout error';
                        $0503:        diagstr        := 'Data lost';
                        $0504:        diagstr        := 'EEPROM value out of range';
                        $0511:        diagstr        := 'Device not available';
                        $0512:        diagstr        := 'Device already in use';
                        $0531:        diagstr        := 'Channel not found';
                        $0541:        diagstr        := 'Specified infotext not available';
                        $0551:        diagstr        :=        'No buffer for caption reserved';
                        $0561:        diagstr        := 'CPS is not supported';
                        $0601:        diagstr        := 'Error when setting the real time clock';
                        $0602:        diagstr        := 'Error when reading the real time clock';
                        $0603:        diagstr        := 'Error when writing to EEPROM';
                        $0604:        diagstr        := 'Error when reading from EEPROM';
                        $FFFF:        diagstr        := 'Diagnosis is invalid';
                ELSE
                        diagstr := 'Diagnosis is unknown';
                END;
END;


BEGIN

END.

