{************************************************************************
*
*                          MLXERRD.PAS
*
*          Modul zur Fehlerauswertung fuer SORCUS-Bibliotheken
*
*                    Version          : siehe Historie
*                    Erstellung       : 25.09.97
*                    letzte Aenderung : siehe Historie
*                    Autoren          : M.Haecker
*                                       H.Doersam
*
*     (c) SORCUS Computer GmbH Heidelberg 1996, 1997
*************************************************************************}

{************************************************************************
*
*  Beschreibung:
*        Diese Datei kann zu einem Projekt mit einer SORCUS-Bibliothek
*        fuer MODULAR-4/486 oder Multi-LAB/2 gelinkt werden.
*        Sie enthaelt eine Funktion, die zu einem Fehler (Fehlerklasse
*        und Fehlercode) eine Zeichenkette liefert, die den Fehler
*        beschreibt.
*        Die Zeichenkette ist deutschsprachig. Fuer Anwendungen in
*        Englisch wird die Datei 'MLXERRE.PAS' verwendet.
*
*************************************************************************}

{************************************************************************
*  Historie:
*     21.07.98 (JD)
*        - Fehlerklasse 2, Fehlercode 80h hinzugefuegt
*     02.04.98 (HD)
*        - Fehlerklasse 11, Fehlercode 1 hinzugefuegt
*        - Fehlerklasse 2, Fehlercode 41 hinzugefuegt
*     20.10.97 (HD)
*        - Fehlerklasse 12 hinzugefuegt
*     25.09.97 (HD)
*        - Fehlerklasse 11 hinzugefuegt
*     18.02.96 (MIH)
*        - Fehlerklasse 2 ab Code 0x40 erweitert
*        - Fehlerklasse 6 fuer ML2DEB zugefuegt
*        - Fehlerklasse 4 zugefuegt
*        - Fehlerklasse 7 zugefuegt
*     30.10.96 (MIH)
*        - Portierung von C nach Pascal
*************************************************************************}
UNIT MLXERRD;

INTERFACE

PROCEDURE mlx_get_error_msg(VAR errstr: string; errclass, errcode: byte);


IMPLEMENTATION

{************************************************************************
*  mlx_get_error_msg:
*     liefert den zu einem Fehler (Klasse und Code) gehoerenden String. 
*
*     OUT errstr:     enthaelt die Fehlermeldung
*     IN  errclass:   Fehlerklasse
*     IN  code:       Fehlercode
*
*************************************************************************}
PROCEDURE mlx_get_error_msg(VAR errstr: string; errclass, errcode: byte);
BEGIN
   CASE (errclass) OF
   {****************  error class 0  ********************}
      $00:  
         CASE (errcode) OF
            $00:
               errstr := 'kein Fehler';
             $01:
               errstr := 'Fehler beim Schreiben zur Karte (TBF high)';
             $02:
               errstr := 'Fehler beim Lesen von der Karte (RBF low)';
             $03:
               errstr := 'Plausibilitaetsfehler in Anwort';
             $04:
               errstr := 'DLP Timeout zu Beginn eines Makrobefehls';
             $05:
               errstr := 'Unerwartetes Wort (RBF:=1) zu Beginn eines Makros';
             $06:
               errstr := 'DLM konnte nicht auf Null gesetzt werden';
             $07:
               errstr := 'DLM konnte nicht auf Eins gesetzt werden';
             $08:
               errstr := 'DLP konnte nicht auf Null gesetzt werden';
             $09:
               errstr := 'DLP konnte nicht auf Eins gesetzt werden';
             $0b:
               errstr := 'Resetfehler: Das Statusbit TBF geht nach Reset nicht auf 0';
             $0e:
               errstr := 'Resetfehler: Das Statusbit TBF kann bei Reset nicht auf 1 gesetzt werden';
             $0f:
               errstr := 'DLP ist gesetzt beim Empfangen von Zeichen';
             $10:
               errstr := 'DLP ist gesetzt beim Senden von Zeichen';
             $12:
               errstr := 'Karte reagiert nicht';
             $13:
               errstr := 'RBF ist bei Interrupt nicht gesetzt';
             $14:
               errstr := 'TBF ist bei Interrupt gesetzt';
             $15:
               errstr := 'Fehler beim Senden des ersten Wortes eines Makrobefehls';
             ELSE
               errstr := 'Der Fehlercode ist in Klasse 0 nicht vorgesehen';
          END;
   {****************  error class 1  ********************}
       $01:  
         CASE (errcode) OF
             $00:
               errstr := 'kein Fehler';
             $01:
               errstr := 'MINI Betriebssystem ist nicht aktiv';
             $02:
               errstr := 'ROM Betriebssystem konnte nicht aktiviert werden';
             $03:
               errstr := 'RAM Betriebssystemdatei nicht gefunden';
             $04:
               errstr := 'RAM Betriebssystemdatei: Lesefehler';
             $05:
               errstr := 'RAM Betriebssystemdatei: Fehler bim Oeffnen/Schlieen';
             $06:
               errstr := 'RAM Betriebssystem konnte nicht aktiviert werden';
             $11:
               errstr := 'Programmdatei nicht gefunden';
             $12:
               errstr := 'Speicher-Reservierungsfehler auf der Karte';
             $13:
               errstr := 'Zuwenig freier Speicher auf der Karte';
             $14:
               errstr := 'Programmdatei Lesefehler';
             $15:
               errstr := 'Programmdatei: Fehler beim Oeffnen/Schliessen';
             $16:
               errstr := 'Falsche Linker-Signatur';
             $17:
               errstr := 'Karte laesst sich nicht initialisieren';
             $18:
               errstr := 'Debug-Tabelle konnte nicht eingerichtet werden';
             $20:
               errstr := 'Kein Modul auf Steckplatz vorhanden';
             $21:
               errstr := 'Modul braucht keine Initialisierung';
             $22:
               errstr := 'Modul wurde nicht initialisiert wegen EEPROM-Konfiguration';
             $23:
               errstr := 'Initialisierungsroutine ist nicht implementiert';
             $40:
               errstr := 'Bootfehler: Adresse konnte nicht eingestellt werden';
             $41:
               errstr := 'Bootfehler: Zugriffsmodus ''Wort'' nicht moeglich';
             $42:
               errstr := 'Bootfehler: Zugriffsmodus nicht wie erwartet';
             $43:
               errstr := 'Bootfehler: unbekannter Fehler bei Zugriffsmodus';
             $44:
               errstr := 'Bootfehler: Fehler beim Schreiben des OsX oder beim Starten';
             $45:
               errstr := 'Bootfehler: Fehler beim Rcksetzen des Befehlszeigers';
             ELSE
               errstr := 'Fehlercode ist in Klasse 1 nicht vorgesehen';
         END;

   {****************  error class 2  ********************}
       $02:  
         CASE (errcode) OF
             $00:
               errstr := 'kein Fehler';
             $01:
               errstr := 'Die Kartennummer ist unzulaessig';
             $02:
               errstr := 'Basisadresse nicht zulaessig';
             $03:
               errstr := 'Betriebsart nicht zulaessig';
             $04:
               errstr := 'PC-Interruptkanal nicht zulaessig';
             $05:
               errstr := 'PC-DMA-Kanal nicht zulaessig';
             $06:
               errstr := 'Die Bibliothek ist noch nicht initialisiert';
             $07:
               errstr := 'Programmtyp und Installationsflag stimmen nicht ueberein';
             $10:
               errstr := 'Unzulaessiger Parameter (Datum/Zeit)';
             $11:
               errstr := 'Datenrueckgabelaenge ueberschreitet den vorgegebenen Wert';
             $19:
               errstr := 'Parameternummer fuer EEPROM ungueltig';
             $20:
               errstr := 'Vor dem Aufruf von ml8_init_bib muss ml8_bib_startup aufgerufen werden';
             $21:
               errstr := 'Aufruf einer Multi-LAB/2-Bibliotheksfunktion fuer eine MODULAR-4/486-Karte';
             $22:
               errstr := 'Aufruf einer MODULAR-4/486-Bibliotheksfunktion fuer eine Multi-LAB/2-Karte';
             $23:
               errstr := 'Aufruf einer Funktion, die im Augenblick nicht unterstuetzt wird';
             $24:
               errstr := 'Multi-LAB/2a unterstuetzt Funktion nicht';
             $25:
               errstr := 'Multi-LAB/2d unterstuetzt Funktion nicht';
             $26:
               errstr := 'Parameter #1 ist falsch';
             $27:
               errstr := 'Parameter #2 ist falsch';
             $28:
               errstr := 'Parameter #3 ist falsch';
             $29:
               errstr := 'Keine Unterstuetzung von angewaehlter Karte';
             $30:
               errstr := 'Maximale Makro-Kommandolaenge ueberschritten';
             $31:
               errstr := 'Maximale Makro-Kommandorueckgabelaenge ueberschritten';
             $32:
               errstr := 'Erwartete Funktions-Datenlaenge (Hin) ueberschritten';
             $33:
               errstr := 'Erwartete Funktions-Datenlaenge (Rueckgabe) ueberschritten';
             $36:
               errstr := 'Der angegebene Makrobefehl ist unbekannt';
             $40:
               errstr := 'ml8_call_func: outsize unzulaessig';
             $41:
               errstr := 'ml8_call_func: insize unzulaessig';
             $42:
               errstr := 'ml8_call_func: Funktion der Task nicht vorhanden';
             $43:
               errstr := 'ml8_call_func: DDT nicht angelegt';
             $44:
               errstr := 'ml8_call_func: unbekannter Fehler';
             $80:
               errstr := 'Achtung: Das Jahr 2080 wird als 80 zurueckgegeben';
             ELSE
               errstr := 'Fehlercode ist in Klasse 2 nicht vorgesehen';
         END; 
   {****************  error class 4  ********************}
       $04:    
         CASE (errcode) OF
             $00:
               errstr := 'kein Fehler';
             $01:
               errstr := 'Fehler beim Schreiben zur Karte (TBF high)';
             $02:
               errstr := 'Fehler beim Lesen von der Karte (RBF low)';
             $03:
               errstr := 'Plausibilitaetsfehler in Anwort';
             $0E:
               errstr := 'Service Request ohne RBF';
             $0F:
               errstr := 'Service Request ohne DLP';
             $10:
               errstr := 'Rekursiver Aufruf der Service-Routine';
             $11:
               errstr := 'Message Ueberlauf bei der Service-Routine';
             $12:
               errstr := 'DLP konnte in der Service-Routine nicht zurueckgesetzt werden';
             ELSE
               errstr := 'Fehlercode ist in Klasse 4 nicht vorgesehen';
         END;
   {****************  error class 5  ********************}
       $05:
               errstr := 'Fehlercode ist ungueltig, bitte mlx_get_message benutzen';
   {****************  error class 6  ********************}
       $06:
         CASE (errcode) OF
             $00:
               errstr := 'kein Fehler';
             $01:
               errstr := 'Die Kartennummer ist unzulaessig';
             $02:
               errstr := 'Adresskonflikt oder Karte defekt';
             $03:
               errstr := 'Fehler beim Schreiben zur Karte (TBF high)';
             $04:
               errstr := 'Fehler beim Lesen von der Karte (RBF low)';
             $05:
               errstr := 'Device kann nicht geoeffnet werden';
             $06:
               errstr := 'Bibliothek ist noch nicht initialisiert';
             $07:
               errstr := 'Die Kanalnummer ist ungueltig';
             $08:
               errstr := 'Multi-LAB/2a Karte besitzt keine massebezogenen Eingaenge';
             $09:
               errstr := 'Nummer fuer Analogeingang ist ungueltig';
             $0A:
               errstr := 'Nummer fuer Analogausgang ist ungueltig';
             $0B:
               errstr := 'Nummer fuer digitalen Eingang ist ungueltig';
             $0C:
               errstr := 'Nummer fuer digitalen Ausgang ist ungueltig';
             $0D:
               errstr := 'Nummer fuer Differenzeingang ist ungueltig';
             $0E:
               errstr := 'ml2_get_data kann auf den angegebenen Kanal nicht angewendet werden';
             $0F:
               errstr := 'ml2_set_data kann auf den angegebenen Kanal nicht angewendet werden';
             $12:
               errstr := 'Der angegebene Spannungsbereich kann nicht eingestellt werden';
             $13:
               errstr := 'Multi-LAB/2d: Fuer Differenzeingaenge ist nur der Bereich +/-10V moeglich';
             $14:
               errstr := 'Multi-LAB/2a: Fuer Differenzeingaenge ist nur der Bereich +/-5V moeglich';
             $15:
               errstr := 'Multi-LAB/2d: Fuer massebezogene Eingaenge ist nur der Bereich +/-10V moeglich';
             $16:
               errstr := 'Multi-LAB/2a: Fuer die analogen Ausgaenge ist nur der Bereich +/-5V moeglich';
             $17:
               errstr := 'Multi-LAB/2d: Fuer die analogen Ausgaenge ist nur der Bereich +/-10V moeglich';
             $18:
               errstr := 'Unbekannte Versionsnummer';
             $19:
               errstr := 'Das angegebene Maskierungsflag kann nicht verwendet werden';
             $1A:
               errstr := 'ml2_get_device_state kann auf den angegebenen Kanal nicht angewendet werden';
             $1B:
               errstr := 'Bei einer Messung mit ''Autowait'' trat ein Timeout auf';
             $1C:
               errstr := 'Timer B ist uebergelaufen';
             $1D:
               errstr := 'Die Hardware ist bereits durch einen anderen Kanal belegt';
             $1E:
               errstr := 'Es liegt noch kein gueltiges Messergebnis vor';
             $1F:
               errstr := 'Die Hardware fuer den Kanal wurde noch nicht reserviert';
             $20:
               errstr := 'Ungueltiges Handle';
             ELSE
               errstr := 'Fehlercode ist in Klasse 6 nicht vorgesehen';
         END;
   {****************  error class 7  ********************}
       $07:
         CASE (errcode) OF
             $00:
               errstr := 'kein Fehler';
             $01:
               errstr := 'Systemfehler ist aufgetreten. Code von GetLastError() in <Struct>.System.error';
             $02:
               errstr := 'Fehler im Treiber';
             ELSE
               errstr := 'Fehlercode ist in Klasse 7 nicht vorgesehen';
         END;  

   {****************  error class 8  ********************}
       $08:   
         CASE (errcode) OF
             $01:
               errstr := 'Treiber konnte nicht geoeffnet werden';
             $02:
               errstr := 'Rueckgabelaenge des Treibers falsch';
             $03:
               errstr := 'SRQ-Thread konnte nicht aktiviert werden';
             $04:
               errstr := 'SRQ-Event konnte nicht aktiviert werden';
             $05:
               errstr := 'SRQ-Hold-Request konnte nicht installiert werden';
             $06:
               errstr := 'SRQ-Thread: Prioritaet nicht erhoehbar';
             $07:
               errstr := 'User-Service-Thread konnte nicht aktiviert werden';
             $08:
               errstr := 'SRQ-Synchronisation: Ereignis konnte nicht geoeffnet werden';
             $09:
               errstr := 'SRQ-Synchronisation: Ereignis konnte nicht gesetzt werden';
             $0A:
               errstr := 'SRQ-Synchronisation: Ereignis konnte nicht zurueckgesetzt werden';
             $0B:
               errstr := 'Prozessspeicher im Treiber konnte nicht angelegt werden';
             $0C:
               errstr := 'Prozessspeicher im Treiber konnte nicht freigegeben werden';
             $0D:
               errstr := 'Prozess konnte nicht mit dem Treiber verbunden werden';
             $0E:
               errstr := 'SRQ-Thread konnte nicht angehalten werden';
             $10:
               errstr := 'Falscher Parameter beim Lesen/Schreiben im Treiber';
             $11:
               errstr := 'Falscher Parameter beim Lesen im Treiber';
             $12:
               errstr := 'Falscher Parameter beim Schreiben im Treiber';
             $13:
               errstr := 'Parameter kann nicht geschrieben werden';
             $14:
               errstr := 'Parametertyp wurde falsch angegeben';
             $15:
               errstr := 'Prozess-ID ist nicht gueltig';
             $16:
               errstr := 'Protokollpuffer kann nicht gelesen werden';
             $17:
               errstr := 'Kartennummer ist ungueltig oder Karte ist nicht installiert';
             $FF:
               errstr := 'Allgemeiner Treiberfehler';
             ELSE
               errstr := 'Der Fehlercode ist in Klasse 8 nicht vorgesehen';
         END;

   {****************  error class 11  ********************}

      $0B:
         CASE (errcode) OF
            $00:
               errstr := 'Kein Fehler';
            $01:
               errstr := 'Neuere OsX Version erforderlich';
            $40:
               errstr := 'Handle ungueltig';
            $41:
               errstr := 'Verwendeter Datentyp falsch';
            $42:
               errstr := 'Fehler in MDD-Dienst (Diagnose moeglich)';
            $43:
               errstr := 'Fehler in Kanal-Dienst (Diagnose moeglich)';
            $44:
               errstr := 'Dienst nicht verfuegbar';
            $45:
               errstr := 'MDD nicht verfuegbar';
            ELSE
               errstr := 'Der Fehlercode ist in Klasse 11 nicht vorgesehen';
         END;

   {****************  error class 12  ********************}

      $0C:
         CASE (errcode) OF
            $00:
               errstr := 'Kein Fehler';
            $84:
               errstr := 'Soft-State falsch oder anderer Befehl noch nicht beendet';
            $85:
               errstr := 'Eingesetztes Flash-Eprom wird nicht unterstuetzt';
            $86:
               errstr := 'Dienst falsch';
            $87:
               errstr := 'Kein Flash-Eprom (lt. EEPROM)';
            $88:
               errstr := 'Steckplatz oder IC-Nr. falsch';
            $89:
               errstr := 'Parameter nicht aligned';
            $8A:
               errstr := 'Adresse falsch';
            $8B:
               errstr := 'Flash-Eprom nicht geloescht';
            $8C:
               errstr := 'Flash-Eprom nicht programmierbar/loeschbar (Timeout)';
            ELSE
               errstr := 'Der Fehlercode ist unbekannt';
         END;

      ELSE
         errstr := 'Fehlerklasse nicht vorgesehen';
      END;
END;

END.
