{************************************************************************
*
*                                MLXERRE
*
*          module for error decoding
*
*                    version          : see history
*                    creation         : 25.09.97
*                    last change      : see history
*                    authors          : M.Haecker
*                                       H.Doersam
*
*     (c) SORCUS Computer GmbH Heidelberg 1995..1997
*************************************************************************}

{************************************************************************
*
*  description:
*        This file may be linked to a project with the SORCUS library
*        for MODULAR-4/486 or Multi-LAB/2.
*        It contains a procedure to convert an error class and error code 
*        provided by the library into a string.
*
*************************************************************************}

{************************************************************************
*  History:
*     21.07.98 (HD)
*        - error class 2, error code $80 added
*     02.04.98 (HD)
*        - error class 11, error code 1 added
*        - error class 2, error code 41 added
*     20.10.97 (HD)
*        - error class 12 added
*     25.09.97 (HD)
*        - error class 11 added
*     18.02.96 (MIH)
*        - error class 2 code 0x40+ added
*        - error class 6 for ML2DEB added
*        - error class 4 added
*        - error class 7 added
*************************************************************************}
UNIT MLXERRE;

INTERFACE

PROCEDURE mlx_get_error_msg(VAR errstr: string; errclass, errcode: byte);


IMPLEMENTATION

{************************************************************************
*  ml8_get_error_msg:
*     This procedure converts an error class and error code provided by the 
*     SORCUS library into a string.
*
*     OUT errstr:     contains the error string
*     IN  errclass:   error class
*     IN  code:       error code
*
*************************************************************************}
PROCEDURE mlx_get_error_msg(VAR errstr: string; errclass, errcode: byte);
BEGIN
   CASE (errclass) OF
   {****************  error class 0  ********************}
      $00:  
         CASE (errcode) OF
            $00:
               errstr := 'No error';
             $01:
               errstr := 'TBF error: TBF did not become low while trying to send';
             $02:
               errstr := 'RBF error: RBF did not become high while trying to receive';
             $03:
               errstr := 'Plausibility checking failed';
             $04:
               errstr := 'DLP timeout at the beginning of a macro command';
             $05:
               errstr := 'RBF error: RBF was high at the beginning of a macro command';
             $06:
               errstr := 'DLM could not be set low';
             $07:
               errstr := 'DLM could not be set high';
             $08:
               errstr := 'DLP could not be set low';
             $09:
               errstr := 'DLP could not be set high';
             $0b:
               errstr := 'Reset error: TBF stayed high after a hard-reset';
             $0e:
               errstr := 'Reset error: TBF stayed low after a hard-reset';
             $0f:
               errstr := 'DLP was high while trying to receive';
             $10:
               errstr := 'DLP was high while trying to send';
             $12:
               errstr := 'Board does not react';
             $13:
               errstr := 'RBF was not high when a hardware interrupt occured';
             $14:
               errstr := 'TBF was high when a hardware interrupt occured';
             $15:
               errstr := 'Error when sending the first word of a macro command';
             ELSE
               errstr := 'The error code is unknown';
          END;
   {****************  error class 1  ********************}
       $01:  
         CASE (errcode) OF
             $00:
               errstr := 'No error';
             $01:
               errstr := 'MINI operating system is not active';
             $02:
               errstr := 'ROM operating system could not be activated';
             $03:
               errstr := 'RAM operating system file not found';
             $04:
               errstr := 'RAM operating system file: reading error';
             $05:
               errstr := 'RAM operating system file: error during opening/closing';
             $06:
               errstr := 'RAM operating system could not be activated';
             $11:
               errstr := 'Program file not found';
             $12:
               errstr := 'Memory allocation error on the board';
             $13:
               errstr := 'Not enough memory on the board';
             $14:
               errstr := 'Program file: reading error';
             $15:
               errstr := 'Program file: error during opening/closing';
             $16:
               errstr := 'Wrong linker signature';
             $17:
               errstr := 'Board cannot be initialized';
             $18:
               errstr := 'Debug table cannot be created';
             $20:
               errstr := 'No module found';
             $21:
               errstr := 'Module does not need any initialization';
             $22:
               errstr := 'Module was not initialized because of the EEPROM configuration';
             $23:
               errstr := 'Initialization routine is not implemented';
             $40:
               errstr := 'Boot error: address cannot be set';
             $41:
               errstr := 'Boot error: access mode ''WORD'' is not possible';
             $42:
               errstr := 'Boot error: wrong access mode';
             $43:
               errstr := 'Boot error: unknown error in access mode';
             $44:
               errstr := 'Boot error: error when writing/starting the OsX';
             $45:
               errstr := 'Boot error: error when resetting the instruction pointer';
             ELSE
               errstr := 'The errorcode is unknown';
         END;

   {****************  error class 2  ********************}
       $02:  
         CASE (errcode) OF
             $00:
               errstr := 'No error';
             $01:
               errstr := 'Card number is invalid';
             $02:
               errstr := 'Base address is invalid';
             $03:
               errstr := 'Operating mode is invalid';
             $04:
               errstr := 'Interrupt channel is invalid';
             $05:
               errstr := 'DMA Channel is invalid';
             $06:
               errstr := 'The library has not been initialized';
             $07:
               errstr := 'Program type and installation flags do not agree';
             $10:
               errstr := 'Invalid parameter (date/time)';
             $11:
               errstr := 'Data return length is greater than allowed';
             $19:
               errstr := 'Parameter number for EEPROM is invalid';
             $20:
               errstr := 'A library function was called before calling ''mlx_bib_startup''';
             $21:
               errstr := 'Call of a MODULAR-4 function for a Multi-LAB/2 board';
             $22:
               errstr := 'Call of a Multi-LAB/2 function for a MODULAR-4 board';
             $23:
               errstr := 'Call of a function that is not implemented';
             $24:
               errstr := 'Call of a function that is not supported by Multi-LAB/2a';
             $25:
               errstr := 'Call of a function that is not supported by Multi-LAB/2d';
             $26:
               errstr := 'Parameter #1 is wrong';
             $27:
               errstr := 'Parameter #2 is wrong';
             $28:
               errstr := 'Parameter #3 is wrong';
             $29:
               errstr := 'No support by selected card';
             $30:
               errstr := 'Maximum macro command length has exceeded';
             $31:
               errstr := 'Maximum macro command return length has exceeded';
             $32:
               errstr := 'Data length has been exceeded (send)';
             $33:
               errstr := 'Data length has been exceeded (receive)';
             $36:
               errstr := 'Macro command is unknown';
             $40:
               errstr := 'mlx_call_func: outsize is invalid';
             $41:
               errstr := 'mlx_call_func: insize is invalid';
             $42:
               errstr := 'mlx_call_func: function of a task does not exist';
             $43:
               errstr := 'mlx_call_func: DDT not created';
             $44:
               errstr := 'mlx_call_func: unknown error';
             $80:
               errstr := 'Attention: The year 2080 will be returned as 80';
             ELSE
               errstr := 'The error code is unknown';
         END; 
   {****************  error class 4  ********************}
       $04:     
         CASE (errcode) OF
             $00:
               errstr := 'No error';
             $01:
               errstr := 'TBF error: TBF did not become low while trying to send';
             $02:
               errstr := 'RBF error: RBF did not become high while trying to receive';
             $03:
               errstr := 'Plausibility checking failed';
             $0E:
               errstr := 'Service request without RBF';
             $0F:
               errstr := 'Service request without DLP';
             $10:
               errstr := 'Recursive call of the service routine';
             $11:
               errstr := 'Message overflow in the service routine';
             $12:
               errstr := 'No DLP reset in service routine';
             ELSE
               errstr := 'The error code is unknown';
         END;        
   {****************  error class 5  ********************}
       $05:    
               errstr := 'The error code is invalid; please use mlx_get_message';
   {****************  error class 6  ********************}
       $06:     
         CASE (errcode) OF
             $00:
               errstr := 'No error';
             $01:
               errstr := 'The card number is invalid';
             $02:
               errstr := 'Address conflict or defective board';
             $03:
               errstr := 'TBF error: TBF did not become low while trying to send';
             $04:
               errstr := 'RBF error: RBF did not become high while trying to receive';
             $05:
               errstr := 'Device can not be generated';
             $06:
               errstr := 'The library has not been initialized';
             $07:
               errstr := 'The channel number is invalid';
             $08:
               errstr := 'Multi-LAB/2a board does not have single-ended inputs';
             $09:
               errstr := 'An incorrect analog input channel number was specified';
             $0A:
               errstr := 'An incorrect analog output channel number was specified';
             $0B:
               errstr := 'An incorrect number was specified for a digital input';
             $0C:
               errstr := 'An incorrect number was specified for a digital output';
             $0D:
               errstr := 'An incorrect number was specified for a differential input';
             $0E:
               errstr := 'ml2_get_data cannot be used for the specified channel';
             $0F:
               errstr := 'ml2_set_data cannot be used for the specified channel';
             $12:
               errstr := 'The specified voltage range cannot be set';
             $13:
               errstr := 'Multi-LAB/2d: The range for differential inputs must be +/-10V';
             $14:
               errstr := 'Multi-LAB/2a: The range for differential inputs must be +/-5V';
             $15:
               errstr := 'Multi-LAB/2d: The range for single-ended inputs must be +/-10V';
             $16:
               errstr := 'Multi-LAB/2a: The range for analog outputs must be +/-5V';
             $17:
               errstr := 'Multi-LAB/2d: The range for analog outputs must be +/-10V';
             $18:
               errstr := 'Unknown version number';
             $19:
               errstr := 'The specified mask flag cannot be used';
             $1A:
               errstr := 'ml2_get_device_state cannot be used for the specified channel';
             $1B:
               errstr := 'A timeout occured while measurement with autowait';
             $1C:
               errstr := 'Timer B overflow';
             $1D:
               errstr := 'The hardware is used by another channel';
             $1E:
               errstr := 'No valid measurement result is ready yet';
             $1F:
               errstr := 'The hardware for the channel has not been reserved yet';
             $20:
               errstr := 'Handle is invalid';
             ELSE
               errstr := 'The error code is unknown';
         END; 
   {****************  error class 7  ********************}
       $07:     
         CASE (errcode) OF
             $00:
               errstr := 'No error';
             $01:
               errstr := 'System error occured. The code of GetLastError() is in <Struct>.System.error';
             $02:
               errstr := 'Error in driver';
             ELSE
               errstr := 'The error code is unknown';
         END;
   {****************  error class 8  ********************}
       $08:
         CASE (errcode) OF
             $01:
               errstr := 'Driver could not be opened';
             $02:
               errstr := 'Wrong return length';
             $03:
               errstr := 'SRQ thread could not be created';
             $04:
               errstr := 'SRQ event could not be activated';
             $05:
               errstr := 'SRQ hold request could not be installed';
             $06:
               errstr := 'SRQ thread: priority could not be increased';
             $07:
               errstr := 'User service thread could not be activated';
             $08:
               errstr := 'SRQ synchronisation: event could not be opened';
             $09:
               errstr := 'SRQ synchronisation: event could not be set';
             $0A:
               errstr := 'SRQ synchronisation: event could not be reset';
             $0B:
               errstr := 'Process buffer could not be allocated';
             $0C:
               errstr := 'Process buffer could not be freed';
             $0D:
               errstr := 'Process could not be connected';
             $0E:
               errstr := 'SRQ thread could not be stopped';
             $10:
               errstr := 'Wrong parameter when reading/writing';
             $11:
               errstr := 'Wrong parameter when reading';
             $12:
               errstr := 'Wrong parameter when writing';
             $13:
               errstr := 'Parameter could not be written';
             $14:
               errstr := 'Parameter type is wrong';
             $15:
               errstr := 'Process ID is invalid';
             $16:
               errstr := 'Protocol buffer could not be read';
             $17:
               errstr := 'Card number is invalid or card is not installed';
             $FF:
               errstr := 'General driver failure';
             ELSE
               errstr := 'The error code is unknown';
         END;

   {****************  error class 11  ********************}

      $0B:
         CASE (errcode) OF
            $00:
               errstr := 'No Error';
            $01:
               errstr := 'Newer OsX version necessary';
            $40:
               errstr := 'Handle invalid';
            $41:
               errstr := 'Used Data Type is wrong';
            $42:
               errstr := 'Error in MDD Service (Diagnosis possible)';
            $43:
               errstr := 'Error in Channel Service (Diagnosis possible)';
            $44:
               errstr := 'Service not available';
            $45:
               errstr := 'MDD not installed';
            ELSE
               errstr := 'The Error Code is unknown';
         END;

   {****************  error class 12  ********************}

      $0C:
         CASE (errcode) OF
            $00:
               errstr := 'No Error';
            $84:
               errstr := 'Soft-State wrong or another Command is not finished yet';
            $85:
               errstr := 'Used Flash-Eprom is not supported';
            $86:
               errstr := 'Service is wrong';
            $87:
               errstr := 'No Flash-Eprom (cause EEPROM)';
            $88:
               errstr := 'Slot or IC Number is wrong';
            $89:
               errstr := 'Parameter is not aligned';
            $8A:
               errstr := 'Address is wrong';
            $8B:
               errstr := 'Flash-Eprom is not erased';
            $8C:
               errstr := 'Flash-Eprom is not programmable/eraseable (Timeout)';
            ELSE
               errstr := 'The Error Code is unknown';
         END;

      ELSE
         errstr := 'Error class is unknown';
   END;
END;

END.
