Attribute VB_Name = "MLX_IMPORT_LIBRARY"
'*************************************************
'   MLXBIB.BAS
'
'   Import library to write Visual Basic programs
'   with the SORCUS boards Multi-LAB/2, Multi-COM
'   or MODULAR-4/486
'
'   Operating Systems:  Windows 3.x
'                       Windows 9x
'                       Windows NT
'
'   (C) SORCUS Computer GmbH 1997-99
'*************************************************
'
'   SELECT PLATFORM:
'
'   Comment the following line if your program
'   should run on a Windows 9x or Windows NT system
'
'   #Const PLATFORM = 16    ' Windows 3.x
'
'   Comment the following line if your program
'   should run on a Windows 3.1x system
'
    #Const PLATFORM = 32    ' Windows 9x, Windows NT
'
'   SELECT USED BOARD(S):
'   If your target system is Windows NT you can
'   use several board types.
'
'   Comment the following line if you don't
'   communicate with a Multi-LAB/2 board
'
'   #Const BOARD = 2        ' Multi-LAB/2
'
'   Comment the following line if you don't
'   communicate with a Multi-COM board
'
'   #Const BOARD = 6        ' Multi-COM
'
'   Comment the following line if you don't
'   communicate with a short MODULAR-4/486 board
'
'   #Const BOARD = 7        ' short MODULAR-4/486
'
'   Comment the following line if you don't
'   communicate with a long MODULAR-4/486 board
'
    #Const BOARD = 8        ' long MODULAR-4/486
'
'*************************************************



'*************************************************
'   Constants
'*************************************************

'   Number of cards you can handle with the library
Public Const NUMBEROFCARDS = 8

'   Definitions for the actual language
Public Const LANGUAGE_C = &H200
Public Const LANGUAGE_PASCAL = &H100
Public Const LANGUAGE_VISUAL_BASIC = &H200

'   Version status
Public Const FREE_RELEASE = "F"
Public Const BETA_VERSION = "B"
Public Const EPROM_OSX = "E"
Public Const RAM_OSX = "R"

'   Day of week
Public Const SUNDAY = 0
Public Const MONDAY = 1
Public Const TUESDAY = 2
Public Const WEDNESDAY = 3
Public Const THURSDAY = 4
Public Const FRIDAY = 5
Public Const SATURDAY = 6

'   Strategies for memory allocation
Public Const ALLOC_GET_SIZE = 0
Public Const ALLOC_UP_ABS = 1
Public Const ALLOC_UP_MAX = 2
Public Const ALLOC_DOWN_ABS = 3
Public Const ALLOC_DOWN_MAX = 4

'   Strategies used by buffer operations
Public Const BUFFER_ALL_OR_NOTHING = 0
Public Const BUFFER_MAXIMUM = 1
Public Const BUFFER_COPY = 2
Public Const BUFFER_TRY_MULTIPLE = 4

'   Constants for the error record
Public Const MAX_ERR_OUT_CMD = 6
Public Const MAX_ERR_IN_CMD = 6
Public Const MAX_ERR_OUT_DATA = 6
Public Const MAX_ERR_IN_DATA = 6

Public Const STATUSMAP_OLD_ERROR_SEND = 1
Public Const STATUSMAP_OLD_ERROR_RECEIVE = 2
Public Const STATUSMAP_ERROR_REQUEST = 64
Public Const STATUSMAP_LIB_NOT_INITIALIZED = 128

'   Constants for flash programming
Public Const FLASH_GET_CUSTOMER_ID = &H0
Public Const FLASH_GET_DEVICE_ID = &H1
Public Const FLASH_GET_SIZE_INFO = &H2
Public Const FLASH_GET_ORGANIZATION = &H3
Public Const FLASH_CHECK_WRITE_PROTECTED = &H4
Public Const FLASH_GET_ERASE_STATUS = &H5
Public Const FLASH_COPY_EPROM = &H6
Public Const FLASH_GET_SOFT_STATE = &HA
Public Const FLASH_ERASE_ENABLE = &HB
Public Const FLASH_ERASE_DISABLE = &HC
Public Const FLASH_PROGRAM_ENABLE = &HD
Public Const FLASH_PROGRAM_DISABLE = &HE

'   Constants for watch errors
Public Const WATCH_ERR_STATUS = 0
Public Const WATCH_ERR_CLASS = 1
Public Const WATCH_ERR_CODE = 2
Public Const WATCH_ERR_STATUS_PORT = 3
Public Const WATCH_ERR_STATUS_MAP = 4
Public Const WATCH_ERR_SYSTEM = 5
Public Const WATCH_ERR_DRV_OUT_SIZE = 6
Public Const WATCH_ERR_DRV_IN_SIZE = 7

#If PLATFORM = 32 Then
' Constants for Visual Basic specific SRQ-handling
Public Const GWL_WNDPROC = -4
Public Const WM_SRQ_RECEIVED = &H400 ' may be changed
Public Const WM_ERROR_MSG = &H401 ' may be changed

' Windows SDK functions for SRQ handling:
Declare Function SetWindowLong Lib "User32.dll" Alias _
"SetWindowLongA" (ByVal hwnd As Long, ByVal nIndex As Long, _
ByVal dwNewLong As Long) As Long

Declare Function GetActiveWindow Lib "User32.dll" () As Long

Declare Function CallWindowProc Lib "User32.dll" Alias _
"CallWindowProcA" (ByVal lpPrevWndFunc As Long, ByVal hwnd As Long, _
ByVal Msg As Long, ByVal wParam As Long, ByVal lParam As Long) As Long
#End If ' PLATFORM = 32

'*************************************************
'   mlX_bib_startup
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_bib_startup Lib "mlxw32.dll" _
Alias "ml8_bib_startup" _
(ByVal language As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_bib_startup Lib "wml2bib.dll" _
Alias "ml8_bib_startup" _
(ByVal language As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_bib_startup Lib "mlxw32.dll" _
Alias "ml8_bib_startup" _
(ByVal language As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_bib_startup Lib "wml6bib.dll" _
Alias "ml8_bib_startup" _
(ByVal language As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_bib_startup Lib "mlxw32.dll" _
Alias "ml8_bib_startup" _
(ByVal language As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_bib_startup Lib "wml7bib.dll" _
Alias "ml8_bib_startup" _
(ByVal language As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_bib_startup Lib "mlxw32.dll" _
(ByVal language As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_bib_startup Lib "wml8bib.dll" _
(ByVal language As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_reset
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_reset Lib "mlxw32.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByVal error_handler As Long, _
ByVal osname As String, ByVal timeout As Integer) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_reset Lib "wml2bib.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByRef error_handler As Long, _
ByVal osname As String, ByVal timeout As Integer) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_reset Lib "mlxw32.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByVal error_handler As Long, _
ByVal osname As String, ByVal timeout As Integer) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_reset Lib "wml6bib.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByRef error_handler As Long, _
ByVal osname As String, ByVal timeout As Integer) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_reset Lib "mlxw32.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByVal error_handler As Long, _
ByVal osname As String, ByVal timeout As Integer) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_reset Lib "wml7bib.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByRef error_handler As Long, _
ByVal osname As String, ByVal timeout As Integer) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_reset Lib "mlxw32.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByVal error_handler As Long, _
ByVal osname As String, ByVal timeout As Integer) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_reset Lib "wml8bib.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByRef error_handler As Long, _
ByVal osname As String, ByVal timeout As Integer) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_start
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_start Lib "mlxw32.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByVal error_handler As Long, _
ByVal timeout As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_start Lib "wml2bib.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByRef error_handler As Long, _
ByVal timeout As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_start Lib "mlxw32.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByVal error_handler As Long, _
ByVal timeout As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_start Lib "wml6bib.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByRef error_handler As Long, _
ByVal timeout As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_start Lib "mlxw32.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByVal error_handler As Long, _
ByVal timeout As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_start Lib "wml7bib.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByRef error_handler As Long, _
ByVal timeout As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_start Lib "mlxw32.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByVal error_handler As Long, _
ByVal timeout As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_start Lib "wml8bib.dll" _
(ByVal card As Integer, ByVal adr As Integer, _
ByVal mode As Integer, ByVal irq_channel As Integer, _
ByVal dma_channel As Integer, _
ByRef error_handler As Long, _
ByVal timeout As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_exit_card
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_exit_card Lib "mlxw32.dll" _
Alias "ml8_exit_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_exit_card Lib "wml2bib.dll" _
Alias "ml8_exit_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_exit_card Lib "mlxw32.dll" _
Alias "ml8_exit_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_exit_card Lib "wml6bib.dll" _
Alias "ml8_exit_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_exit_card Lib "mlxw32.dll" _
Alias "ml8_exit_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_exit_card Lib "wml7bib.dll" _
Alias "ml8_exit_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_exit_card Lib "mlxw32.dll" _
(ByVal card As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_exit_card Lib "wml8bib.dll" _
(ByVal card As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_exit
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_exit Lib "mlxw32.dll" _
Alias "ml8_exit" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_exit Lib "wml2bib.dll" _
Alias "ml8_exit" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_exit Lib "mlxw32.dll" _
Alias "ml8_exit" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_exit Lib "wml6bib.dll" _
Alias "ml8_exit" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_exit Lib "mlxw32.dll" _
Alias "ml8_exit" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_exit Lib "wml7bib.dll" _
Alias "ml8_exit" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_exit Lib "mlxw32.dll" _
()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_exit Lib "wml8bib.dll" _
()
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_select_card
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_select_card Lib "mlxw32.dll" _
Alias "ml8_select_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_select_card Lib "wml2bib.dll" _
Alias "ml8_select_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_select_card Lib "mlxw32.dll" _
Alias "ml8_select_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_select_card Lib "wml6bib.dll" _
Alias "ml8_select_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_select_card Lib "mlxw32.dll" _
Alias "ml8_select_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_select_card Lib "wml7bib.dll" _
Alias "ml8_select_card" _
(ByVal card As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_select_card Lib "mlxw32.dll" _
(ByVal card As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_select_card Lib "wml8bib.dll" _
(ByVal card As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_selected_card
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_get_selected_card _
Lib "mlxw32.dll" Alias "ml8_get_selected_card" _
() As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_get_selected_card _
Lib "wml2bib.dll" _
Alias "ml8_get_selected_card" _
() As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_selected_card _
Lib "mlxw32.dll" Alias "ml8_get_selected_card" _
() As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_selected_card _
Lib "wml6bib.dll" Alias "ml8_get_selected_card" _
() As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_selected_card _
Lib "mlxw32.dll" Alias "ml8_get_selected_card" _
() As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_selected_card _
Lib "wml7bib.dll" Alias "ml8_get_selected_card" _
() As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_selected_card _
Lib "mlxw32.dll" () As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_get_selected_card _
Lib "wml8bib.dll" () As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_osx_version
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_get_osx_version Lib "mlxw32.dll" _
Alias "ml8_get_osx_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_get_osx_version Lib "wml2bib.dll" _
Alias "ml8_get_osx_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_osx_version Lib "mlxw32.dll" _
Alias "ml8_get_osx_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_get_osx_version Lib "wml6bib.dll" _
Alias "ml8_get_osx_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_osx_version Lib "mlxw32.dll" _
Alias "ml8_get_osx_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_get_osx_version Lib "wml7bib.dll" _
Alias "ml8_get_osx_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_osx_version Lib "mlxw32.dll" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_get_osx_version Lib "wml8bib.dll" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_lib_version
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_get_lib_version Lib "mlxw32.dll" _
Alias "ml8_get_lib_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_get_lib_version Lib "wml2bib.dll" _
Alias "ml8_get_lib_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_lib_version Lib "mlxw32.dll" _
Alias "ml8_get_lib_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_get_lib_version Lib "wml6bib.dll" _
Alias "ml8_get_lib_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_lib_version Lib "mlxw32.dll" _
Alias "ml8_get_lib_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_get_lib_version Lib "wml7bib.dll" _
Alias "ml8_get_lib_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_lib_version Lib "mlxw32.dll" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_get_lib_version Lib "wml8bib.dll" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_mlxdrv_version
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_get_mlxdrv_version Lib "mlxw32.dll" _
Alias "ml8_get_mlxdrv_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_mlxdrv_version Lib "mlxw32.dll" _
Alias "ml8_get_mlxdrv_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_mlxdrv_version Lib "mlxw32.dll" _
Alias "ml8_get_mlxdrv_version" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_mlxdrv_version Lib "mlxw32.dll" _
(ByRef VersionCode As Long, ByRef DateCode As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_create_version_string
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_create_version_string _
Lib "mlxw32.dll" Alias "ml8_create_version_string" _
(ByVal pcVersionString As String, _
ByVal ulVersion As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_create_version_string _
Lib "wml2bib.dll" Alias "ml8_create_version_string" _
(ByVal pcVersionString As String, _
ByVal ulVersion As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_create_version_string _
Lib "mlxw32.dll" Alias "ml8_create_version_string" _
(ByVal pcVersionString As String, _
ByVal ulVersion As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_create_version_string _
Lib "wml6bib.dll" Alias "ml8_create_version_string" _
(ByVal pcVersionString As String, _
ByVal ulVersion As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_create_version_string _
Lib "mlxw32.dll" Alias "ml8_create_version_string" _
(ByVal pcVersionString As String, _
ByVal ulVersion As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_create_version_string _
Lib "wml7bib.dll" Alias "ml8_create_version_string" _
(ByVal pcVersionString As String, _
ByVal ulVersion As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_create_version_string _
Lib "mlxw32.dll" (ByVal pcVersionString As String, _
ByVal ulVersion As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_create_version_string _
Lib "wml8bib.dll" (ByVal pcVersionString As String, _
ByVal ulVersion As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_create_date_string
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_create_date_string Lib "mlxw32.dll" _
Alias "ml8_create_date_string" _
(ByVal pcDateString As String, ByVal ulDate As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_create_date_string Lib "wml2bib.dll" _
Alias "ml8_create_date_string" _
(ByVal pcDateString As String, ByVal ulDate As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_create_date_string Lib "mlxw32.dll" _
Alias "ml8_create_date_string" _
(ByVal pcDateString As String, ByVal ulDate As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_create_date_string Lib "wml6bib.dll" _
Alias "ml8_create_date_string" _
(ByVal pcDateString As String, ByVal ulDate As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_create_date_string Lib "mlxw32.dll" _
Alias "ml8_create_date_string" _
(ByVal pcDateString As String, ByVal ulDate As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_create_date_string Lib "wml7bib.dll" _
Alias "ml8_create_date_string" _
(ByVal pcDateString As String, ByVal ulDate As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_create_date_string Lib "mlxw32.dll" _
(ByVal pcDateString As String, ByVal ulDate As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_create_date_string Lib "wml8bib.dll" _
(ByVal pcDateString As String, ByVal ulDate As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_create_time_string
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_create_time_string Lib "mlxw32.dll" _
Alias "ml8_create_time_string" _
(ByVal pcTimeString As String, ByVal ulTime As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_create_time_string Lib "wml2bib.dll" _
Alias "ml8_create_time_string" _
(ByVal pcTimeString As String, ByVal ulTime As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_create_time_string Lib "mlxw32.dll" _
Alias "ml8_create_time_string" _
(ByVal pcTimeString As String, ByVal ulTime As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_create_time_string Lib "wml6bib.dll" _
Alias "ml8_create_time_string" _
(ByVal pcTimeString As String, ByVal ulTime As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_create_time_string Lib "mlxw32.dll" _
Alias "ml8_create_time_string" _
(ByVal pcTimeString As String, ByVal ulTime As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_create_time_string Lib "wml7bib.dll" _
Alias "ml8_create_time_string" _
(ByVal pcTimeString As String, ByVal ulTime As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_create_time_string Lib "mlxw32.dll" _
(ByVal pcTimeString As String, ByVal ulTime As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_create_time_string Lib "wml8bib.dll" _
(ByVal pcTimeString As String, ByRef ulTime As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_local_led_on
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_led_on Lib "mlxw32.dll" _
Alias "ml8_local_led_on" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_led_on Lib "wml2bib.dll" _
Alias "ml8_local_led_on" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_local_led_on Lib "mlxw32.dll" _
Alias "ml8_local_led_on" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_local_led_on Lib "wml6bib.dll" _
Alias "ml8_local_led_on" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_local_led_on Lib "mlxw32.dll" _
Alias "ml8_local_led_on" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_local_led_on Lib "wml7bib.dll" _
Alias "ml8_local_led_on" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_local_led_on Lib "mlxw32.dll" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_local_led_on Lib "wml8bib.dll" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 2

'*************************************************
'   mlX_local_led_off
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_led_off Lib "mlxw32.dll" _
Alias "ml8_local_led_off" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_led_off Lib "wml2bib.dll" _
Alias "ml8_local_led_off" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_local_led_off Lib "mlxw32.dll" _
Alias "ml8_local_led_off" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_local_led_off Lib "wml6bib.dll" _
Alias "ml8_local_led_off" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_local_led_off Lib "mlxw32.dll" _
Alias "ml8_local_led_off" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_local_led_off Lib "wml7bib.dll" _
Alias "ml8_local_led_off" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_local_led_off Lib "mlxw32.dll" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_local_led_off Lib "wml8bib.dll" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_local_led_status
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_get_local_led_status _
Lib "mlxw32.dll" Alias "ml8_get_local_led_status" _
() As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_get_local_led_status _
Lib "wml2bib.dll" Alias "ml8_get_local_led_status" _
() As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_local_led_status _
Lib "mlxw32.dll" Alias "ml8_get_local_led_status" _
() As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_local_led_status _
Lib "wml6bib.dll" Alias "ml8_get_local_led_status" _
() As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_local_led_status _
Lib "mlxw32.dll" Alias "ml8_get_local_led_status" _
() As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_local_led_status _
Lib "wml7bib.dll" Alias "ml8_get_local_led_status" _
() As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_local_led_status _
Lib "mlxw32.dll" () As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_get_local_led_status _
Lib "wml8bib.dll" () As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_external_led_on
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_external_led_on Lib "mlxw32.dll" _
Alias "ml8_external_led_on" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_external_led_on Lib "wml6bib.dll" _
Alias "ml8_external_led_on" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_external_led_on Lib "mlxw32.dll" _
Alias "ml8_external_led_on" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_external_led_on Lib "wml7bib.dll" _
Alias "ml8_external_led_on" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_external_led_on Lib "mlxw32.dll" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_external_led_on Lib "wml8bib.dll" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_external_led_off
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_external_led_off Lib "mlxw32.dll" _
Alias "ml8_external_led_off" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_external_led_off Lib "wml6bib.dll" _
Alias "ml8_external_led_off" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_external_led_off Lib "mlxw32.dll" _
Alias "ml8_external_led_off" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_external_led_off Lib "wml7bib.dll" _
Alias "ml8_external_led_off" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_external_led_off Lib "mlxw32.dll" ()
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_external_led_off Lib "wml8bib.dll" ()
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_transfer_and_install
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_transfer_and_install _
Lib "mlxw32.dll" Alias "ml8_transfer_and_install" _
(ByVal pgmname As String, ByVal usage As Integer, _
ByVal task As Integer, ByVal prgnum As Integer, _
ByVal interrupt As Integer, ByVal flag As Long, _
ByVal size As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_transfer_and_install _
Lib "wml2bib.dll" Alias "ml8_transfer_and_install" _
(ByVal pgmname As String, ByVal usage As Integer, _
ByVal task As Integer, ByVal prgnum As Integer, _
ByVal interrupt As Integer, ByVal flag As Long, _
ByVal size As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_transfer_and_install _
Lib "mlxw32.dll" Alias "ml8_transfer_and_install" _
(ByVal pgmname As String, ByVal usage As Integer, _
ByVal task As Integer, ByVal prgnum As Integer, _
ByVal interrupt As Integer, ByVal flag As Long, _
ByVal size As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_transfer_and_install _
Lib "wml6bib.dll" Alias "ml8_transfer_and_install" _
(ByVal pgmname As String, ByVal usage As Integer, _
ByVal task As Integer, ByVal prgnum As Integer, _
ByVal interrupt As Integer, ByVal flag As Long, _
ByVal size As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_transfer_and_install _
Lib "mlxw32.dll" Alias "ml8_transfer_and_install" _
(ByVal pgmname As String, ByVal usage As Integer, _
ByVal task As Integer, ByVal prgnum As Integer, _
ByVal interrupt As Integer, ByVal flag As Long, _
ByVal size As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_transfer_and_install _
Lib "wml7bib.dll" Alias "ml8_transfer_and_install" _
(ByVal pgmname As String, ByVal usage As Integer, _
ByVal task As Integer, ByVal prgnum As Integer, _
ByVal interrupt As Integer, ByVal flag As Long, _
ByVal size As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_transfer_and_install _
Lib "mlxw32.dll" _
(ByVal pgmname As String, ByVal usage As Integer, _
ByVal task As Integer, ByVal prgnum As Integer, _
ByVal interrupt As Integer, ByVal flag As Long, _
ByVal size As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_transfer_and_install _
Lib "wml8bib.dll" _
(ByVal pgmname As String, ByVal usage As Integer, _
ByVal task As Integer, ByVal prgnum As Integer, _
ByVal interrupt As Integer, ByVal flag As Long, _
ByVal size As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_task_info
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_get_task_info Lib "mlxw32.dll" _
Alias "ml8_get_task_info" _
(ByVal task As Integer, ByVal callnr As Integer, _
ByRef result As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_get_task_info Lib "wml2bib.dll" _
Alias "ml8_get_task_info" _
(ByVal task As Integer, ByVal callnr As Integer, _
ByRef result As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_task_info Lib "mlxw32.dll" _
Alias "ml8_get_task_info" _
(ByVal task As Integer, ByVal callnr As Integer, _
ByRef result As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_get_task_info Lib "wml6bib.dll" _
Alias "ml8_get_task_info" _
(ByVal task As Integer, ByVal callnr As Integer, _
ByRef result As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_task_info Lib "mlxw32.dll" _
Alias "ml8_get_task_info" _
(ByVal task As Integer, ByVal callnr As Integer, _
ByRef result As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_get_task_info Lib "wml7bib.dll" _
Alias "ml8_get_task_info" _
(ByVal task As Integer, ByVal callnr As Integer, _
ByRef result As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_task_info Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal callnr As Integer, _
ByRef result As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_get_task_info Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal callnr As Integer, _
ByRef result As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_task_status
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_get_task_status _
Lib "mlxw32.dll" Alias "ml8_get_task_status" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_get_task_status _
Lib "wml2bib.dll" Alias "ml8_get_task_status" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_task_status _
Lib "mlxw32.dll" Alias "ml8_get_task_status" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_task_status _
Lib "wml6bib.dll" Alias "ml8_get_task_status" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_task_status _
Lib "mlxw32.dll" Alias "ml8_get_task_status" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_task_status _
Lib "wml7bib.dll" Alias "ml8_get_task_status" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_task_status _
Lib "mlxw32.dll" (ByVal task As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_get_task_status _
Lib "wml8bib.dll" (ByVal task As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_task_number
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_get_task_number _
Lib "mlxw32.dll" Alias "ml8_get_task_number" _
(ByVal prog_nr As Integer, ByRef install_nr As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_get_task_number _
Lib "wml2bib.dll" Alias "ml8_get_task_number" _
(ByVal prog_nr As Integer, ByRef install_nr As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_task_number _
Lib "mlxw32.dll" Alias "ml8_get_task_number" _
(ByVal prog_nr As Integer, ByRef install_nr As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_task_number _
Lib "wml6bib.dll" Alias "ml8_get_task_number" _
(ByVal prog_nr As Integer, ByRef install_nr As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_task_number _
Lib "mlxw32.dll" Alias "ml8_get_task_number" _
(ByVal prog_nr As Integer, ByRef install_nr As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_task_number _
Lib "wml7bib.dll" Alias "ml8_get_task_number" _
(ByVal prog_nr As Integer, ByRef install_nr As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_task_number _
Lib "mlxw32.dll" (ByVal prog_nr As Integer, _
ByRef install_nr As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_get_task_number _
Lib "wml8bib.dll" (ByVal prog_nr As Integer, _
ByRef install_nr As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_pgm_installed
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_get_pgm_installed Lib "mlxw32.dll" _
Alias "ml8_get_pgm_installed" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_get_pgm_installed Lib "wml2bib.dll" _
Alias "ml8_get_pgm_installed" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_pgm_installed Lib "mlxw32.dll" _
Alias "ml8_get_pgm_installed" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_pgm_installed Lib "wml6bib.dll" _
Alias "ml8_get_pgm_installed" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_pgm_installed Lib "mlxw32.dll" _
Alias "ml8_get_pgm_installed" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_pgm_installed Lib "wml7bib.dll" _
Alias "ml8_get_pgm_installed" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_pgm_installed Lib "mlxw32.dll" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_get_pgm_installed Lib "wml8bib.dll" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_int_task
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_get_int_task Lib "mlxw32.dll" _
Alias "ml8_get_int_task" _
(ByVal inter As Integer, ByRef task As Integer, _
ByRef dummy As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_get_int_task Lib "wml2bib.dll" _
Alias "ml8_get_int_task" _
(ByVal inter As Integer, ByRef task As Integer, _
ByRef dummy As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_int_task Lib "mlxw32.dll" _
Alias "ml8_get_int_task" _
(ByVal inter As Integer, ByRef task As Integer, _
ByRef dummy As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_get_int_task Lib "wml6bib.dll" _
Alias "ml8_get_int_task" _
(ByVal inter As Integer, ByRef task As Integer, _
ByRef dummy As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_int_task Lib "mlxw32.dll" _
Alias "ml8_get_int_task" _
(ByVal inter As Integer, ByRef task As Integer, _
ByRef dummy As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_get_int_task Lib "wml7bib.dll" _
Alias "ml8_get_int_task" _
(ByVal inter As Integer, ByRef task As Integer, _
ByRef dummy As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_int_task Lib "mlxw32.dll" _
(ByVal inter As Integer, ByRef task As Integer, _
ByRef dummy As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_get_int_task Lib "wml8bib.dll" _
(ByVal inter As Integer, ByRef task As Integer, _
ByRef dummy As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_wakeup_task
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_wakeup_task Lib "mlxw32.dll" _
Alias "ml8_wakeup_task" (ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_wakeup_task Lib "wml2bib.dll" _
Alias "ml8_wakeup_task" (ByVal task As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_wakeup_task Lib "mlxw32.dll" _
Alias "ml8_wakeup_task" (ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_wakeup_task Lib "wml6bib.dll" _
Alias "ml8_wakeup_task" (ByVal task As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_wakeup_task Lib "mlxw32.dll" _
Alias "ml8_wakeup_task" (ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_wakeup_task Lib "wml7bib.dll" _
Alias "ml8_wakeup_task" (ByVal task As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_wakeup_task Lib "mlxw32.dll" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_wakeup_task Lib "wml8bib.dll" _
(ByVal task As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_wakeup_ti_task
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_wakeup_ti_task Lib "mlxw32.dll" _
Alias "ml8_wakeup_ti_task" _
(ByVal task As Integer, ByVal priority As Byte, _
ByVal count As Long, ByVal interval As Long, ByVal holdoff As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_wakeup_ti_task Lib "wml2bib.dll" _
Alias "ml8_wakeup_ti_task" _
(ByVal task As Integer, ByVal priority As Byte, _
ByVal count As Long, ByVal interval As Long, ByVal holdoff As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_wakeup_ti_task Lib "mlxw32.dll" _
Alias "ml8_wakeup_ti_task" _
(ByVal task As Integer, ByVal priority As Byte, _
ByVal count As Long, ByVal interval As Long, ByVal holdoff As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_wakeup_ti_task Lib "wml6bib.dll" _
Alias "ml8_wakeup_ti_task" _
(ByVal task As Integer, ByVal priority As Byte, _
ByVal count As Long, ByVal interval As Long, ByVal holdoff As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_wakeup_ti_task Lib "mlxw32.dll" _
Alias "ml8_wakeup_ti_task" _
(ByVal task As Integer, ByVal priority As Byte, _
ByVal count As Long, ByVal interval As Long, ByVal holdoff As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_wakeup_ti_task Lib "wml7bib.dll" _
Alias "ml8_wakeup_ti_task" _
(ByVal task As Integer, ByVal priority As Byte, _
ByVal count As Long, ByVal interval As Long, ByVal holdoff As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_wakeup_ti_task Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal priority As Byte, _
ByVal count As Long, ByVal interval As Long, ByVal holdoff As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_wakeup_ti_task Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal priority As Byte, _
ByVal count As Long, ByVal interval As Long, ByVal holdoff As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_sleep_task
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_sleep_task Lib "mlxw32.dll" _
Alias "ml8_sleep_task" (ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_sleep_task Lib "wml2bib.dll" _
Alias "ml8_sleep_task" (ByVal task As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_sleep_task Lib "mlxw32.dll" _
Alias "ml8_sleep_task" (ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_sleep_task Lib "wml6bib.dll" _
Alias "ml8_sleep_task" (ByVal task As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_sleep_task Lib "mlxw32.dll" _
Alias "ml8_sleep_task" (ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_sleep_task Lib "wml7bib.dll" _
Alias "ml8_sleep_task" (ByVal task As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_sleep_task Lib "mlxw32.dll" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_sleep_task Lib "wml8bib.dll" _
(ByVal task As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_call_proc
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_call_proc Lib "mlxw32.dll" _
Alias "ml8_call_proc" _
(ByVal task As Integer, ByVal procnum As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_call_proc Lib "wml2bib.dll" _
Alias "ml8_call_proc" _
(ByVal task As Integer, ByVal procnum As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_call_proc Lib "mlxw32.dll" _
Alias "ml8_call_proc" _
(ByVal task As Integer, ByVal procnum As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_call_proc Lib "wml6bib.dll" _
Alias "ml8_call_proc" _
(ByVal task As Integer, ByVal procnum As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_call_proc Lib "mlxw32.dll" _
Alias "ml8_call_proc" _
(ByVal task As Integer, ByVal procnum As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_call_proc Lib "wml7bib.dll" _
Alias "ml8_call_proc" _
(ByVal task As Integer, ByVal procnum As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_call_proc Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal procnum As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_call_proc Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal procnum As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_call_func
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_call_func Lib "mlxw32.dll" _
Alias "ml8_call_func" _
(ByVal task As Integer, ByVal func As Integer, _
ByVal outsize As Integer, ByRef outdata As Any, _
ByVal maxinsize As Integer, ByRef insize As Integer, _
ByRef indata As Any, berror As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_call_func Lib "wml2bib.dll" _
Alias "ml8_call_func" _
(ByVal task As Integer, ByVal func As Integer, _
ByVal outsize As Integer, ByRef outdata As Any, _
ByVal maxinsize As Integer, ByRef insize As Integer, _
ByRef indata As Any, berror As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_call_func Lib "mlxw32.dll" _
Alias "ml8_call_func" _
(ByVal task As Integer, ByVal func As Integer, _
ByVal outsize As Integer, ByRef outdata As Any, _
ByVal maxinsize As Integer, ByRef insize As Integer, _
ByRef indata As Any, berror As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_call_func Lib "wml6bib.dll" _
Alias "ml8_call_func" _
(ByVal task As Integer, ByVal func As Integer, _
ByVal outsize As Integer, ByRef outdata As Any, _
ByVal maxinsize As Integer, ByRef insize As Integer, _
ByRef indata As Any, berror As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_call_func Lib "mlxw32.dll" _
Alias "ml8_call_func" _
(ByVal task As Integer, ByVal func As Integer, _
ByVal outsize As Integer, ByRef outdata As Any, _
ByVal maxinsize As Integer, ByRef insize As Integer, _
ByRef indata As Any, berror As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_call_func Lib "wml7bib.dll" _
Alias "ml8_call_func" _
(ByVal task As Integer, ByVal func As Integer, _
ByVal outsize As Integer, ByRef outdata As Any, _
ByVal maxinsize As Integer, ByRef insize As Integer, _
ByRef indata As Any, berror As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_call_func Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal func As Integer, _
ByVal outsize As Integer, ByRef outdata As Any, _
ByVal maxinsize As Integer, ByRef insize As Integer, _
ByRef indata As Any, berror As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_call_func Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal func As Integer, _
ByVal outsize As Integer, ByRef outdata As Any, _
ByVal maxinsize As Integer, ByRef insize As Integer, _
ByRef indata As Any, berror As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_par_byte
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_read_par_byte _
Lib "mlxw32.dll" Alias "ml8_read_par_byte" _
(ByVal task As Integer, ByVal start As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_read_par_byte _
Lib "wml2bib.dll" Alias "ml8_read_par_byte" _
(ByVal task As Integer, ByVal start As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_read_par_byte _
Lib "mlxw32.dll" Alias "ml8_read_par_byte" _
(ByVal task As Integer, ByVal start As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_read_par_byte _
Lib "wml6bib.dll" Alias "ml8_read_par_byte" _
(ByVal task As Integer, ByVal start As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_read_par_byte _
Lib "mlxw32.dll" Alias "ml8_read_par_byte" _
(ByVal task As Integer, ByVal start As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_read_par_byte _
Lib "wml7bib.dll" Alias "ml8_read_par_byte" _
(ByVal task As Integer, ByVal start As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_read_par_byte _
Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal start As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_read_par_byte _
Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal start As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_par_word
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_read_par_word _
Lib "mlxw32.dll" Alias "ml8_read_par_word" _
(ByVal task As Integer, ByVal start As Integer) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_read_par_word _
Lib "wml2bib.dll" Alias "ml8_read_par_word" _
(ByVal task As Integer, ByVal start As Integer) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_read_par_word _
Lib "mlxw32.dll" Alias "ml8_read_par_word" _
(ByVal task As Integer, ByVal start As Integer) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_read_par_word _
Lib "wml6bib.dll" Alias "ml8_read_par_word" _
(ByVal task As Integer, ByVal start As Integer) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_read_par_word _
Lib "mlxw32.dll" Alias "ml8_read_par_word" _
(ByVal task As Integer, ByVal start As Integer) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_read_par_word _
Lib "wml7bib.dll" Alias "ml8_read_par_word" _
(ByVal task As Integer, ByVal start As Integer) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_read_par_word _
Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal start As Integer) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_read_par_word _
Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal start As Integer) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_par_dword
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_read_par_dword _
Lib "mlxw32.dll" Alias "ml8_read_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByRef data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_read_par_dword _
Lib "wml2bib.dll" Alias "ml8_read_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByRef data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_read_par_dword _
Lib "mlxw32.dll" Alias "ml8_read_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByRef data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_read_par_dword _
Lib "wml6bib.dll" Alias "ml8_read_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByRef data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_read_par_dword _
Lib "mlxw32.dll" Alias "ml8_read_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByRef data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_read_par_dword _
Lib "wml7bib.dll" Alias "ml8_read_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByRef data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_read_par_dword _
Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByRef data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_read_par_dword _
Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByRef data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_par_block
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_read_par_block _
Lib "mlxw32.dll" Alias "ml8_read_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_read_par_block _
Lib "wml2bib.dll" Alias "ml8_read_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_read_par_block _
Lib "mlxw32.dll" Alias "ml8_read_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_read_par_block _
Lib "wml6bib.dll" Alias "ml8_read_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_read_par_block _
Lib "mlxw32.dll" Alias "ml8_read_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_read_par_block _
Lib "wml7bib.dll" Alias "ml8_read_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_read_par_block Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_read_par_block Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_par_byte
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_par_byte _
Lib "mlxw32.dll" Alias "ml8_write_par_byte" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_par_byte _
Lib "wml2bib.dll" Alias "ml8_write_par_byte" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_par_byte _
Lib "mlxw32.dll" Alias "ml8_write_par_byte" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_par_byte _
Lib "wml6bib.dll" Alias "ml8_write_par_byte" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_par_byte _
Lib "mlxw32.dll" Alias "ml8_write_par_byte" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_par_byte _
Lib "wml7bib.dll" Alias "ml8_write_par_byte" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_par_byte Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_par_byte Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_par_word
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_par_word _
Lib "mlxw32.dll" Alias "ml8_write_par_word" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_par_word _
Lib "wml2bib.dll" Alias "ml8_write_par_word" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_par_word _
Lib "mlxw32.dll" Alias "ml8_write_par_word" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_par_word _
Lib "wml6bib.dll" Alias "ml8_write_par_word" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_par_word _
Lib "mlxw32.dll" Alias "ml8_write_par_word" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_par_word _
Lib "wml7bib.dll" Alias "ml8_write_par_word" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_par_word Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_par_word Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_par_dword
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_par_dword _
Lib "mlxw32.dll" Alias "ml8_write_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_par_dword _
Lib "wml2bib.dll" Alias "ml8_write_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_par_dword _
Lib "mlxw32.dll" Alias "ml8_write_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_par_dword _
Lib "wml6bib.dll" Alias "ml8_write_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_par_dword _
Lib "mlxw32.dll" Alias "ml8_write_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_par_dword _
Lib "wml7bib.dll" Alias "ml8_write_par_dword" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_par_dword Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_par_dword Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_par_block
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_par_block _
Lib "mlxw32.dll" Alias "ml8_write_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_par_block _
Lib "wml2bib.dll" Alias "ml8_write_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_par_block _
Lib "mlxw32.dll" Alias "ml8_write_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_par_block _
Lib "wml6bib.dll" Alias "ml8_write_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_par_block _
Lib "mlxw32.dll" Alias "ml8_write_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_par_block _
Lib "wml7bib.dll" Alias "ml8_write_par_block" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_par_block Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_par_block Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal start As Integer, _
ByVal size As Integer, data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_reset_r_pointer
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_reset_r_pointer Lib "mlxw32.dll" _
Alias "ml8_reset_r_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_reset_r_pointer Lib "wml2bib.dll" _
Alias "ml8_reset_r_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_reset_r_pointer Lib "mlxw32.dll" _
Alias "ml8_reset_r_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_reset_r_pointer Lib "wml6bib.dll" _
Alias "ml8_reset_r_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_reset_r_pointer Lib "mlxw32.dll" _
Alias "ml8_reset_r_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_reset_r_pointer Lib "wml7bib.dll" _
Alias "ml8_reset_r_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_reset_r_pointer Lib "mlxw32.dll" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_reset_r_pointer Lib "wml8bib.dll" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_reset_w_pointer
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_reset_w_pointer Lib "mlxw32.dll" _
Alias "ml8_reset_w_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_reset_w_pointer Lib "wml2bib.dll" _
Alias "ml8_reset_w_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_reset_w_pointer Lib "mlxw32.dll" _
Alias "ml8_reset_w_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_reset_w_pointer Lib "wml6bib.dll" _
Alias "ml8_reset_w_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_reset_w_pointer Lib "mlxw32.dll" _
Alias "ml8_reset_w_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_reset_w_pointer Lib "wml7bib.dll" _
Alias "ml8_reset_w_pointer" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_reset_w_pointer Lib "mlxw32.dll" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_reset_w_pointer Lib "wml8bib.dll" _
(ByVal task As Integer)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_move_r_pointer
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_move_r_pointer Lib "mlxw32.dll" _
Alias "ml8_move_r_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_move_r_pointer Lib "wml2bib.dll" _
Alias "ml8_move_r_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_move_r_pointer Lib "mlxw32.dll" _
Alias "ml8_move_r_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_move_r_pointer Lib "wml6bib.dll" _
Alias "ml8_move_r_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_move_r_pointer Lib "mlxw32.dll" _
Alias "ml8_move_r_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_move_r_pointer Lib "wml7bib.dll" _
Alias "ml8_move_r_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_move_r_pointer Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_move_r_pointer Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_move_w_pointer
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_move_w_pointer Lib "mlxw32.dll" _
Alias "ml8_move_w_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_move_w_pointer Lib "wml2bib.dll" _
Alias "ml8_move_w_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_move_w_pointer Lib "mlxw32.dll" _
Alias "ml8_move_w_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_move_w_pointer Lib "wml6bib.dll" _
Alias "ml8_move_w_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_move_w_pointer Lib "mlxw32.dll" _
Alias "ml8_move_w_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_move_w_pointer Lib "wml7bib.dll" _
Alias "ml8_move_w_pointer" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_move_w_pointer Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_move_w_pointer Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal offset As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_data_byte
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_read_data_byte Lib "mlxw32.dll" _
Alias "ml8_read_data_byte" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_read_data_byte Lib "wml2bib.dll" _
Alias "ml8_read_data_byte" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_read_data_byte Lib "mlxw32.dll" _
Alias "ml8_read_data_byte" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_read_data_byte Lib "wml6bib.dll" _
Alias "ml8_read_data_byte" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_read_data_byte Lib "mlxw32.dll" _
Alias "ml8_read_data_byte" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_read_data_byte Lib "wml7bib.dll" _
Alias "ml8_read_data_byte" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_read_data_byte Lib "mlxw32.dll" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_read_data_byte Lib "wml8bib.dll" _
(ByVal task As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_data_word
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_read_data_word Lib "mlxw32.dll" _
Alias "ml8_read_data_word" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_read_data_word Lib "wml2bib.dll" _
Alias "ml8_read_data_word" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_read_data_word Lib "mlxw32.dll" _
Alias "ml8_read_data_word" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_read_data_word Lib "wml6bib.dll" _
Alias "ml8_read_data_word" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_read_data_word Lib "mlxw32.dll" _
Alias "ml8_read_data_word" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_read_data_word Lib "wml7bib.dll" _
Alias "ml8_read_data_word" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_read_data_word Lib "mlxw32.dll" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_read_data_word Lib "wml8bib.dll" _
(ByVal task As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_data_word
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_read_data_dword Lib "mlxw32.dll" _
Alias "ml8_read_data_dword" _
(ByVal task As Integer, ByRef data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_read_data_dword Lib "wml2bib.dll" _
Alias "ml8_read_data_dword" _
(ByVal task As Integer, ByRef data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_read_data_dword Lib "mlxw32.dll" _
Alias "ml8_read_data_dword" _
(ByVal task As Integer, ByRef data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_read_data_dword Lib "wml6bib.dll" _
Alias "ml8_read_data_dword" _
(ByVal task As Integer, ByRef data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_read_data_dword Lib "mlxw32.dll" _
Alias "ml8_read_data_dword" _
(ByVal task As Integer, ByRef data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_read_data_dword Lib "wml7bib.dll" _
Alias "ml8_read_data_dword" _
(ByVal task As Integer, ByRef data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_read_data_dword Lib "mlxw32.dll" _
(ByVal task As Integer, ByRef data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_read_data_dword Lib "wml8bib.dll" _
(ByVal task As Integer, ByRef data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_data_block
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_read_data_block Lib "mlxw32.dll" _
Alias "ml8_read_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_read_data_block Lib "wml2bib.dll" _
Alias "ml8_read_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_read_data_block Lib "mlxw32.dll" _
Alias "ml8_read_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_read_data_block Lib "wml6bib.dll" _
Alias "ml8_read_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_read_data_block Lib "mlxw32.dll" _
Alias "ml8_read_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_read_data_block Lib "wml7bib.dll" _
Alias "ml8_read_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_read_data_block Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_read_data_block Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_data_byte
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_data_byte Lib "mlxw32.dll" _
Alias "ml8_write_data_byte" _
(ByVal task As Integer, ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_data_byte Lib "wml2bib.dll" _
Alias "ml8_write_data_byte" _
(ByVal task As Integer, ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_data_byte Lib "mlxw32.dll" _
Alias "ml8_write_data_byte" _
(ByVal task As Integer, ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_data_byte Lib "wml6bib.dll" _
Alias "ml8_write_data_byte" _
(ByVal task As Integer, ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_data_byte Lib "mlxw32.dll" _
Alias "ml8_write_data_byte" _
(ByVal task As Integer, ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_data_byte Lib "wml7bib.dll" _
Alias "ml8_write_data_byte" _
(ByVal task As Integer, ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_data_byte Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_data_byte Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_data_word
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_data_word Lib "mlxw32.dll" _
Alias "ml8_write_data_word" _
(ByVal task As Integer, ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_data_word Lib "wml2bib.dll" _
Alias "ml8_write_data_word" _
(ByVal task As Integer, ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_data_word Lib "mlxw32.dll" _
Alias "ml8_write_data_word" _
(ByVal task As Integer, ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_data_word Lib "wml6bib.dll" _
Alias "ml8_write_data_word" _
(ByVal task As Integer, ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_data_word Lib "mlxw32.dll" _
Alias "ml8_write_data_word" _
(ByVal task As Integer, ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_data_word Lib "wml7bib.dll" _
Alias "ml8_write_data_word" _
(ByVal task As Integer, ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_data_word Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_data_word Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_data_dword
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_data_dword Lib "mlxw32.dll" _
Alias "ml8_write_data_dword" _
(ByVal task As Integer, ByVal data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_data_dword Lib "wml2bib.dll" _
Alias "ml8_write_data_dword" _
(ByVal task As Integer, ByVal data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_data_dword Lib "mlxw32.dll" _
Alias "ml8_write_data_dword" _
(ByVal task As Integer, ByVal data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_data_dword Lib "wml6bib.dll" _
Alias "ml8_write_data_word" _
(ByVal task As Integer, ByVal data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_data_dword Lib "mlxw32.dll" _
Alias "ml8_write_data_dword" _
(ByVal task As Integer, ByVal data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_data_dword Lib "wml7bib.dll" _
Alias "ml8_write_data_word" _
(ByVal task As Integer, ByVal data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_data_dword Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal data As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_data_dword Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal data As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_data_block
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_data_block Lib "mlxw32.dll" _
Alias "ml8_write_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_data_block Lib "wml2bib.dll" _
Alias "ml8_write_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_data_block Lib "mlxw32.dll" _
Alias "ml8_write_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_data_block Lib "wml6bib.dll" _
Alias "ml8_write_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_data_block Lib "mlxw32.dll" _
Alias "ml8_write_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_data_block Lib "wml7bib.dll" _
Alias "ml8_write_data_block" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_data_block Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_data_block Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal size As Integer, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_data
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_read_data Lib "mlxw32.dll" _
Alias "ml8_read_data" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_read_data Lib "wml6bib.dll" _
Alias "ml8_read_data" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_read_data Lib "mlxw32.dll" _
Alias "ml8_read_data" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_read_data Lib "wml7bib.dll" _
Alias "ml8_read_data" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_read_data Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_read_data Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_data
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_data Lib "mlxw32.dll" _
Alias "ml8_write_data" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_data Lib "wml6bib.dll" _
Alias "ml8_write_data" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_data Lib "mlxw32.dll" _
Alias "ml8_write_data" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_data Lib "wml7bib.dll" _
Alias "ml8_write_data" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_data Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_data Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal rel_ofs As Long, _
ByRef data As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_set_ram_pointer
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_set_ram_pointer Lib "mlxw32.dll" _
Alias "ml8_set_ram_pointer" _
(ByVal adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_set_ram_pointer Lib "wml2bib.dll" _
Alias "ml8_set_ram_pointer" _
(ByVal adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_set_ram_pointer Lib "mlxw32.dll" _
Alias "ml8_set_ram_pointer" _
(ByVal adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_set_ram_pointer Lib "wml6bib.dll" _
Alias "ml8_set_ram_pointer" _
(ByVal adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_set_ram_pointer Lib "mlxw32.dll" _
Alias "ml8_set_ram_pointer" _
(ByVal adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_set_ram_pointer Lib "wml7bib.dll" _
Alias "ml8_set_ram_pointer" _
(ByVal adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_set_ram_pointer Lib "mlxw32.dll" _
(ByVal adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_set_ram_pointer Lib "wml8bib.dll" _
(ByVal adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_ram
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_read_ram Lib "mlxw32.dll" _
Alias "ml8_read_ram" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_read_ram Lib "wml2bib.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_read_ram Lib "mlxw32.dll" _
Alias "ml8_read_ram" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_read_ram Lib "wml6bib.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_read_ram Lib "mlxw32.dll" _
Alias "ml8_read_ram" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_read_ram Lib "wml7bib.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_read_ram Lib "mlxw32.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_read_ram Lib "wml8bib.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_write_ram
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_ram Lib "mlxw32.dll" _
Alias "ml8_write_ram" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_ram Lib "wml2bib.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_ram Lib "mlxw32.dll" _
Alias "ml8_read_ram" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_ram Lib "wml6bib.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_ram Lib "mlxw32.dll" _
Alias "ml8_read_ram" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_ram Lib "wml7bib.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_ram Lib "mlxw32.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_ram Lib "wml8bib.dll" _
(ByVal size As Integer, ByRef data As Any)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_read_memory
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_read_memory Lib "mlxw32.dll" _
Alias "ml8_read_memory" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_read_memory Lib "wml6bib.dll" _
Alias "ml8_read_memory" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_read_memory Lib "mlxw32.dll" _
Alias "ml8_read_memory" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_read_memory Lib "wml7bib.dll" _
Alias "ml8_read_memory" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_read_memory Lib "mlxw32.dll" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_read_memory Lib "wml8bib.dll" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_memory
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_memory Lib "mlxw32.dll" _
Alias "ml8_write_memory" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_memory Lib "wml6bib.dll" _
Alias "ml8_write_memory" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_memory Lib "mlxw32.dll" _
Alias "ml8_write_memory" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_memory Lib "wml7bib.dll" _
Alias "ml8_write_memory" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_memory Lib "mlxw32.dll" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_memory Lib "wml8bib.dll" _
(ByVal start_adr As Long, ByVal size As Integer, _
ByRef data_ptr As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_in8_port
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_in8_port Lib "mlxw32.dll" _
Alias "ml8_in8_port" (ByVal port As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_in8_port Lib "wml2bib.dll" _
Alias "ml8_in8_port" (ByVal port As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_in8_port Lib "mlxw32.dll" _
Alias "ml8_in8_port" (ByVal port As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_in8_port Lib "wml6bib.dll" _
Alias "ml8_in8_port" (ByVal port As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_in8_port Lib "mlxw32.dll" _
Alias "ml8_in8_port" (ByVal port As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_in8_port Lib "wml7bib.dll" _
Alias "ml8_in8_port" (ByVal port As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_in8_port Lib "mlxw32.dll" _
(ByVal port As Integer) As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_in8_port Lib "wml8bib.dll" _
(ByVal port As Integer) As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_in16_port
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_in16_port Lib "mlxw32.dll" _
Alias "ml8_in16_port" (ByVal port As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_in16_port Lib "wml2bib.dll" _
Alias "ml8_in16_port" (ByVal port As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_in16_port Lib "mlxw32.dll" _
Alias "ml8_in16_port" (ByVal port As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_in16_port Lib "wml6bib.dll" _
Alias "ml8_in16_port" (ByVal port As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_in16_port Lib "mlxw32.dll" _
Alias "ml8_in16_port" (ByVal port As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_in16_port Lib "wml7bib.dll" _
Alias "ml8_in16_port" (ByVal port As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_in16_port Lib "mlxw32.dll" _
(ByVal port As Integer) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_in16_port Lib "wml8bib.dll" _
(ByVal port As Integer) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_out8_port
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_out8_port Lib "mlxw32.dll" _
Alias "ml8_out8_port" _
(ByVal port As Integer, ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_out8_port Lib "wml2bib.dll" _
Alias "ml8_out8_port" _
(ByVal port As Integer, ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_out8_port Lib "mlxw32.dll" _
Alias "ml8_out8_port" _
(ByVal port As Integer, ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_out8_port Lib "wml6bib.dll" _
Alias "ml8_out8_port" _
(ByVal port As Integer, ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_out8_port Lib "mlxw32.dll" _
Alias "ml8_out8_port" _
(ByVal port As Integer, ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_out8_port Lib "wml7bib.dll" _
Alias "ml8_out8_port" _
(ByVal port As Integer, ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_out8_port Lib "mlxw32.dll" _
(ByVal port As Integer, ByVal data As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_out8_port Lib "wml8bib.dll" _
(ByVal port As Integer, ByVal data As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_out16_port
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_out16_port Lib "mlxw32.dll" _
Alias "ml8_out16_port" _
(ByVal port As Integer, ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_out16_port Lib "wml2bib.dll" _
Alias "ml8_out16_port" _
(ByVal port As Integer, ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_out16_port Lib "mlxw32.dll" _
Alias "ml8_out16_port" _
(ByVal port As Integer, ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_out16_port Lib "wml6bib.dll" _
Alias "ml8_out16_port" _
(ByVal port As Integer, ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_out16_port Lib "mlxw32.dll" _
Alias "ml8_out16_port" _
(ByVal port As Integer, ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_out16_port Lib "wml7bib.dll" _
Alias "ml8_out16_port" _
(ByVal port As Integer, ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_out16_port Lib "mlxw32.dll" _
(ByVal port As Integer, ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_out16_port Lib "wml8bib.dll" _
(ByVal port As Integer, ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_set_macro_interruptible
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_set_macro_interruptible _
Lib "mlxw32.dll" Alias "ml8_set_macro_interruptible" _
(ByVal on_off As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_set_macro_interruptible _
Lib "wml2bib.dll" Alias "ml8_set_macro_interruptible" _
(ByVal on_off As Byte)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_set_macro_interruptible _
Lib "mlxw32.dll" Alias "ml8_set_macro_interruptible" _
(ByVal on_off As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_set_macro_interruptible _
Lib "wml6bib.dll" Alias "ml8_set_macro_interruptible" _
(ByVal on_off As Byte)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_set_macro_interruptible _
Lib "mlxw32.dll" Alias "ml8_set_macro_interruptible" _
(ByVal on_off As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_set_macro_interruptible _
Lib "wml7bib.dll" Alias "ml8_set_macro_interruptible" _
(ByVal on_off As Byte)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_set_macro_interruptible _
Lib "mlxw32.dll" (ByVal on_off As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_set_macro_interruptible _
Lib "wml8bib.dll" (ByVal on_off As Byte)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_allocate_ram
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_allocate_ram Lib "mlxw32.dll" _
Alias "ml8_allocate_ram" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal strategy As Byte, ByVal align As Byte, _
ByRef size As Long, ByRef adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_allocate_ram Lib "wml2bib.dll" _
Alias "ml8_allocate_ram" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal strategy As Byte, ByVal align As Byte, _
ByRef size As Long, ByRef adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_allocate_ram Lib "mlxw32.dll" _
Alias "ml8_allocate_ram" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal strategy As Byte, ByVal align As Byte, _
ByRef size As Long, ByRef adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_allocate_ram Lib "wml6bib.dll" _
Alias "ml8_allocate_ram" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal strategy As Byte, ByVal align As Byte, _
ByRef size As Long, ByRef adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_allocate_ram Lib "mlxw32.dll" _
Alias "ml8_allocate_ram" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal strategy As Byte, ByVal align As Byte, _
ByRef size As Long, ByRef adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_allocate_ram Lib "wml7bib.dll" _
Alias "ml8_allocate_ram" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal strategy As Byte, ByVal align As Byte, _
ByRef size As Long, ByRef adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_allocate_ram Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal strategy As Byte, ByVal align As Byte, _
ByRef size As Long, ByRef adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_allocate_ram Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal strategy As Byte, ByVal align As Byte, _
ByRef size As Long, ByRef adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_free_ram_size
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_get_free_ram_size Lib "mlxw32.dll" _
Alias "ml8_get_free_ram_size" _
(ByVal align As Byte, ByRef size As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_get_free_ram_size Lib "wml2bib.dll" _
Alias "ml8_get_free_ram_size" _
(ByVal align As Byte, ByRef size As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_free_ram_size Lib "mlxw32.dll" _
Alias "ml8_get_free_ram_size" _
(ByVal align As Byte, ByRef size As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_get_free_ram_size Lib "wml6bib.dll" _
Alias "ml8_get_free_ram_size" _
(ByVal align As Byte, ByRef size As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_free_ram_size Lib "mlxw32.dll" _
Alias "ml8_get_free_ram_size" _
(ByVal align As Byte, ByRef size As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_get_free_ram_size Lib "wml7bib.dll" _
Alias "ml8_get_free_ram_size" _
(ByVal align As Byte, ByRef size As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_free_ram_size Lib "mlxw32.dll" _
(ByVal align As Byte, ByRef size As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_get_free_ram_size Lib "wml8bib.dll" _
(ByVal align As Byte, ByRef size As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_transfer_pgm
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_transfer_pgm Lib "mlxw32.dll" _
Alias "ml8_transfer_pgm" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal pgmname As String, ByRef adr As Long, _
ByRef prepadr As Long, ByRef flag As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_transfer_pgm Lib "wml2bib.dll" _
Alias "ml8_transfer_pgm" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal pgmname As String, ByRef adr As Long, _
ByRef prepadr As Long, ByRef flag As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_transfer_pgm Lib "mlxw32.dll" _
Alias "ml8_transfer_pgm" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal pgmname As String, ByRef adr As Long, _
ByRef prepadr As Long, ByRef flag As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_transfer_pgm Lib "wml7bib.dll" _
Alias "ml8_transfer_pgm" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal pgmname As String, ByRef adr As Long, _
ByRef prepadr As Long, ByRef flag As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_transfer_pgm Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal pgmname As String, ByRef adr As Long, _
ByRef prepadr As Long, ByRef flag As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_transfer_pgm Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal usage As Integer, _
ByVal pgmname As String, ByRef adr As Long, _
ByRef prepadr As Long, ByRef flag As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_enable_remote_debug
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_enable_remote_debug Lib "mlxw32.dll" _
Alias "ml8_enable_remote_debug" _
(ByVal task As Integer, ByVal pgmname As String, _
ByVal loadadr As Long, ByRef prepadr As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_enable_remote_debug Lib "wml2bib.dll" _
Alias "ml8_enable_remote_debug" _
(ByVal task As Integer, ByVal pgmname As String, _
ByRef adr As Long, ByRef prepadr As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_enable_remote_debug Lib "mlxw32.dll" _
Alias "ml8_enable_remote_debug" _
(ByVal task As Integer, ByVal pgmname As String, _
ByVal loadadr As Long, ByRef prepadr As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_enable_remote_debug Lib "wml6bib.dll" _
Alias "ml8_enable_remote_debug" _
(ByVal task As Integer, ByVal pgmname As String, _
ByRef adr As Long, ByRef prepadr As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_enable_remote_debug Lib "mlxw32.dll" _
Alias "ml8_enable_remote_debug" _
(ByVal task As Integer, ByVal pgmname As String, _
ByVal loadadr As Long, ByRef prepadr As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_enable_remote_debug Lib "wml7bib.dll" _
Alias "ml8_enable_remote_debug" _
(ByVal task As Integer, ByVal pgmname As String, _
ByRef adr As Long, ByRef prepadr As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_enable_remote_debug Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal pgmname As String, _
ByVal loadadr As Long, ByRef prepadr As Long) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_enable_remote_debug Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal pgmname As String, _
ByRef adr As Long, ByRef prepadr As Long) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_send_macro
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_send_macro Lib "mlxw32.dll" _
Alias "ml8_send_macro" _
(ByVal CB As Byte, ByVal format As Byte, _
ByVal n As Integer, ByVal m As Integer, _
ByRef b As Any, ByRef dataout As Any) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_send_macro Lib "wml2bib.dll" _
Alias "ml8_send_macro" _
(ByVal CB As Byte, ByVal format As Byte, _
ByVal n As Integer, ByVal m As Integer, _
ByRef b As Any, ByRef dataout As Any) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_send_macro Lib "mlxw32.dll" _
Alias "ml8_send_macro" _
(ByVal CB As Byte, ByVal format As Byte, _
ByVal n As Integer, ByVal m As Integer, _
ByRef b As Any, ByRef dataout As Any) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_send_macro Lib "wml6bib.dll" _
Alias "ml8_send_macro" _
(ByVal CB As Byte, ByVal format As Byte, _
ByVal n As Integer, ByVal m As Integer, _
ByRef b As Any, ByRef dataout As Any) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_send_macro Lib "mlxw32.dll" _
Alias "ml8_send_macro" _
(ByVal CB As Byte, ByVal format As Byte, _
ByVal n As Integer, ByVal m As Integer, _
ByRef b As Any, ByRef dataout As Any) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_send_macro Lib "wml7bib.dll" _
Alias "ml8_send_macro" _
(ByVal CB As Byte, ByVal format As Byte, _
ByVal n As Integer, ByVal m As Integer, _
ByRef b As Any, ByRef dataout As Any) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_send_macro Lib "mlxw32.dll" _
(ByVal CB As Byte, ByVal format As Byte, _
ByVal n As Integer, ByVal m As Integer, _
ByRef b As Any, ByRef dataout As Any) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_send_macro Lib "wml8bib.dll" _
(ByVal CB As Byte, ByVal format As Byte, _
ByVal n As Integer, ByVal m As Integer, _
ByRef b As Any, ByRef dataout As Any) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_install_task
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_install_task Lib "mlxw32.dll" _
Alias "ml8_install_task" _
(ByVal task As Integer, ByVal prgnum As Integer, _
ByVal intnum As Integer, ByVal flag As Long, _
ByVal size As Long, ByVal adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_install_task Lib "wml2bib.dll" _
Alias "ml8_install_task" _
(ByVal task As Integer, ByVal prgnum As Integer, _
ByVal intnum As Integer, ByVal flag As Long, _
ByVal size As Long, ByVal adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_install_task Lib "mlxw32.dll" _
Alias "ml8_install_task" _
(ByVal task As Integer, ByVal prgnum As Integer, _
ByVal intnum As Integer, ByVal flag As Long, _
ByVal size As Long, ByVal adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_install_task Lib "wml6bib.dll" _
Alias "ml8_install_task" _
(ByVal task As Integer, ByVal prgnum As Integer, _
ByVal intnum As Integer, ByVal flag As Long, _
ByVal size As Long, ByVal adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_install_task Lib "mlxw32.dll" _
Alias "ml8_install_task" _
(ByVal task As Integer, ByVal prgnum As Integer, _
ByVal intnum As Integer, ByVal flag As Long, _
ByVal size As Long, ByVal adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_install_task Lib "wml7bib.dll" _
Alias "ml8_install_task" _
(ByVal task As Integer, ByVal prgnum As Integer, _
ByVal intnum As Integer, ByVal flag As Long, _
ByVal size As Long, ByVal adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_install_task Lib "mlxw32.dll" _
(ByVal task As Integer, ByVal prgnum As Integer, _
ByVal intnum As Integer, ByVal flag As Long, _
ByVal size As Long, ByVal adr As Long)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_install_task Lib "wml8bib.dll" _
(ByVal task As Integer, ByVal prgnum As Integer, _
ByVal intnum As Integer, ByVal flag As Long, _
ByVal size As Long, ByVal adr As Long)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_eeprom_copy
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_read_eeprom_copy _
Lib "mlxw32.dll" Alias "ml8_read_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_read_eeprom_copy _
Lib "wml2bib.dll" Alias "ml8_read_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_read_eeprom_copy _
Lib "mlxw32.dll" Alias "ml8_read_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_read_eeprom_copy _
Lib "wml6bib.dll" Alias "ml8_read_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_read_eeprom_copy _
Lib "mlxw32.dll" Alias "ml8_read_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_read_eeprom_copy _
Lib "wml7bib.dll" Alias "ml8_read_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_read_eeprom_copy _
Lib "mlxw32.dll" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_read_eeprom_copy _
Lib "wml8bib.dll" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_eeprom_direct
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Function ml2_read_eeprom_direct _
Lib "mlxw32.dll" Alias "ml8_read_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml2_read_eeprom_direct _
Lib "wml2bib.dll" Alias "ml8_read_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_read_eeprom_direct _
Lib "mlxw32.dll" Alias "ml8_read_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_read_eeprom_direct _
Lib "wml6bib.dll" Alias "ml8_read_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_read_eeprom_direct _
Lib "mlxw32.dll" Alias "ml8_read_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_read_eeprom_direct _
Lib "wml7bib.dll" Alias "ml8_read_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_read_eeprom_direct _
Lib "mlxw32.dll" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_read_eeprom_direct _
Lib "wml8bib.dll" _
(ByVal modul As Byte, ByVal reladr As Byte) As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_eeprom_copy
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_eeprom_copy Lib "mlxw32.dll" _
Alias "ml8_write_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_eeprom_copy Lib "wml2bib.dll" _
Alias "ml8_write_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_eeprom_copy Lib "mlxw32.dll" _
Alias "ml8_write_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_eeprom_copy Lib "wml6bib.dll" _
Alias "ml8_write_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_eeprom_copy Lib "mlxw32.dll" _
Alias "ml8_write_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_eeprom_copy Lib "wml7bib.dll" _
Alias "ml8_write_eeprom_copy" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_eeprom_copy Lib "mlxw32.dll" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_eeprom_copy Lib "wml8bib.dll" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_write_eeprom_direct
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_write_eeprom_direct Lib "mlxw32.dll" _
Alias "ml8_write_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml2_write_eeprom_direct Lib "wml2bib.dll" _
Alias "ml8_write_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_write_eeprom_direct Lib "mlxw32.dll" _
Alias "ml8_write_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_write_eeprom_direct Lib "wml6bib.dll" _
Alias "ml8_write_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_write_eeprom_direct Lib "mlxw32.dll" _
Alias "ml8_write_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_write_eeprom_direct Lib "wml7bib.dll" _
Alias "ml8_write_eeprom_direct" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_write_eeprom_direct Lib "mlxw32.dll" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_write_eeprom_direct Lib "wml8bib.dll" _
(ByVal modul As Byte, ByVal reladr As Byte, _
ByVal data As Integer)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_set_flash_mode
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_set_flash_mode Lib "mlxw32.dll" _
Alias "ml8_set_flash_mode" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_set_flash_mode Lib "wml6bib.dll" _
Alias "ml8_set_flash_mode" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_set_flash_mode Lib "mlxw32.dll" _
Alias "ml8_set_flash_mode" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_set_flash_mode Lib "wml7bib.dll" _
Alias "ml8_set_flash_mode" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_set_flash_mode Lib "mlxw32.dll" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_set_flash_mode Lib "wml8bib.dll" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_flash_info
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_flash_info Lib "mlxw32.dll" _
Alias "ml8_get_flash_info" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_flash_info Lib "wml6bib.dll" _
Alias "ml8_get_flash_info" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_flash_info Lib "mlxw32.dll" _
Alias "ml8_get_flash_info" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_flash_info Lib "wml7bib.dll" _
Alias "ml8_get_flash_info" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_flash_info Lib "mlxw32.dll" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_get_flash_info Lib "wml8bib.dll" _
(ByVal ucDevNo As Byte, ByVal icICNo As Byte, _
ByVal ucMode As Byte, ByVal ucOption As Byte) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_erase_flash_sector
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_erase_flash_sector _
Lib "mlxw32.dll" Alias "ml8_erase_flash_sector" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulFirstAdr As Long, ByVal ulLastAdr As Long) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_erase_flash_sector _
Lib "wml6bib.dll" Alias "ml8_erase_flash_sector" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulFirstAdr As Long, ByVal ulLastAdr As Long) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_erase_flash_sector _
Lib "mlxw32.dll" Alias "ml8_erase_flash_sector" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulFirstAdr As Long, ByVal ulLastAdr As Long) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_erase_flash_sector _
Lib "wml7bib.dll" Alias "ml8_erase_flash_sector" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulFirstAdr As Long, ByVal ulLastAdr As Long) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_erase_flash_sector _
Lib "mlxw32.dll" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulFirstAdr As Long, ByVal ulLastAdr As Long) _
As Integer
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_erase_flash_sector _
Lib "wml8bib.dll" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulFirstAdr As Long, ByVal ulLastAdr As Long) _
As Integer
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_program_flash
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_program_flash Lib "mlxw32.dll" _
Alias "ml8_program_flash" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_program_flash Lib "wml6bib.dll" _
Alias "ml8_program_flash" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_program_flash Lib "mlxw32.dll" _
Alias "ml8_program_flash" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_program_flash Lib "wml7bib.dll" _
Alias "ml8_program_flash" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_program_flash Lib "mlxw32.dll" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_program_flash Lib "wml8bib.dll" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_read_flash
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_read_flash Lib "mlxw32.dll" _
Alias "ml8_read_flash" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_read_flash Lib "wml6bib.dll" _
Alias "ml8_read_flash" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_read_flash Lib "mlxw32.dll" _
Alias "ml8_read_flash" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_read_flash Lib "wml7bib.dll" _
Alias "ml8_read_flash" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_read_flash Lib "mlxw32.dll" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_read_flash Lib "wml8bib.dll" _
(ByVal ucDevNo As Byte, ByVal ucICNo As Byte, _
ByVal ulStartAdr As Long, ByVal usSize As Integer, _
ByRef pData As Any)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_rtc_status
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_rtc_status _
Lib "mlxw32.dll" Alias "ml8_get_rtc_status" _
() As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_rtc_status _
Lib "wml6bib.dll" Alias "ml8_get_rtc_status" _
() As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_rtc_status _
Lib "mlxw32.dll" Alias "ml8_get_rtc_status" _
() As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_rtc_status _
Lib "wml7bib.dll" Alias "ml8_get_rtc_status" _
() As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_rtc_status _
Lib "mlxw32.dll" () As Byte
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_get_rtc_status _
Lib "wml8bib.dll" () As Byte
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_set_rtc_mode
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_set_rtc_mode Lib "mlxw32.dll" _
Alias "ml8_set_rtc_mode" _
(ByVal mode As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_set_rtc_mode Lib "wml6bib.dll" _
Alias "ml8_set_rtc_mode" _
(ByVal mode As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_set_rtc_mode Lib "mlxw32.dll" _
Alias "ml8_set_rtc_mode" _
(ByVal mode As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_set_rtc_mode Lib "wml7bib.dll" _
Alias "ml8_set_rtc_mode" _
(ByVal mode As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_set_rtc_mode Lib "mlxw32.dll" _
(ByVal mode As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_set_rtc_mode Lib "wml8bib.dll" _
(ByVal mode As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_date_and_time
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_date_and_time _
Lib "mlxw32.dll" Alias "ml8_get_date_and_time" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_get_date_and_time _
Lib "wml6bib.dll" Alias "ml8_get_date_and_time" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_date_and_time _
Lib "mlxw32.dll" Alias "ml8_get_date_and_time" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_get_date_and_time _
Lib "wml7bib.dll" Alias "ml8_get_date_and_time" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_date_and_time _
Lib "mlxw32.dll" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_get_date_and_time _
Lib "wml8bib.dll" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_date_and_time_2000
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_date_and_time_2000 _
Lib "mlxw32.dll" Alias "ml8_get_date_and_time_2000" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_get_date_and_time_2000 _
Lib "wml6bib.dll" Alias "ml8_get_date_and_time_2000" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_date_and_time_2000 _
Lib "mlxw32.dll" Alias "ml8_get_date_and_time_2000" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_get_date_and_time_2000 _
Lib "wml7bib.dll" Alias "ml8_get_date_and_time_2000" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_date_and_time_2000 _
Lib "mlxw32.dll" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_get_date_and_time_2000 _
Lib "wml8bib.dll" _
(ByRef year As Byte, ByRef month As Byte, _
ByRef day As Byte, ByRef dow As Byte, _
ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_time
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_time _
Lib "mlxw32.dll" Alias "ml8_get_time" _
(ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_get_time _
Lib "wml6bib.dll" Alias "ml8_get_time" _
(ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_time _
Lib "mlxw32.dll" Alias "ml8_get_time" _
(ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_get_time _
Lib "wml7bib.dll" Alias "ml8_get_time" _
(ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_time _
Lib "mlxw32.dll" _
(ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_get_time _
Lib "wml8bib.dll" _
(ByRef hour As Byte, ByRef min As Byte, _
ByRef sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_get_rtc_date_code
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_rtc_date_code _
Lib "mlxw32.dll" Alias "ml8_get_rtc_date_code" _
() As Long
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_rtc_date_code _
Lib "wml6bib.dll" Alias "ml8_get_rtc_date_code" _
() As Long
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_rtc_date_code _
Lib "mlxw32.dll" Alias "ml8_get_rtc_date_code" _
() As Long
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_rtc_date_code _
Lib "wml7bib.dll" Alias "ml8_get_rtc_date_code" _
() As Long
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_rtc_date_code _
Lib "mlxw32.dll" () As Long
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_get_rtc_date_code _
Lib "wml8bib.dll" () As Long
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_get_rtc_time_code
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Function ml6_get_rtc_time_code _
Lib "mlxw32.dll" Alias "ml8_get_rtc_time_code" _
() As Long
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml6_get_rtc_time_code _
Lib "wml6bib.dll" Alias "ml8_get_rtc_time_code" _
() As Long
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Function ml7_get_rtc_time_code _
Lib "mlxw32.dll" Alias "ml8_get_rtc_time_code" _
() As Long
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml7_get_rtc_time_code _
Lib "wml7bib.dll" Alias "ml8_get_rtc_time_code" _
() As Long
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Function ml8_get_rtc_time_code _
Lib "mlxw32.dll" () As Long
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Function ml8_get_rtc_time_code _
Lib "wml8bib.dll" () As Long
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_set_date_and_time
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_set_date_and_time _
Lib "mlxw32.dll" Alias "ml8_set_date_and_time" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_set_date_and_time _
Lib "wml6bib.dll" Alias "ml8_set_date_and_time" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_set_date_and_time _
Lib "mlxw32.dll" Alias "ml8_set_date_and_time" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_set_date_and_time _
Lib "wml7bib.dll" Alias "ml8_set_date_and_time" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_set_date_and_time _
Lib "mlxw32.dll" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_set_date_and_time _
Lib "wml8bib.dll" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_set_date_and_time_2000
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_set_date_and_time_2000 _
Lib "mlxw32.dll" Alias "ml8_set_date_and_time_2000" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_set_date_and_time_2000 _
Lib "wml6bib.dll" Alias "ml8_set_date_and_time_2000" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_set_date_and_time_2000 _
Lib "mlxw32.dll" Alias "ml8_set_date_and_time_2000" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_set_date_and_time_2000 _
Lib "wml7bib.dll" Alias "ml8_set_date_and_time_2000" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_set_date_and_time_2000 _
Lib "mlxw32.dll" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_set_date_and_time_2000 _
Lib "wml8bib.dll" _
(ByVal year As Byte, ByVal month As Byte, _
ByVal day As Byte, ByVal dow As Byte, _
ByVal hour As Byte, ByVal min As Byte, _
ByVal sec As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8
   
'*************************************************
'   mlX_init_io
'*************************************************

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_init_io Lib "mlxw32.dll" _
Alias "ml8_init_io" _
(ByVal microchannel As Byte, ByVal opt As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml6_init_io Lib "wml6bib.dll" _
Alias "ml8_init_io" _
(ByVal microchannel As Byte, ByVal opt As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_init_io Lib "mlxw32.dll" _
Alias "ml8_init_io" _
(ByVal microchannel As Byte, ByVal opt As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml7_init_io Lib "wml7bib.dll" _
Alias "ml8_init_io" _
(ByVal microchannel As Byte, ByVal opt As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_init_io Lib "mlxw32.dll" _
(ByVal microchannel As Byte, ByVal opt As Byte)
#End If ' PLATFORM = 32
#If PLATFORM = 16 Then
Declare Sub ml8_init_io Lib "wml8bib.dll" _
(ByVal microchannel As Byte, ByVal opt As Byte)
#End If ' PLATFORM = 16
#End If ' BOARD = 8

'*************************************************
'   mlX_set_service
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_set_service _
Lib "mlxw32.dll" Alias "ml8_set_vb_service" _
(ByVal WM_msg As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_set_service _
Lib "mlxw32.dll" Alias "ml8_set_vb_service" _
(ByVal WM_msg As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_set_service _
Lib "mlxw32.dll" Alias "ml8_set_vb_service" _
(ByVal WM_msg As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_set_service Lib "mlxw32.dll" _
Alias "ml8_set_vb_service" (ByVal WM_msg As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_set_error_handling
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_set_error_handling _
Lib "mlxw32.dll" Alias "ml8_set_vb_error_handling" _
(ByVal WM_msg As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_set_error_handling _
Lib "mlxw32.dll" Alias "ml8_set_vb_error_handling" _
(ByVal WM_msg As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_set_error_handling _
Lib "mlxw32.dll" Alias "ml8_set_vb_error_handling" _
(ByVal WM_msg As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_set_error_handling _
Lib "mlxw32.dll" Alias "ml8_set_vb_error_handling" _
(ByVal WM_msg As Long)
#End If ' PLATFORM = 32
#End If ' BOARD = 8

'*************************************************
'   mlX_get_error_class_and_code
'*************************************************

#If BOARD = 2 Then
#If PLATFORM = 32 Then
Declare Sub ml2_get_error_class_and_code _
Lib "mlxw32.dll" Alias "ml8_get_error_class_and_code" _
(ByRef error_class As Byte, ByRef error_code As Byte)
#End If ' PLATFORM = 32
#End If ' BOARD = 2

#If BOARD = 6 Then
#If PLATFORM = 32 Then
Declare Sub ml6_get_error_class_and_code _
Lib "mlxw32.dll" Alias "ml8_get_error_class_and_code" _
(ByRef error_class As Byte, ByRef error_code As Byte)
#End If ' PLATFORM = 32
#End If ' BOARD = 6

#If BOARD = 7 Then
#If PLATFORM = 32 Then
Declare Sub ml7_get_error_class_and_code _
Lib "mlxw32.dll" Alias "ml8_get_error_class_and_code" _
(ByRef error_class As Byte, ByRef error_code As Byte)
#End If ' PLATFORM = 32
#End If ' BOARD = 7

#If BOARD = 8 Then
#If PLATFORM = 32 Then
Declare Sub ml8_get_error_class_and_code Lib "mlxw32.dll" _
(ByRef error_class As Byte, ByRef error_code As Byte)
#End If ' PLATFORM = 32
#End If ' BOARD = 8


'*************************************************
' ml8_write_dma ml8_read_dma * ML8 only
'*************************************************


#If BOARD = 8 Then
#If PLATFORM = 32 Then

Declare Function ml8_write_dma Lib "mlxw32.dll" _
(ByRef pbuffer, ByVal ulBufferSize As Long, ByRef pulBytesWritten As Long) As Integer
        
Declare Function ml8_read_dma Lib "mlxw32.dll" _
(ByRef pbuffer, ByVal ulBufferSize As Long, ByRef pulBytesRead As Long) As Integer

#End If ' PLATFORM = 32
#End If ' BOARD = 8

